% Copyright 2025 Daniel Nagel
%
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3c
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX
% version 2005/12/01 or later.
%
% This work has the LPPL maintenance status `maintained'.
% 
% The Current Maintainer of this work is Daniel Nagel
%
\__fontawesome_def_icon:nnnnn{}{42-group}{brands0}{0}{"E080}
\__fontawesome_def_icon:nnnnn{}{500px}{brands0}{1}{"F26E}
\__fontawesome_def_icon:nnnnn{\faA}{a}{free0}{0}{"41}
\__fontawesome_def_icon:nnnnn{\faAccessibleIcon}{accessible-icon}{brands0}{3}{"F368}
\__fontawesome_def_icon:nnnnn{\faAccusoft}{accusoft}{brands0}{4}{"F369}
\__fontawesome_def_icon:nnnnn{\faAddressBook}{address-book}{free0}{1}{"F2B9}
\__fontawesome_def_icon:nnnnn{\faAddressCard}{address-card}{free0}{2}{"F2BB}
\__fontawesome_def_icon:nnnnn{\faAdn}{adn}{brands0}{5}{"F170}
\__fontawesome_def_icon:nnnnn{\faAdversal}{adversal}{brands0}{6}{"F36A}
\__fontawesome_def_icon:nnnnn{\faAffiliatetheme}{affiliatetheme}{brands0}{7}{"F36B}
\__fontawesome_def_icon:nnnnn{\faAirbnb}{airbnb}{brands0}{8}{"F834}
\__fontawesome_def_icon:nnnnn{\faAlgolia}{algolia}{brands0}{9}{"F36C}
\__fontawesome_def_icon:nnnnn{\faAlignCenter}{align-center}{free0}{3}{"F037}
\__fontawesome_def_icon:nnnnn{\faAlignJustify}{align-justify}{free0}{4}{"F039}
\__fontawesome_def_icon:nnnnn{\faAlignLeft}{align-left}{free0}{5}{"F036}
\__fontawesome_def_icon:nnnnn{\faAlignRight}{align-right}{free0}{6}{"F038}
\__fontawesome_def_icon:nnnnn{\faAlipay}{alipay}{brands0}{10}{"F642}
\__fontawesome_def_icon:nnnnn{\faAmazon}{amazon}{brands0}{11}{"F270}
\__fontawesome_def_icon:nnnnn{\faAmazonPay}{amazon-pay}{brands0}{12}{"F42C}
\__fontawesome_def_icon:nnnnn{\faAmilia}{amilia}{brands0}{13}{"F36D}
\__fontawesome_def_icon:nnnnn{\faAnchor}{anchor}{free0}{7}{"F13D}
\__fontawesome_def_icon:nnnnn{\faAnchorCircleCheck}{anchor-circle-check}{free0}{8}{"E4AA}
\__fontawesome_def_icon:nnnnn{\faAnchorCircleExclamation}{anchor-circle-exclamation}{free0}{9}{"E4AB}
\__fontawesome_def_icon:nnnnn{\faAnchorCircleXmark}{anchor-circle-xmark}{free0}{10}{"E4AC}
\__fontawesome_def_icon:nnnnn{\faAnchorLock}{anchor-lock}{free0}{11}{"E4AD}
\__fontawesome_def_icon:nnnnn{\faAndroid}{android}{brands0}{14}{"F17B}
\__fontawesome_def_icon:nnnnn{\faAngellist}{angellist}{brands0}{15}{"F209}
\__fontawesome_def_icon:nnnnn{\faAngleDown}{angle-down}{free0}{12}{"F107}
\__fontawesome_def_icon:nnnnn{\faAngleLeft}{angle-left}{free0}{13}{"F104}
\__fontawesome_def_icon:nnnnn{\faAngleRight}{angle-right}{free0}{14}{"F105}
\__fontawesome_def_icon:nnnnn{\faAngleUp}{angle-up}{free0}{15}{"F106}
\__fontawesome_def_icon:nnnnn{\faAnglesDown}{angles-down}{free0}{16}{"F103}
\__fontawesome_def_icon:nnnnn{\faAnglesLeft}{angles-left}{free0}{17}{"F100}
\__fontawesome_def_icon:nnnnn{\faAnglesRight}{angles-right}{free0}{18}{"F101}
\__fontawesome_def_icon:nnnnn{\faAnglesUp}{angles-up}{free0}{19}{"F102}
\__fontawesome_def_icon:nnnnn{\faAngrycreative}{angrycreative}{brands0}{16}{"F36E}
\__fontawesome_def_icon:nnnnn{\faAngular}{angular}{brands0}{17}{"F420}
\__fontawesome_def_icon:nnnnn{\faAnkh}{ankh}{free0}{20}{"F644}
\__fontawesome_def_icon:nnnnn{\faAppStore}{app-store}{brands0}{18}{"F36F}
\__fontawesome_def_icon:nnnnn{\faAppStoreIos}{app-store-ios}{brands0}{19}{"F370}
\__fontawesome_def_icon:nnnnn{\faApper}{apper}{brands0}{20}{"F371}
\__fontawesome_def_icon:nnnnn{\faApple}{apple}{brands0}{21}{"F179}
\__fontawesome_def_icon:nnnnn{\faApplePay}{apple-pay}{brands0}{22}{"F415}
\__fontawesome_def_icon:nnnnn{\faAppleWhole}{apple-whole}{free0}{21}{"F5D1}
\__fontawesome_def_icon:nnnnn{\faArchway}{archway}{free0}{22}{"F557}
\__fontawesome_def_icon:nnnnn{\faArrowDown}{arrow-down}{free0}{23}{"F063}
\__fontawesome_def_icon:nnnnn{}{arrow-down-1-9}{free0}{24}{"F162}
\__fontawesome_def_icon:nnnnn{}{arrow-down-9-1}{free0}{25}{"F886}
\__fontawesome_def_icon:nnnnn{\faArrowDownAZ}{arrow-down-a-z}{free0}{26}{"F15D}
\__fontawesome_def_icon:nnnnn{\faArrowDownLong}{arrow-down-long}{free0}{27}{"F175}
\__fontawesome_def_icon:nnnnn{\faArrowDownShortWide}{arrow-down-short-wide}{free0}{28}{"F884}
\__fontawesome_def_icon:nnnnn{\faArrowDownUpAcrossLine}{arrow-down-up-across-line}{free0}{29}{"E4AF}
\__fontawesome_def_icon:nnnnn{\faArrowDownUpLock}{arrow-down-up-lock}{free0}{30}{"E4B0}
\__fontawesome_def_icon:nnnnn{\faArrowDownWideShort}{arrow-down-wide-short}{free0}{31}{"F160}
\__fontawesome_def_icon:nnnnn{\faArrowDownZA}{arrow-down-z-a}{free0}{32}{"F881}
\__fontawesome_def_icon:nnnnn{\faArrowLeft}{arrow-left}{free0}{33}{"F060}
\__fontawesome_def_icon:nnnnn{\faArrowLeftLong}{arrow-left-long}{free0}{34}{"F177}
\__fontawesome_def_icon:nnnnn{\faArrowPointer}{arrow-pointer}{free0}{35}{"F245}
\__fontawesome_def_icon:nnnnn{\faArrowRight}{arrow-right}{free0}{36}{"F061}
\__fontawesome_def_icon:nnnnn{\faArrowRightArrowLeft}{arrow-right-arrow-left}{free0}{37}{"F0EC}
\__fontawesome_def_icon:nnnnn{\faArrowRightFromBracket}{arrow-right-from-bracket}{free0}{38}{"F08B}
\__fontawesome_def_icon:nnnnn{\faArrowRightLong}{arrow-right-long}{free0}{39}{"F178}
\__fontawesome_def_icon:nnnnn{\faArrowRightToBracket}{arrow-right-to-bracket}{free0}{40}{"F090}
\__fontawesome_def_icon:nnnnn{\faArrowRightToCity}{arrow-right-to-city}{free0}{41}{"E4B3}
\__fontawesome_def_icon:nnnnn{\faArrowRotateLeft}{arrow-rotate-left}{free0}{42}{"F0E2}
\__fontawesome_def_icon:nnnnn{\faArrowRotateRight}{arrow-rotate-right}{free0}{43}{"F01E}
\__fontawesome_def_icon:nnnnn{\faArrowTrendDown}{arrow-trend-down}{free0}{44}{"E097}
\__fontawesome_def_icon:nnnnn{\faArrowTrendUp}{arrow-trend-up}{free0}{45}{"E098}
\__fontawesome_def_icon:nnnnn{\faArrowTurnDown}{arrow-turn-down}{free0}{46}{"F149}
\__fontawesome_def_icon:nnnnn{\faArrowTurnUp}{arrow-turn-up}{free0}{47}{"F148}
\__fontawesome_def_icon:nnnnn{\faArrowUp}{arrow-up}{free0}{48}{"F062}
\__fontawesome_def_icon:nnnnn{}{arrow-up-1-9}{free0}{49}{"F163}
\__fontawesome_def_icon:nnnnn{}{arrow-up-9-1}{free0}{50}{"F887}
\__fontawesome_def_icon:nnnnn{\faArrowUpAZ}{arrow-up-a-z}{free0}{51}{"F15E}
\__fontawesome_def_icon:nnnnn{\faArrowUpFromBracket}{arrow-up-from-bracket}{free0}{52}{"E09A}
\__fontawesome_def_icon:nnnnn{\faArrowUpFromGroundWater}{arrow-up-from-ground-water}{free0}{53}{"E4B5}
\__fontawesome_def_icon:nnnnn{\faArrowUpFromWaterPump}{arrow-up-from-water-pump}{free0}{54}{"E4B6}
\__fontawesome_def_icon:nnnnn{\faArrowUpLong}{arrow-up-long}{free0}{55}{"F176}
\__fontawesome_def_icon:nnnnn{\faArrowUpRightDots}{arrow-up-right-dots}{free0}{56}{"E4B7}
\__fontawesome_def_icon:nnnnn{\faArrowUpRightFromSquare}{arrow-up-right-from-square}{free0}{57}{"F08E}
\__fontawesome_def_icon:nnnnn{\faArrowUpShortWide}{arrow-up-short-wide}{free0}{58}{"F885}
\__fontawesome_def_icon:nnnnn{\faArrowUpWideShort}{arrow-up-wide-short}{free0}{59}{"F161}
\__fontawesome_def_icon:nnnnn{\faArrowUpZA}{arrow-up-z-a}{free0}{60}{"F882}
\__fontawesome_def_icon:nnnnn{\faArrowsDownToLine}{arrows-down-to-line}{free0}{61}{"E4B8}
\__fontawesome_def_icon:nnnnn{\faArrowsDownToPeople}{arrows-down-to-people}{free0}{62}{"E4B9}
\__fontawesome_def_icon:nnnnn{\faArrowsLeftRight}{arrows-left-right}{free0}{63}{"F07E}
\__fontawesome_def_icon:nnnnn{\faArrowsLeftRightToLine}{arrows-left-right-to-line}{free0}{64}{"E4BA}
\__fontawesome_def_icon:nnnnn{\faArrowsRotate}{arrows-rotate}{free0}{65}{"F021}
\__fontawesome_def_icon:nnnnn{\faArrowsSpin}{arrows-spin}{free0}{66}{"E4BB}
\__fontawesome_def_icon:nnnnn{\faArrowsSplitUpAndLeft}{arrows-split-up-and-left}{free0}{67}{"E4BC}
\__fontawesome_def_icon:nnnnn{\faArrowsToCircle}{arrows-to-circle}{free0}{68}{"E4BD}
\__fontawesome_def_icon:nnnnn{\faArrowsToDot}{arrows-to-dot}{free0}{69}{"E4BE}
\__fontawesome_def_icon:nnnnn{\faArrowsToEye}{arrows-to-eye}{free0}{70}{"E4BF}
\__fontawesome_def_icon:nnnnn{\faArrowsTurnRight}{arrows-turn-right}{free0}{71}{"E4C0}
\__fontawesome_def_icon:nnnnn{\faArrowsTurnToDots}{arrows-turn-to-dots}{free0}{72}{"E4C1}
\__fontawesome_def_icon:nnnnn{\faArrowsUpDown}{arrows-up-down}{free0}{73}{"F07D}
\__fontawesome_def_icon:nnnnn{\faArrowsUpDownLeftRight}{arrows-up-down-left-right}{free0}{74}{"F047}
\__fontawesome_def_icon:nnnnn{\faArrowsUpToLine}{arrows-up-to-line}{free0}{75}{"E4C2}
\__fontawesome_def_icon:nnnnn{\faArtstation}{artstation}{brands0}{23}{"F77A}
\__fontawesome_def_icon:nnnnn{\faAsterisk}{asterisk}{free0}{76}{"2A}
\__fontawesome_def_icon:nnnnn{\faAsymmetrik}{asymmetrik}{brands0}{25}{"F372}
\__fontawesome_def_icon:nnnnn{\faAt}{at}{free0}{77}{"40}
\__fontawesome_def_icon:nnnnn{\faAtlassian}{atlassian}{brands0}{27}{"F77B}
\__fontawesome_def_icon:nnnnn{\faAtom}{atom}{free0}{78}{"F5D2}
\__fontawesome_def_icon:nnnnn{\faAudible}{audible}{brands0}{28}{"F373}
\__fontawesome_def_icon:nnnnn{\faAudioDescription}{audio-description}{free0}{79}{"F29E}
\__fontawesome_def_icon:nnnnn{\faAustralSign}{austral-sign}{free0}{80}{"E0A9}
\__fontawesome_def_icon:nnnnn{\faAutoprefixer}{autoprefixer}{brands0}{29}{"F41C}
\__fontawesome_def_icon:nnnnn{\faAvianex}{avianex}{brands0}{30}{"F374}
\__fontawesome_def_icon:nnnnn{\faAviato}{aviato}{brands0}{31}{"F421}
\__fontawesome_def_icon:nnnnn{\faAward}{award}{free0}{81}{"F559}
\__fontawesome_def_icon:nnnnn{\faAws}{aws}{brands0}{32}{"F375}
\__fontawesome_def_icon:nnnnn{\faB}{b}{free0}{82}{"42}
\__fontawesome_def_icon:nnnnn{\faBaby}{baby}{free0}{83}{"F77C}
\__fontawesome_def_icon:nnnnn{\faBabyCarriage}{baby-carriage}{free0}{84}{"F77D}
\__fontawesome_def_icon:nnnnn{\faBackward}{backward}{free0}{85}{"F04A}
\__fontawesome_def_icon:nnnnn{\faBackwardFast}{backward-fast}{free0}{86}{"F049}
\__fontawesome_def_icon:nnnnn{\faBackwardStep}{backward-step}{free0}{87}{"F048}
\__fontawesome_def_icon:nnnnn{\faBacon}{bacon}{free0}{88}{"F7E5}
\__fontawesome_def_icon:nnnnn{\faBacteria}{bacteria}{free0}{89}{"E059}
\__fontawesome_def_icon:nnnnn{\faBacterium}{bacterium}{free0}{90}{"E05A}
\__fontawesome_def_icon:nnnnn{\faBagShopping}{bag-shopping}{free0}{91}{"F290}
\__fontawesome_def_icon:nnnnn{\faBahai}{bahai}{free0}{92}{"F666}
\__fontawesome_def_icon:nnnnn{\faBahtSign}{baht-sign}{free0}{93}{"E0AC}
\__fontawesome_def_icon:nnnnn{\faBan}{ban}{free0}{94}{"F05E}
\__fontawesome_def_icon:nnnnn{\faBanSmoking}{ban-smoking}{free0}{95}{"F54D}
\__fontawesome_def_icon:nnnnn{\faBandage}{bandage}{free0}{96}{"F462}
\__fontawesome_def_icon:nnnnn{\faBandcamp}{bandcamp}{brands0}{34}{"F2D5}
\__fontawesome_def_icon:nnnnn{\faBangladeshiTakaSign}{bangladeshi-taka-sign}{free0}{97}{"E2E6}
\__fontawesome_def_icon:nnnnn{\faBarcode}{barcode}{free0}{98}{"F02A}
\__fontawesome_def_icon:nnnnn{\faBars}{bars}{free0}{99}{"F0C9}
\__fontawesome_def_icon:nnnnn{\faBarsProgress}{bars-progress}{free0}{100}{"F828}
\__fontawesome_def_icon:nnnnn{\faBarsStaggered}{bars-staggered}{free0}{101}{"F550}
\__fontawesome_def_icon:nnnnn{\faBaseball}{baseball}{free0}{102}{"F433}
\__fontawesome_def_icon:nnnnn{\faBaseballBatBall}{baseball-bat-ball}{free0}{103}{"F432}
\__fontawesome_def_icon:nnnnn{\faBasketShopping}{basket-shopping}{free0}{104}{"F291}
\__fontawesome_def_icon:nnnnn{\faBasketball}{basketball}{free0}{105}{"F434}
\__fontawesome_def_icon:nnnnn{\faBath}{bath}{free0}{106}{"F2CD}
\__fontawesome_def_icon:nnnnn{\faBatteryEmpty}{battery-empty}{free0}{107}{"F244}
\__fontawesome_def_icon:nnnnn{\faBatteryFull}{battery-full}{free0}{108}{"F240}
\__fontawesome_def_icon:nnnnn{\faBatteryHalf}{battery-half}{free0}{109}{"F242}
\__fontawesome_def_icon:nnnnn{\faBatteryQuarter}{battery-quarter}{free0}{110}{"F243}
\__fontawesome_def_icon:nnnnn{\faBatteryThreeQuarters}{battery-three-quarters}{free0}{111}{"F241}
\__fontawesome_def_icon:nnnnn{\faBattleNet}{battle-net}{brands0}{35}{"F835}
\__fontawesome_def_icon:nnnnn{\faBed}{bed}{free0}{112}{"F236}
\__fontawesome_def_icon:nnnnn{\faBedPulse}{bed-pulse}{free0}{113}{"F487}
\__fontawesome_def_icon:nnnnn{\faBeerMugEmpty}{beer-mug-empty}{free0}{114}{"F0FC}
\__fontawesome_def_icon:nnnnn{\faBehance}{behance}{brands0}{36}{"F1B4}
\__fontawesome_def_icon:nnnnn{\faBell}{bell}{free0}{115}{"F0F3}
\__fontawesome_def_icon:nnnnn{\faBellConcierge}{bell-concierge}{free0}{116}{"F562}
\__fontawesome_def_icon:nnnnn{\faBellSlash}{bell-slash}{free0}{117}{"F1F6}
\__fontawesome_def_icon:nnnnn{\faBezierCurve}{bezier-curve}{free0}{118}{"F55B}
\__fontawesome_def_icon:nnnnn{\faBicycle}{bicycle}{free0}{119}{"F206}
\__fontawesome_def_icon:nnnnn{\faBilibili}{bilibili}{brands0}{37}{"E3D9}
\__fontawesome_def_icon:nnnnn{\faBimobject}{bimobject}{brands0}{38}{"F378}
\__fontawesome_def_icon:nnnnn{\faBinoculars}{binoculars}{free0}{120}{"F1E5}
\__fontawesome_def_icon:nnnnn{\faBiohazard}{biohazard}{free0}{121}{"F780}
\__fontawesome_def_icon:nnnnn{\faBitbucket}{bitbucket}{brands0}{39}{"F171}
\__fontawesome_def_icon:nnnnn{\faBitcoin}{bitcoin}{brands0}{40}{"F379}
\__fontawesome_def_icon:nnnnn{\faBitcoinSign}{bitcoin-sign}{free0}{122}{"E0B4}
\__fontawesome_def_icon:nnnnn{\faBity}{bity}{brands0}{41}{"F37A}
\__fontawesome_def_icon:nnnnn{\faBlackTie}{black-tie}{brands0}{42}{"F27E}
\__fontawesome_def_icon:nnnnn{\faBlackberry}{blackberry}{brands0}{43}{"F37B}
\__fontawesome_def_icon:nnnnn{\faBlender}{blender}{free0}{123}{"F517}
\__fontawesome_def_icon:nnnnn{\faBlenderPhone}{blender-phone}{free0}{124}{"F6B6}
\__fontawesome_def_icon:nnnnn{\faBlog}{blog}{free0}{125}{"F781}
\__fontawesome_def_icon:nnnnn{\faBlogger}{blogger}{brands0}{44}{"F37C}
\__fontawesome_def_icon:nnnnn{\faBloggerB}{blogger-b}{brands0}{45}{"F37D}
\__fontawesome_def_icon:nnnnn{\faBluesky}{bluesky}{brands0}{46}{"E671}
\__fontawesome_def_icon:nnnnn{\faBluetooth}{bluetooth}{brands0}{47}{"F293}
\__fontawesome_def_icon:nnnnn{\faBluetoothB}{bluetooth-b}{brands0}{48}{"F294}
\__fontawesome_def_icon:nnnnn{\faBold}{bold}{free0}{126}{"F032}
\__fontawesome_def_icon:nnnnn{\faBolt}{bolt}{free0}{127}{"F0E7}
\__fontawesome_def_icon:nnnnn{\faBoltLightning}{bolt-lightning}{free0}{128}{"E0B7}
\__fontawesome_def_icon:nnnnn{\faBomb}{bomb}{free0}{129}{"F1E2}
\__fontawesome_def_icon:nnnnn{\faBone}{bone}{free0}{130}{"F5D7}
\__fontawesome_def_icon:nnnnn{\faBong}{bong}{free0}{131}{"F55C}
\__fontawesome_def_icon:nnnnn{\faBook}{book}{free0}{132}{"F02D}
\__fontawesome_def_icon:nnnnn{\faBookAtlas}{book-atlas}{free0}{133}{"F558}
\__fontawesome_def_icon:nnnnn{\faBookBible}{book-bible}{free0}{134}{"F647}
\__fontawesome_def_icon:nnnnn{\faBookBookmark}{book-bookmark}{free0}{135}{"E0BB}
\__fontawesome_def_icon:nnnnn{\faBookJournalWhills}{book-journal-whills}{free0}{136}{"F66A}
\__fontawesome_def_icon:nnnnn{\faBookMedical}{book-medical}{free0}{137}{"F7E6}
\__fontawesome_def_icon:nnnnn{\faBookOpen}{book-open}{free0}{138}{"F518}
\__fontawesome_def_icon:nnnnn{\faBookOpenReader}{book-open-reader}{free0}{139}{"F5DA}
\__fontawesome_def_icon:nnnnn{\faBookQuran}{book-quran}{free0}{140}{"F687}
\__fontawesome_def_icon:nnnnn{\faBookSkull}{book-skull}{free0}{141}{"F6B7}
\__fontawesome_def_icon:nnnnn{\faBookTanakh}{book-tanakh}{free0}{142}{"F827}
\__fontawesome_def_icon:nnnnn{\faBookmark}{bookmark}{free0}{143}{"F02E}
\__fontawesome_def_icon:nnnnn{\faBootstrap}{bootstrap}{brands0}{49}{"F836}
\__fontawesome_def_icon:nnnnn{\faBorderAll}{border-all}{free0}{144}{"F84C}
\__fontawesome_def_icon:nnnnn{\faBorderNone}{border-none}{free0}{145}{"F850}
\__fontawesome_def_icon:nnnnn{\faBorderTopLeft}{border-top-left}{free0}{146}{"F853}
\__fontawesome_def_icon:nnnnn{\faBoreHole}{bore-hole}{free0}{147}{"E4C3}
\__fontawesome_def_icon:nnnnn{\faBots}{bots}{brands0}{50}{"E340}
\__fontawesome_def_icon:nnnnn{\faBottleDroplet}{bottle-droplet}{free0}{148}{"E4C4}
\__fontawesome_def_icon:nnnnn{\faBottleWater}{bottle-water}{free0}{149}{"E4C5}
\__fontawesome_def_icon:nnnnn{\faBowlFood}{bowl-food}{free0}{150}{"E4C6}
\__fontawesome_def_icon:nnnnn{\faBowlRice}{bowl-rice}{free0}{151}{"E2EB}
\__fontawesome_def_icon:nnnnn{\faBowlingBall}{bowling-ball}{free0}{152}{"F436}
\__fontawesome_def_icon:nnnnn{\faBox}{box}{free0}{153}{"F466}
\__fontawesome_def_icon:nnnnn{\faBoxArchive}{box-archive}{free0}{154}{"F187}
\__fontawesome_def_icon:nnnnn{\faBoxOpen}{box-open}{free0}{155}{"F49E}
\__fontawesome_def_icon:nnnnn{\faBoxTissue}{box-tissue}{free0}{156}{"E05B}
\__fontawesome_def_icon:nnnnn{\faBoxesPacking}{boxes-packing}{free0}{157}{"E4C7}
\__fontawesome_def_icon:nnnnn{\faBoxesStacked}{boxes-stacked}{free0}{158}{"F468}
\__fontawesome_def_icon:nnnnn{\faBraille}{braille}{free0}{159}{"F2A1}
\__fontawesome_def_icon:nnnnn{\faBrain}{brain}{free0}{160}{"F5DC}
\__fontawesome_def_icon:nnnnn{\faBrave}{brave}{brands0}{51}{"E63C}
\__fontawesome_def_icon:nnnnn{\faBraveReverse}{brave-reverse}{brands0}{52}{"E63D}
\__fontawesome_def_icon:nnnnn{\faBrazilianRealSign}{brazilian-real-sign}{free0}{161}{"E46C}
\__fontawesome_def_icon:nnnnn{\faBreadSlice}{bread-slice}{free0}{162}{"F7EC}
\__fontawesome_def_icon:nnnnn{\faBridge}{bridge}{free0}{163}{"E4C8}
\__fontawesome_def_icon:nnnnn{\faBridgeCircleCheck}{bridge-circle-check}{free0}{164}{"E4C9}
\__fontawesome_def_icon:nnnnn{\faBridgeCircleExclamation}{bridge-circle-exclamation}{free0}{165}{"E4CA}
\__fontawesome_def_icon:nnnnn{\faBridgeCircleXmark}{bridge-circle-xmark}{free0}{166}{"E4CB}
\__fontawesome_def_icon:nnnnn{\faBridgeLock}{bridge-lock}{free0}{167}{"E4CC}
\__fontawesome_def_icon:nnnnn{\faBridgeWater}{bridge-water}{free0}{168}{"E4CE}
\__fontawesome_def_icon:nnnnn{\faBriefcase}{briefcase}{free0}{169}{"F0B1}
\__fontawesome_def_icon:nnnnn{\faBriefcaseMedical}{briefcase-medical}{free0}{170}{"F469}
\__fontawesome_def_icon:nnnnn{\faBroom}{broom}{free0}{171}{"F51A}
\__fontawesome_def_icon:nnnnn{\faBroomBall}{broom-ball}{free0}{172}{"F458}
\__fontawesome_def_icon:nnnnn{\faBrush}{brush}{free0}{173}{"F55D}
\__fontawesome_def_icon:nnnnn{\faBtc}{btc}{brands0}{53}{"F15A}
\__fontawesome_def_icon:nnnnn{\faBucket}{bucket}{free0}{174}{"E4CF}
\__fontawesome_def_icon:nnnnn{\faBuffer}{buffer}{brands0}{54}{"F837}
\__fontawesome_def_icon:nnnnn{\faBug}{bug}{free0}{175}{"F188}
\__fontawesome_def_icon:nnnnn{\faBugSlash}{bug-slash}{free0}{176}{"E490}
\__fontawesome_def_icon:nnnnn{\faBugs}{bugs}{free0}{177}{"E4D0}
\__fontawesome_def_icon:nnnnn{\faBuilding}{building}{free0}{178}{"F1AD}
\__fontawesome_def_icon:nnnnn{\faBuildingCircleArrowRight}{building-circle-arrow-right}{free0}{179}{"E4D1}
\__fontawesome_def_icon:nnnnn{\faBuildingCircleCheck}{building-circle-check}{free0}{180}{"E4D2}
\__fontawesome_def_icon:nnnnn{\faBuildingCircleExclamation}{building-circle-exclamation}{free0}{181}{"E4D3}
\__fontawesome_def_icon:nnnnn{\faBuildingCircleXmark}{building-circle-xmark}{free0}{182}{"E4D4}
\__fontawesome_def_icon:nnnnn{\faBuildingColumns}{building-columns}{free0}{183}{"F19C}
\__fontawesome_def_icon:nnnnn{\faBuildingFlag}{building-flag}{free0}{184}{"E4D5}
\__fontawesome_def_icon:nnnnn{\faBuildingLock}{building-lock}{free0}{185}{"E4D6}
\__fontawesome_def_icon:nnnnn{\faBuildingNgo}{building-ngo}{free0}{186}{"E4D7}
\__fontawesome_def_icon:nnnnn{\faBuildingShield}{building-shield}{free0}{187}{"E4D8}
\__fontawesome_def_icon:nnnnn{\faBuildingUn}{building-un}{free0}{188}{"E4D9}
\__fontawesome_def_icon:nnnnn{\faBuildingUser}{building-user}{free0}{189}{"E4DA}
\__fontawesome_def_icon:nnnnn{\faBuildingWheat}{building-wheat}{free0}{190}{"E4DB}
\__fontawesome_def_icon:nnnnn{\faBullhorn}{bullhorn}{free0}{191}{"F0A1}
\__fontawesome_def_icon:nnnnn{\faBullseye}{bullseye}{free0}{192}{"F140}
\__fontawesome_def_icon:nnnnn{\faBurger}{burger}{free0}{193}{"F805}
\__fontawesome_def_icon:nnnnn{\faBuromobelexperte}{buromobelexperte}{brands0}{55}{"F37F}
\__fontawesome_def_icon:nnnnn{\faBurst}{burst}{free0}{194}{"E4DC}
\__fontawesome_def_icon:nnnnn{\faBus}{bus}{free0}{195}{"F207}
\__fontawesome_def_icon:nnnnn{\faBusSimple}{bus-simple}{free0}{196}{"F55E}
\__fontawesome_def_icon:nnnnn{\faBusinessTime}{business-time}{free0}{197}{"F64A}
\__fontawesome_def_icon:nnnnn{\faBuyNLarge}{buy-n-large}{brands0}{56}{"F8A6}
\__fontawesome_def_icon:nnnnn{\faBuysellads}{buysellads}{brands0}{57}{"F20D}
\__fontawesome_def_icon:nnnnn{\faC}{c}{free0}{198}{"43}
\__fontawesome_def_icon:nnnnn{\faCableCar}{cable-car}{free0}{199}{"F7DA}
\__fontawesome_def_icon:nnnnn{\faCakeCandles}{cake-candles}{free0}{200}{"F1FD}
\__fontawesome_def_icon:nnnnn{\faCalculator}{calculator}{free0}{201}{"F1EC}
\__fontawesome_def_icon:nnnnn{\faCalendar}{calendar}{free0}{202}{"F133}
\__fontawesome_def_icon:nnnnn{\faCalendarCheck}{calendar-check}{free0}{203}{"F274}
\__fontawesome_def_icon:nnnnn{\faCalendarDay}{calendar-day}{free0}{204}{"F783}
\__fontawesome_def_icon:nnnnn{\faCalendarDays}{calendar-days}{free0}{205}{"F073}
\__fontawesome_def_icon:nnnnn{\faCalendarMinus}{calendar-minus}{free0}{206}{"F272}
\__fontawesome_def_icon:nnnnn{\faCalendarPlus}{calendar-plus}{free0}{207}{"F271}
\__fontawesome_def_icon:nnnnn{\faCalendarWeek}{calendar-week}{free0}{208}{"F784}
\__fontawesome_def_icon:nnnnn{\faCalendarXmark}{calendar-xmark}{free0}{209}{"F273}
\__fontawesome_def_icon:nnnnn{\faCamera}{camera}{free0}{210}{"F030}
\__fontawesome_def_icon:nnnnn{\faCameraRetro}{camera-retro}{free0}{211}{"F083}
\__fontawesome_def_icon:nnnnn{\faCameraRotate}{camera-rotate}{free0}{212}{"E0D8}
\__fontawesome_def_icon:nnnnn{\faCampground}{campground}{free0}{213}{"F6BB}
\__fontawesome_def_icon:nnnnn{\faCanadianMapleLeaf}{canadian-maple-leaf}{brands0}{59}{"F785}
\__fontawesome_def_icon:nnnnn{\faCandyCane}{candy-cane}{free0}{214}{"F786}
\__fontawesome_def_icon:nnnnn{\faCannabis}{cannabis}{free0}{215}{"F55F}
\__fontawesome_def_icon:nnnnn{\faCapsules}{capsules}{free0}{216}{"F46B}
\__fontawesome_def_icon:nnnnn{\faCar}{car}{free0}{217}{"F1B9}
\__fontawesome_def_icon:nnnnn{\faCarBattery}{car-battery}{free0}{218}{"F5DF}
\__fontawesome_def_icon:nnnnn{\faCarBurst}{car-burst}{free0}{219}{"F5E1}
\__fontawesome_def_icon:nnnnn{\faCarOn}{car-on}{free0}{220}{"E4DD}
\__fontawesome_def_icon:nnnnn{\faCarRear}{car-rear}{free0}{221}{"F5DE}
\__fontawesome_def_icon:nnnnn{\faCarSide}{car-side}{free0}{222}{"F5E4}
\__fontawesome_def_icon:nnnnn{\faCarTunnel}{car-tunnel}{free0}{223}{"E4DE}
\__fontawesome_def_icon:nnnnn{\faCaravan}{caravan}{free0}{224}{"F8FF}
\__fontawesome_def_icon:nnnnn{\faCaretDown}{caret-down}{free0}{225}{"F0D7}
\__fontawesome_def_icon:nnnnn{\faCaretLeft}{caret-left}{free0}{226}{"F0D9}
\__fontawesome_def_icon:nnnnn{\faCaretRight}{caret-right}{free0}{227}{"F0DA}
\__fontawesome_def_icon:nnnnn{\faCaretUp}{caret-up}{free0}{228}{"F0D8}
\__fontawesome_def_icon:nnnnn{\faCarrot}{carrot}{free0}{229}{"F787}
\__fontawesome_def_icon:nnnnn{\faCartArrowDown}{cart-arrow-down}{free0}{230}{"F218}
\__fontawesome_def_icon:nnnnn{\faCartFlatbed}{cart-flatbed}{free0}{231}{"F474}
\__fontawesome_def_icon:nnnnn{\faCartFlatbedSuitcase}{cart-flatbed-suitcase}{free0}{232}{"F59D}
\__fontawesome_def_icon:nnnnn{\faCartPlus}{cart-plus}{free0}{233}{"F217}
\__fontawesome_def_icon:nnnnn{\faCartShopping}{cart-shopping}{free0}{234}{"F07A}
\__fontawesome_def_icon:nnnnn{\faCashRegister}{cash-register}{free0}{235}{"F788}
\__fontawesome_def_icon:nnnnn{\faCat}{cat}{free0}{236}{"F6BE}
\__fontawesome_def_icon:nnnnn{\faCcAmazonPay}{cc-amazon-pay}{brands0}{60}{"F42D}
\__fontawesome_def_icon:nnnnn{\faCcAmex}{cc-amex}{brands0}{61}{"F1F3}
\__fontawesome_def_icon:nnnnn{\faCcApplePay}{cc-apple-pay}{brands0}{62}{"F416}
\__fontawesome_def_icon:nnnnn{\faCcDinersClub}{cc-diners-club}{brands0}{63}{"F24C}
\__fontawesome_def_icon:nnnnn{\faCcDiscover}{cc-discover}{brands0}{64}{"F1F2}
\__fontawesome_def_icon:nnnnn{\faCcJcb}{cc-jcb}{brands0}{65}{"F24B}
\__fontawesome_def_icon:nnnnn{\faCcMastercard}{cc-mastercard}{brands0}{66}{"F1F1}
\__fontawesome_def_icon:nnnnn{\faCcPaypal}{cc-paypal}{brands0}{67}{"F1F4}
\__fontawesome_def_icon:nnnnn{\faCcStripe}{cc-stripe}{brands0}{68}{"F1F5}
\__fontawesome_def_icon:nnnnn{\faCcVisa}{cc-visa}{brands0}{69}{"F1F0}
\__fontawesome_def_icon:nnnnn{\faCediSign}{cedi-sign}{free0}{237}{"E0DF}
\__fontawesome_def_icon:nnnnn{\faCentSign}{cent-sign}{free0}{238}{"E3F5}
\__fontawesome_def_icon:nnnnn{\faCentercode}{centercode}{brands0}{70}{"F380}
\__fontawesome_def_icon:nnnnn{\faCentos}{centos}{brands0}{71}{"F789}
\__fontawesome_def_icon:nnnnn{\faCertificate}{certificate}{free0}{239}{"F0A3}
\__fontawesome_def_icon:nnnnn{\faChair}{chair}{free0}{240}{"F6C0}
\__fontawesome_def_icon:nnnnn{\faChalkboard}{chalkboard}{free0}{241}{"F51B}
\__fontawesome_def_icon:nnnnn{\faChalkboardUser}{chalkboard-user}{free0}{242}{"F51C}
\__fontawesome_def_icon:nnnnn{\faChampagneGlasses}{champagne-glasses}{free0}{243}{"F79F}
\__fontawesome_def_icon:nnnnn{\faChargingStation}{charging-station}{free0}{244}{"F5E7}
\__fontawesome_def_icon:nnnnn{\faChartArea}{chart-area}{free0}{245}{"F1FE}
\__fontawesome_def_icon:nnnnn{\faChartBar}{chart-bar}{free0}{246}{"F080}
\__fontawesome_def_icon:nnnnn{\faChartColumn}{chart-column}{free0}{247}{"E0E3}
\__fontawesome_def_icon:nnnnn{\faChartDiagram}{chart-diagram}{free0}{248}{"E695}
\__fontawesome_def_icon:nnnnn{\faChartGantt}{chart-gantt}{free0}{249}{"E0E4}
\__fontawesome_def_icon:nnnnn{\faChartLine}{chart-line}{free0}{250}{"F201}
\__fontawesome_def_icon:nnnnn{\faChartPie}{chart-pie}{free0}{251}{"F200}
\__fontawesome_def_icon:nnnnn{\faChartSimple}{chart-simple}{free0}{252}{"E473}
\__fontawesome_def_icon:nnnnn{\faCheck}{check}{free0}{253}{"F00C}
\__fontawesome_def_icon:nnnnn{\faCheckDouble}{check-double}{free0}{254}{"F560}
\__fontawesome_def_icon:nnnnn{\faCheckToSlot}{check-to-slot}{free0}{255}{"F772}
\__fontawesome_def_icon:nnnnn{\faCheese}{cheese}{free1}{0}{"F7EF}
\__fontawesome_def_icon:nnnnn{\faChess}{chess}{free1}{1}{"F439}
\__fontawesome_def_icon:nnnnn{\faChessBishop}{chess-bishop}{free1}{2}{"F43A}
\__fontawesome_def_icon:nnnnn{\faChessBoard}{chess-board}{free1}{3}{"F43C}
\__fontawesome_def_icon:nnnnn{\faChessKing}{chess-king}{free1}{4}{"F43F}
\__fontawesome_def_icon:nnnnn{\faChessKnight}{chess-knight}{free1}{5}{"F441}
\__fontawesome_def_icon:nnnnn{\faChessPawn}{chess-pawn}{free1}{6}{"F443}
\__fontawesome_def_icon:nnnnn{\faChessQueen}{chess-queen}{free1}{7}{"F445}
\__fontawesome_def_icon:nnnnn{\faChessRook}{chess-rook}{free1}{8}{"F447}
\__fontawesome_def_icon:nnnnn{\faChevronDown}{chevron-down}{free1}{9}{"F078}
\__fontawesome_def_icon:nnnnn{\faChevronLeft}{chevron-left}{free1}{10}{"F053}
\__fontawesome_def_icon:nnnnn{\faChevronRight}{chevron-right}{free1}{11}{"F054}
\__fontawesome_def_icon:nnnnn{\faChevronUp}{chevron-up}{free1}{12}{"F077}
\__fontawesome_def_icon:nnnnn{\faChild}{child}{free1}{13}{"F1AE}
\__fontawesome_def_icon:nnnnn{\faChildCombatant}{child-combatant}{free1}{14}{"E4E0}
\__fontawesome_def_icon:nnnnn{\faChildDress}{child-dress}{free1}{15}{"E59C}
\__fontawesome_def_icon:nnnnn{\faChildReaching}{child-reaching}{free1}{16}{"E59D}
\__fontawesome_def_icon:nnnnn{\faChildren}{children}{free1}{17}{"E4E1}
\__fontawesome_def_icon:nnnnn{\faChrome}{chrome}{brands0}{72}{"F268}
\__fontawesome_def_icon:nnnnn{\faChromecast}{chromecast}{brands0}{73}{"F838}
\__fontawesome_def_icon:nnnnn{\faChurch}{church}{free1}{18}{"F51D}
\__fontawesome_def_icon:nnnnn{\faCircle}{circle}{free1}{19}{"F111}
\__fontawesome_def_icon:nnnnn{\faCircleArrowDown}{circle-arrow-down}{free1}{20}{"F0AB}
\__fontawesome_def_icon:nnnnn{\faCircleArrowLeft}{circle-arrow-left}{free1}{21}{"F0A8}
\__fontawesome_def_icon:nnnnn{\faCircleArrowRight}{circle-arrow-right}{free1}{22}{"F0A9}
\__fontawesome_def_icon:nnnnn{\faCircleArrowUp}{circle-arrow-up}{free1}{23}{"F0AA}
\__fontawesome_def_icon:nnnnn{\faCircleCheck}{circle-check}{free1}{24}{"F058}
\__fontawesome_def_icon:nnnnn{\faCircleChevronDown}{circle-chevron-down}{free1}{25}{"F13A}
\__fontawesome_def_icon:nnnnn{\faCircleChevronLeft}{circle-chevron-left}{free1}{26}{"F137}
\__fontawesome_def_icon:nnnnn{\faCircleChevronRight}{circle-chevron-right}{free1}{27}{"F138}
\__fontawesome_def_icon:nnnnn{\faCircleChevronUp}{circle-chevron-up}{free1}{28}{"F139}
\__fontawesome_def_icon:nnnnn{\faCircleDollarToSlot}{circle-dollar-to-slot}{free1}{29}{"F4B9}
\__fontawesome_def_icon:nnnnn{\faCircleDot}{circle-dot}{free1}{30}{"F192}
\__fontawesome_def_icon:nnnnn{\faCircleDown}{circle-down}{free1}{31}{"F358}
\__fontawesome_def_icon:nnnnn{\faCircleExclamation}{circle-exclamation}{free1}{32}{"F06A}
\__fontawesome_def_icon:nnnnn{\faCircleH}{circle-h}{free1}{33}{"F47E}
\__fontawesome_def_icon:nnnnn{\faCircleHalfStroke}{circle-half-stroke}{free1}{34}{"F042}
\__fontawesome_def_icon:nnnnn{\faCircleInfo}{circle-info}{free1}{35}{"F05A}
\__fontawesome_def_icon:nnnnn{\faCircleLeft}{circle-left}{free1}{36}{"F359}
\__fontawesome_def_icon:nnnnn{\faCircleMinus}{circle-minus}{free1}{37}{"F056}
\__fontawesome_def_icon:nnnnn{\faCircleNodes}{circle-nodes}{free1}{38}{"E4E2}
\__fontawesome_def_icon:nnnnn{\faCircleNotch}{circle-notch}{free1}{39}{"F1CE}
\__fontawesome_def_icon:nnnnn{\faCirclePause}{circle-pause}{free1}{40}{"F28B}
\__fontawesome_def_icon:nnnnn{\faCirclePlay}{circle-play}{free1}{41}{"F144}
\__fontawesome_def_icon:nnnnn{\faCirclePlus}{circle-plus}{free1}{42}{"F055}
\__fontawesome_def_icon:nnnnn{\faCircleQuestion}{circle-question}{free1}{43}{"F059}
\__fontawesome_def_icon:nnnnn{\faCircleRadiation}{circle-radiation}{free1}{44}{"F7BA}
\__fontawesome_def_icon:nnnnn{\faCircleRight}{circle-right}{free1}{45}{"F35A}
\__fontawesome_def_icon:nnnnn{\faCircleStop}{circle-stop}{free1}{46}{"F28D}
\__fontawesome_def_icon:nnnnn{\faCircleUp}{circle-up}{free1}{47}{"F35B}
\__fontawesome_def_icon:nnnnn{\faCircleUser}{circle-user}{free1}{48}{"F2BD}
\__fontawesome_def_icon:nnnnn{\faCircleXmark}{circle-xmark}{free1}{49}{"F057}
\__fontawesome_def_icon:nnnnn{\faCity}{city}{free1}{50}{"F64F}
\__fontawesome_def_icon:nnnnn{\faClapperboard}{clapperboard}{free1}{51}{"E131}
\__fontawesome_def_icon:nnnnn{\faClipboard}{clipboard}{free1}{52}{"F328}
\__fontawesome_def_icon:nnnnn{\faClipboardCheck}{clipboard-check}{free1}{53}{"F46C}
\__fontawesome_def_icon:nnnnn{\faClipboardList}{clipboard-list}{free1}{54}{"F46D}
\__fontawesome_def_icon:nnnnn{\faClipboardQuestion}{clipboard-question}{free1}{55}{"E4E3}
\__fontawesome_def_icon:nnnnn{\faClipboardUser}{clipboard-user}{free1}{56}{"F7F3}
\__fontawesome_def_icon:nnnnn{\faClock}{clock}{free1}{57}{"F017}
\__fontawesome_def_icon:nnnnn{\faClockRotateLeft}{clock-rotate-left}{free1}{58}{"F1DA}
\__fontawesome_def_icon:nnnnn{\faClone}{clone}{free1}{59}{"F24D}
\__fontawesome_def_icon:nnnnn{\faClosedCaptioning}{closed-captioning}{free1}{60}{"F20A}
\__fontawesome_def_icon:nnnnn{\faCloud}{cloud}{free1}{61}{"F0C2}
\__fontawesome_def_icon:nnnnn{\faCloudArrowDown}{cloud-arrow-down}{free1}{62}{"F0ED}
\__fontawesome_def_icon:nnnnn{\faCloudArrowUp}{cloud-arrow-up}{free1}{63}{"F0EE}
\__fontawesome_def_icon:nnnnn{\faCloudBolt}{cloud-bolt}{free1}{64}{"F76C}
\__fontawesome_def_icon:nnnnn{\faCloudMeatball}{cloud-meatball}{free1}{65}{"F73B}
\__fontawesome_def_icon:nnnnn{\faCloudMoon}{cloud-moon}{free1}{66}{"F6C3}
\__fontawesome_def_icon:nnnnn{\faCloudMoonRain}{cloud-moon-rain}{free1}{67}{"F73C}
\__fontawesome_def_icon:nnnnn{\faCloudRain}{cloud-rain}{free1}{68}{"F73D}
\__fontawesome_def_icon:nnnnn{\faCloudShowersHeavy}{cloud-showers-heavy}{free1}{69}{"F740}
\__fontawesome_def_icon:nnnnn{\faCloudShowersWater}{cloud-showers-water}{free1}{70}{"E4E4}
\__fontawesome_def_icon:nnnnn{\faCloudSun}{cloud-sun}{free1}{71}{"F6C4}
\__fontawesome_def_icon:nnnnn{\faCloudSunRain}{cloud-sun-rain}{free1}{72}{"F743}
\__fontawesome_def_icon:nnnnn{\faCloudflare}{cloudflare}{brands0}{74}{"E07D}
\__fontawesome_def_icon:nnnnn{\faCloudscale}{cloudscale}{brands0}{75}{"F383}
\__fontawesome_def_icon:nnnnn{\faCloudsmith}{cloudsmith}{brands0}{76}{"F384}
\__fontawesome_def_icon:nnnnn{\faCloudversify}{cloudversify}{brands0}{77}{"F385}
\__fontawesome_def_icon:nnnnn{\faClover}{clover}{free1}{73}{"E139}
\__fontawesome_def_icon:nnnnn{\faCmplid}{cmplid}{brands0}{78}{"E360}
\__fontawesome_def_icon:nnnnn{\faCode}{code}{free1}{74}{"F121}
\__fontawesome_def_icon:nnnnn{\faCodeBranch}{code-branch}{free1}{75}{"F126}
\__fontawesome_def_icon:nnnnn{\faCodeCommit}{code-commit}{free1}{76}{"F386}
\__fontawesome_def_icon:nnnnn{\faCodeCompare}{code-compare}{free1}{77}{"E13A}
\__fontawesome_def_icon:nnnnn{\faCodeFork}{code-fork}{free1}{78}{"E13B}
\__fontawesome_def_icon:nnnnn{\faCodeMerge}{code-merge}{free1}{79}{"F387}
\__fontawesome_def_icon:nnnnn{\faCodePullRequest}{code-pull-request}{free1}{80}{"E13C}
\__fontawesome_def_icon:nnnnn{\faCodepen}{codepen}{brands0}{79}{"F1CB}
\__fontawesome_def_icon:nnnnn{\faCodiepie}{codiepie}{brands0}{80}{"F284}
\__fontawesome_def_icon:nnnnn{\faCoins}{coins}{free1}{81}{"F51E}
\__fontawesome_def_icon:nnnnn{\faColonSign}{colon-sign}{free1}{82}{"E140}
\__fontawesome_def_icon:nnnnn{\faComment}{comment}{free1}{83}{"F075}
\__fontawesome_def_icon:nnnnn{\faCommentDollar}{comment-dollar}{free1}{84}{"F651}
\__fontawesome_def_icon:nnnnn{\faCommentDots}{comment-dots}{free1}{85}{"F4AD}
\__fontawesome_def_icon:nnnnn{\faCommentMedical}{comment-medical}{free1}{86}{"F7F5}
\__fontawesome_def_icon:nnnnn{\faCommentNodes}{comment-nodes}{free1}{87}{"E696}
\__fontawesome_def_icon:nnnnn{\faCommentSlash}{comment-slash}{free1}{88}{"F4B3}
\__fontawesome_def_icon:nnnnn{\faCommentSms}{comment-sms}{free1}{89}{"F7CD}
\__fontawesome_def_icon:nnnnn{\faComments}{comments}{free1}{90}{"F086}
\__fontawesome_def_icon:nnnnn{\faCommentsDollar}{comments-dollar}{free1}{91}{"F653}
\__fontawesome_def_icon:nnnnn{\faCompactDisc}{compact-disc}{free1}{92}{"F51F}
\__fontawesome_def_icon:nnnnn{\faCompass}{compass}{free1}{93}{"F14E}
\__fontawesome_def_icon:nnnnn{\faCompassDrafting}{compass-drafting}{free1}{94}{"F568}
\__fontawesome_def_icon:nnnnn{\faCompress}{compress}{free1}{95}{"F066}
\__fontawesome_def_icon:nnnnn{\faComputer}{computer}{free1}{96}{"E4E5}
\__fontawesome_def_icon:nnnnn{\faComputerMouse}{computer-mouse}{free1}{97}{"F8CC}
\__fontawesome_def_icon:nnnnn{\faConfluence}{confluence}{brands0}{81}{"F78D}
\__fontawesome_def_icon:nnnnn{\faConnectdevelop}{connectdevelop}{brands0}{82}{"F20E}
\__fontawesome_def_icon:nnnnn{\faContao}{contao}{brands0}{83}{"F26D}
\__fontawesome_def_icon:nnnnn{\faCookie}{cookie}{free1}{98}{"F563}
\__fontawesome_def_icon:nnnnn{\faCookieBite}{cookie-bite}{free1}{99}{"F564}
\__fontawesome_def_icon:nnnnn{\faCopy}{copy}{free1}{100}{"F0C5}
\__fontawesome_def_icon:nnnnn{\faCopyright}{copyright}{free1}{101}{"F1F9}
\__fontawesome_def_icon:nnnnn{\faCottonBureau}{cotton-bureau}{brands0}{84}{"F89E}
\__fontawesome_def_icon:nnnnn{\faCouch}{couch}{free1}{102}{"F4B8}
\__fontawesome_def_icon:nnnnn{\faCow}{cow}{free1}{103}{"F6C8}
\__fontawesome_def_icon:nnnnn{\faCpanel}{cpanel}{brands0}{85}{"F388}
\__fontawesome_def_icon:nnnnn{\faCreativeCommons}{creative-commons}{brands0}{86}{"F25E}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsBy}{creative-commons-by}{brands0}{87}{"F4E7}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsNc}{creative-commons-nc}{brands0}{88}{"F4E8}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsNcEu}{creative-commons-nc-eu}{brands0}{89}{"F4E9}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsNcJp}{creative-commons-nc-jp}{brands0}{90}{"F4EA}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsNd}{creative-commons-nd}{brands0}{91}{"F4EB}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsPd}{creative-commons-pd}{brands0}{92}{"F4EC}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsPdAlt}{creative-commons-pd-alt}{brands0}{93}{"F4ED}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsRemix}{creative-commons-remix}{brands0}{94}{"F4EE}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsSa}{creative-commons-sa}{brands0}{95}{"F4EF}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsSampling}{creative-commons-sampling}{brands0}{96}{"F4F0}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsSamplingPlus}{creative-commons-sampling-plus}{brands0}{97}{"F4F1}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsShare}{creative-commons-share}{brands0}{98}{"F4F2}
\__fontawesome_def_icon:nnnnn{\faCreativeCommonsZero}{creative-commons-zero}{brands0}{99}{"F4F3}
\__fontawesome_def_icon:nnnnn{\faCreditCard}{credit-card}{free1}{104}{"F09D}
\__fontawesome_def_icon:nnnnn{\faCriticalRole}{critical-role}{brands0}{100}{"F6C9}
\__fontawesome_def_icon:nnnnn{\faCrop}{crop}{free1}{105}{"F125}
\__fontawesome_def_icon:nnnnn{\faCropSimple}{crop-simple}{free1}{106}{"F565}
\__fontawesome_def_icon:nnnnn{\faCross}{cross}{free1}{107}{"F654}
\__fontawesome_def_icon:nnnnn{\faCrosshairs}{crosshairs}{free1}{108}{"F05B}
\__fontawesome_def_icon:nnnnn{\faCrow}{crow}{free1}{109}{"F520}
\__fontawesome_def_icon:nnnnn{\faCrown}{crown}{free1}{110}{"F521}
\__fontawesome_def_icon:nnnnn{\faCrutch}{crutch}{free1}{111}{"F7F7}
\__fontawesome_def_icon:nnnnn{\faCruzeiroSign}{cruzeiro-sign}{free1}{112}{"E152}
\__fontawesome_def_icon:nnnnn{\faCss}{css}{brands0}{101}{"E6A2}
\__fontawesome_def_icon:nnnnn{}{css3}{brands0}{102}{"F13C}
\__fontawesome_def_icon:nnnnn{}{css3-alt}{brands0}{103}{"F38B}
\__fontawesome_def_icon:nnnnn{\faCube}{cube}{free1}{113}{"F1B2}
\__fontawesome_def_icon:nnnnn{\faCubes}{cubes}{free1}{114}{"F1B3}
\__fontawesome_def_icon:nnnnn{\faCubesStacked}{cubes-stacked}{free1}{115}{"E4E6}
\__fontawesome_def_icon:nnnnn{\faCuttlefish}{cuttlefish}{brands0}{104}{"F38C}
\__fontawesome_def_icon:nnnnn{\faD}{d}{free1}{116}{"44}
\__fontawesome_def_icon:nnnnn{\faDAndD}{d-and-d}{brands0}{106}{"F38D}
\__fontawesome_def_icon:nnnnn{\faDAndDBeyond}{d-and-d-beyond}{brands0}{107}{"F6CA}
\__fontawesome_def_icon:nnnnn{\faDailymotion}{dailymotion}{brands0}{108}{"E052}
\__fontawesome_def_icon:nnnnn{\faDartLang}{dart-lang}{brands0}{109}{"E693}
\__fontawesome_def_icon:nnnnn{\faDashcube}{dashcube}{brands0}{110}{"F210}
\__fontawesome_def_icon:nnnnn{\faDatabase}{database}{free1}{117}{"F1C0}
\__fontawesome_def_icon:nnnnn{\faDebian}{debian}{brands0}{111}{"E60B}
\__fontawesome_def_icon:nnnnn{\faDeezer}{deezer}{brands0}{112}{"E077}
\__fontawesome_def_icon:nnnnn{\faDeleteLeft}{delete-left}{free1}{118}{"F55A}
\__fontawesome_def_icon:nnnnn{\faDelicious}{delicious}{brands0}{113}{"F1A5}
\__fontawesome_def_icon:nnnnn{\faDemocrat}{democrat}{free1}{119}{"F747}
\__fontawesome_def_icon:nnnnn{\faDeploydog}{deploydog}{brands0}{114}{"F38E}
\__fontawesome_def_icon:nnnnn{\faDeskpro}{deskpro}{brands0}{115}{"F38F}
\__fontawesome_def_icon:nnnnn{\faDesktop}{desktop}{free1}{120}{"F390}
\__fontawesome_def_icon:nnnnn{\faDev}{dev}{brands0}{116}{"F6CC}
\__fontawesome_def_icon:nnnnn{\faDeviantart}{deviantart}{brands0}{117}{"F1BD}
\__fontawesome_def_icon:nnnnn{\faDharmachakra}{dharmachakra}{free1}{121}{"F655}
\__fontawesome_def_icon:nnnnn{\faDhl}{dhl}{brands0}{118}{"F790}
\__fontawesome_def_icon:nnnnn{\faDiagramNext}{diagram-next}{free1}{122}{"E476}
\__fontawesome_def_icon:nnnnn{\faDiagramPredecessor}{diagram-predecessor}{free1}{123}{"E477}
\__fontawesome_def_icon:nnnnn{\faDiagramProject}{diagram-project}{free1}{124}{"F542}
\__fontawesome_def_icon:nnnnn{\faDiagramSuccessor}{diagram-successor}{free1}{125}{"E47A}
\__fontawesome_def_icon:nnnnn{\faDiamond}{diamond}{free1}{126}{"F219}
\__fontawesome_def_icon:nnnnn{\faDiamondTurnRight}{diamond-turn-right}{free1}{127}{"F5EB}
\__fontawesome_def_icon:nnnnn{\faDiaspora}{diaspora}{brands0}{119}{"F791}
\__fontawesome_def_icon:nnnnn{\faDice}{dice}{free1}{128}{"F522}
\__fontawesome_def_icon:nnnnn{}{dice-d20}{free1}{129}{"F6CF}
\__fontawesome_def_icon:nnnnn{}{dice-d6}{free1}{130}{"F6D1}
\__fontawesome_def_icon:nnnnn{\faDiceFive}{dice-five}{free1}{131}{"F523}
\__fontawesome_def_icon:nnnnn{\faDiceFour}{dice-four}{free1}{132}{"F524}
\__fontawesome_def_icon:nnnnn{\faDiceOne}{dice-one}{free1}{133}{"F525}
\__fontawesome_def_icon:nnnnn{\faDiceSix}{dice-six}{free1}{134}{"F526}
\__fontawesome_def_icon:nnnnn{\faDiceThree}{dice-three}{free1}{135}{"F527}
\__fontawesome_def_icon:nnnnn{\faDiceTwo}{dice-two}{free1}{136}{"F528}
\__fontawesome_def_icon:nnnnn{\faDigg}{digg}{brands0}{120}{"F1A6}
\__fontawesome_def_icon:nnnnn{\faDigitalOcean}{digital-ocean}{brands0}{121}{"F391}
\__fontawesome_def_icon:nnnnn{\faDiscord}{discord}{brands0}{122}{"F392}
\__fontawesome_def_icon:nnnnn{\faDiscourse}{discourse}{brands0}{123}{"F393}
\__fontawesome_def_icon:nnnnn{\faDisease}{disease}{free1}{137}{"F7FA}
\__fontawesome_def_icon:nnnnn{\faDisplay}{display}{free1}{138}{"E163}
\__fontawesome_def_icon:nnnnn{\faDivide}{divide}{free1}{139}{"F529}
\__fontawesome_def_icon:nnnnn{\faDna}{dna}{free1}{140}{"F471}
\__fontawesome_def_icon:nnnnn{\faDochub}{dochub}{brands0}{124}{"F394}
\__fontawesome_def_icon:nnnnn{\faDocker}{docker}{brands0}{125}{"F395}
\__fontawesome_def_icon:nnnnn{\faDog}{dog}{free1}{141}{"F6D3}
\__fontawesome_def_icon:nnnnn{\faDollarSign}{dollar-sign}{free1}{142}{"24}
\__fontawesome_def_icon:nnnnn{\faDolly}{dolly}{free1}{143}{"F472}
\__fontawesome_def_icon:nnnnn{\faDongSign}{dong-sign}{free1}{144}{"E169}
\__fontawesome_def_icon:nnnnn{\faDoorClosed}{door-closed}{free1}{145}{"F52A}
\__fontawesome_def_icon:nnnnn{\faDoorOpen}{door-open}{free1}{146}{"F52B}
\__fontawesome_def_icon:nnnnn{\faDove}{dove}{free1}{147}{"F4BA}
\__fontawesome_def_icon:nnnnn{\faDownLeftAndUpRightToCenter}{down-left-and-up-right-to-center}{free1}{148}{"F422}
\__fontawesome_def_icon:nnnnn{\faDownLong}{down-long}{free1}{149}{"F309}
\__fontawesome_def_icon:nnnnn{\faDownload}{download}{free1}{150}{"F019}
\__fontawesome_def_icon:nnnnn{}{draft2digital}{brands0}{127}{"F396}
\__fontawesome_def_icon:nnnnn{\faDragon}{dragon}{free1}{151}{"F6D5}
\__fontawesome_def_icon:nnnnn{\faDrawPolygon}{draw-polygon}{free1}{152}{"F5EE}
\__fontawesome_def_icon:nnnnn{\faDribbble}{dribbble}{brands0}{128}{"F17D}
\__fontawesome_def_icon:nnnnn{\faDropbox}{dropbox}{brands0}{129}{"F16B}
\__fontawesome_def_icon:nnnnn{\faDroplet}{droplet}{free1}{153}{"F043}
\__fontawesome_def_icon:nnnnn{\faDropletSlash}{droplet-slash}{free1}{154}{"F5C7}
\__fontawesome_def_icon:nnnnn{\faDrum}{drum}{free1}{155}{"F569}
\__fontawesome_def_icon:nnnnn{\faDrumSteelpan}{drum-steelpan}{free1}{156}{"F56A}
\__fontawesome_def_icon:nnnnn{\faDrumstickBite}{drumstick-bite}{free1}{157}{"F6D7}
\__fontawesome_def_icon:nnnnn{\faDrupal}{drupal}{brands0}{130}{"F1A9}
\__fontawesome_def_icon:nnnnn{\faDumbbell}{dumbbell}{free1}{158}{"F44B}
\__fontawesome_def_icon:nnnnn{\faDumpster}{dumpster}{free1}{159}{"F793}
\__fontawesome_def_icon:nnnnn{\faDumpsterFire}{dumpster-fire}{free1}{160}{"F794}
\__fontawesome_def_icon:nnnnn{\faDungeon}{dungeon}{free1}{161}{"F6D9}
\__fontawesome_def_icon:nnnnn{\faDyalog}{dyalog}{brands0}{131}{"F399}
\__fontawesome_def_icon:nnnnn{\faE}{e}{free1}{162}{"45}
\__fontawesome_def_icon:nnnnn{\faEarDeaf}{ear-deaf}{free1}{163}{"F2A4}
\__fontawesome_def_icon:nnnnn{\faEarListen}{ear-listen}{free1}{164}{"F2A2}
\__fontawesome_def_icon:nnnnn{\faEarlybirds}{earlybirds}{brands0}{133}{"F39A}
\__fontawesome_def_icon:nnnnn{\faEarthAfrica}{earth-africa}{free1}{165}{"F57C}
\__fontawesome_def_icon:nnnnn{\faEarthAmericas}{earth-americas}{free1}{166}{"F57D}
\__fontawesome_def_icon:nnnnn{\faEarthAsia}{earth-asia}{free1}{167}{"F57E}
\__fontawesome_def_icon:nnnnn{\faEarthEurope}{earth-europe}{free1}{168}{"F7A2}
\__fontawesome_def_icon:nnnnn{\faEarthOceania}{earth-oceania}{free1}{169}{"E47B}
\__fontawesome_def_icon:nnnnn{\faEbay}{ebay}{brands0}{134}{"F4F4}
\__fontawesome_def_icon:nnnnn{\faEdge}{edge}{brands0}{135}{"F282}
\__fontawesome_def_icon:nnnnn{\faEdgeLegacy}{edge-legacy}{brands0}{136}{"E078}
\__fontawesome_def_icon:nnnnn{\faEgg}{egg}{free1}{170}{"F7FB}
\__fontawesome_def_icon:nnnnn{\faEject}{eject}{free1}{171}{"F052}
\__fontawesome_def_icon:nnnnn{\faElementor}{elementor}{brands0}{137}{"F430}
\__fontawesome_def_icon:nnnnn{\faElevator}{elevator}{free1}{172}{"E16D}
\__fontawesome_def_icon:nnnnn{\faEllipsis}{ellipsis}{free1}{173}{"F141}
\__fontawesome_def_icon:nnnnn{\faEllipsisVertical}{ellipsis-vertical}{free1}{174}{"F142}
\__fontawesome_def_icon:nnnnn{\faEllo}{ello}{brands0}{138}{"F5F1}
\__fontawesome_def_icon:nnnnn{\faEmber}{ember}{brands0}{139}{"F423}
\__fontawesome_def_icon:nnnnn{\faEmpire}{empire}{brands0}{140}{"F1D1}
\__fontawesome_def_icon:nnnnn{\faEnvelope}{envelope}{free1}{175}{"F0E0}
\__fontawesome_def_icon:nnnnn{\faEnvelopeCircleCheck}{envelope-circle-check}{free1}{176}{"E4E8}
\__fontawesome_def_icon:nnnnn{\faEnvelopeOpen}{envelope-open}{free1}{177}{"F2B6}
\__fontawesome_def_icon:nnnnn{\faEnvelopeOpenText}{envelope-open-text}{free1}{178}{"F658}
\__fontawesome_def_icon:nnnnn{\faEnvelopesBulk}{envelopes-bulk}{free1}{179}{"F674}
\__fontawesome_def_icon:nnnnn{\faEnvira}{envira}{brands0}{141}{"F299}
\__fontawesome_def_icon:nnnnn{\faEquals}{equals}{free1}{180}{"3D}
\__fontawesome_def_icon:nnnnn{\faEraser}{eraser}{free1}{181}{"F12D}
\__fontawesome_def_icon:nnnnn{\faErlang}{erlang}{brands0}{143}{"F39D}
\__fontawesome_def_icon:nnnnn{\faEthereum}{ethereum}{brands0}{144}{"F42E}
\__fontawesome_def_icon:nnnnn{\faEthernet}{ethernet}{free1}{182}{"F796}
\__fontawesome_def_icon:nnnnn{\faEtsy}{etsy}{brands0}{145}{"F2D7}
\__fontawesome_def_icon:nnnnn{\faEuroSign}{euro-sign}{free1}{183}{"F153}
\__fontawesome_def_icon:nnnnn{\faEvernote}{evernote}{brands0}{146}{"F839}
\__fontawesome_def_icon:nnnnn{\faExclamation}{exclamation}{free1}{184}{"21}
\__fontawesome_def_icon:nnnnn{\faExpand}{expand}{free1}{185}{"F065}
\__fontawesome_def_icon:nnnnn{\faExpeditedssl}{expeditedssl}{brands0}{148}{"F23E}
\__fontawesome_def_icon:nnnnn{\faExplosion}{explosion}{free1}{186}{"E4E9}
\__fontawesome_def_icon:nnnnn{\faEye}{eye}{free1}{187}{"F06E}
\__fontawesome_def_icon:nnnnn{\faEyeDropper}{eye-dropper}{free1}{188}{"F1FB}
\__fontawesome_def_icon:nnnnn{\faEyeLowVision}{eye-low-vision}{free1}{189}{"F2A8}
\__fontawesome_def_icon:nnnnn{\faEyeSlash}{eye-slash}{free1}{190}{"F070}
\__fontawesome_def_icon:nnnnn{\faF}{f}{free1}{191}{"46}
\__fontawesome_def_icon:nnnnn{\faFaceAngry}{face-angry}{free1}{192}{"F556}
\__fontawesome_def_icon:nnnnn{\faFaceDizzy}{face-dizzy}{free1}{193}{"F567}
\__fontawesome_def_icon:nnnnn{\faFaceFlushed}{face-flushed}{free1}{194}{"F579}
\__fontawesome_def_icon:nnnnn{\faFaceFrown}{face-frown}{free1}{195}{"F119}
\__fontawesome_def_icon:nnnnn{\faFaceFrownOpen}{face-frown-open}{free1}{196}{"F57A}
\__fontawesome_def_icon:nnnnn{\faFaceGrimace}{face-grimace}{free1}{197}{"F57F}
\__fontawesome_def_icon:nnnnn{\faFaceGrin}{face-grin}{free1}{198}{"F580}
\__fontawesome_def_icon:nnnnn{\faFaceGrinBeam}{face-grin-beam}{free1}{199}{"F582}
\__fontawesome_def_icon:nnnnn{\faFaceGrinBeamSweat}{face-grin-beam-sweat}{free1}{200}{"F583}
\__fontawesome_def_icon:nnnnn{\faFaceGrinHearts}{face-grin-hearts}{free1}{201}{"F584}
\__fontawesome_def_icon:nnnnn{\faFaceGrinSquint}{face-grin-squint}{free1}{202}{"F585}
\__fontawesome_def_icon:nnnnn{\faFaceGrinSquintTears}{face-grin-squint-tears}{free1}{203}{"F586}
\__fontawesome_def_icon:nnnnn{\faFaceGrinStars}{face-grin-stars}{free1}{204}{"F587}
\__fontawesome_def_icon:nnnnn{\faFaceGrinTears}{face-grin-tears}{free1}{205}{"F588}
\__fontawesome_def_icon:nnnnn{\faFaceGrinTongue}{face-grin-tongue}{free1}{206}{"F589}
\__fontawesome_def_icon:nnnnn{\faFaceGrinTongueSquint}{face-grin-tongue-squint}{free1}{207}{"F58A}
\__fontawesome_def_icon:nnnnn{\faFaceGrinTongueWink}{face-grin-tongue-wink}{free1}{208}{"F58B}
\__fontawesome_def_icon:nnnnn{\faFaceGrinWide}{face-grin-wide}{free1}{209}{"F581}
\__fontawesome_def_icon:nnnnn{\faFaceGrinWink}{face-grin-wink}{free1}{210}{"F58C}
\__fontawesome_def_icon:nnnnn{\faFaceKiss}{face-kiss}{free1}{211}{"F596}
\__fontawesome_def_icon:nnnnn{\faFaceKissBeam}{face-kiss-beam}{free1}{212}{"F597}
\__fontawesome_def_icon:nnnnn{\faFaceKissWinkHeart}{face-kiss-wink-heart}{free1}{213}{"F598}
\__fontawesome_def_icon:nnnnn{\faFaceLaugh}{face-laugh}{free1}{214}{"F599}
\__fontawesome_def_icon:nnnnn{\faFaceLaughBeam}{face-laugh-beam}{free1}{215}{"F59A}
\__fontawesome_def_icon:nnnnn{\faFaceLaughSquint}{face-laugh-squint}{free1}{216}{"F59B}
\__fontawesome_def_icon:nnnnn{\faFaceLaughWink}{face-laugh-wink}{free1}{217}{"F59C}
\__fontawesome_def_icon:nnnnn{\faFaceMeh}{face-meh}{free1}{218}{"F11A}
\__fontawesome_def_icon:nnnnn{\faFaceMehBlank}{face-meh-blank}{free1}{219}{"F5A4}
\__fontawesome_def_icon:nnnnn{\faFaceRollingEyes}{face-rolling-eyes}{free1}{220}{"F5A5}
\__fontawesome_def_icon:nnnnn{\faFaceSadCry}{face-sad-cry}{free1}{221}{"F5B3}
\__fontawesome_def_icon:nnnnn{\faFaceSadTear}{face-sad-tear}{free1}{222}{"F5B4}
\__fontawesome_def_icon:nnnnn{\faFaceSmile}{face-smile}{free1}{223}{"F118}
\__fontawesome_def_icon:nnnnn{\faFaceSmileBeam}{face-smile-beam}{free1}{224}{"F5B8}
\__fontawesome_def_icon:nnnnn{\faFaceSmileWink}{face-smile-wink}{free1}{225}{"F4DA}
\__fontawesome_def_icon:nnnnn{\faFaceSurprise}{face-surprise}{free1}{226}{"F5C2}
\__fontawesome_def_icon:nnnnn{\faFaceTired}{face-tired}{free1}{227}{"F5C8}
\__fontawesome_def_icon:nnnnn{\faFacebook}{facebook}{brands0}{150}{"F09A}
\__fontawesome_def_icon:nnnnn{\faFacebookF}{facebook-f}{brands0}{151}{"F39E}
\__fontawesome_def_icon:nnnnn{\faFacebookMessenger}{facebook-messenger}{brands0}{152}{"F39F}
\__fontawesome_def_icon:nnnnn{\faFan}{fan}{free1}{228}{"F863}
\__fontawesome_def_icon:nnnnn{\faFantasyFlightGames}{fantasy-flight-games}{brands0}{153}{"F6DC}
\__fontawesome_def_icon:nnnnn{\faFaucet}{faucet}{free1}{229}{"E005}
\__fontawesome_def_icon:nnnnn{\faFaucetDrip}{faucet-drip}{free1}{230}{"E006}
\__fontawesome_def_icon:nnnnn{\faFax}{fax}{free1}{231}{"F1AC}
\__fontawesome_def_icon:nnnnn{\faFeather}{feather}{free1}{232}{"F52D}
\__fontawesome_def_icon:nnnnn{\faFeatherPointed}{feather-pointed}{free1}{233}{"F56B}
\__fontawesome_def_icon:nnnnn{\faFedex}{fedex}{brands0}{154}{"F797}
\__fontawesome_def_icon:nnnnn{\faFedora}{fedora}{brands0}{155}{"F798}
\__fontawesome_def_icon:nnnnn{\faFerry}{ferry}{free1}{234}{"E4EA}
\__fontawesome_def_icon:nnnnn{\faFigma}{figma}{brands0}{156}{"F799}
\__fontawesome_def_icon:nnnnn{\faFile}{file}{free1}{235}{"F15B}
\__fontawesome_def_icon:nnnnn{\faFileArrowDown}{file-arrow-down}{free1}{236}{"F56D}
\__fontawesome_def_icon:nnnnn{\faFileArrowUp}{file-arrow-up}{free1}{237}{"F574}
\__fontawesome_def_icon:nnnnn{\faFileAudio}{file-audio}{free1}{238}{"F1C7}
\__fontawesome_def_icon:nnnnn{\faFileCircleCheck}{file-circle-check}{free1}{239}{"E5A0}
\__fontawesome_def_icon:nnnnn{\faFileCircleExclamation}{file-circle-exclamation}{free1}{240}{"E4EB}
\__fontawesome_def_icon:nnnnn{\faFileCircleMinus}{file-circle-minus}{free1}{241}{"E4ED}
\__fontawesome_def_icon:nnnnn{\faFileCirclePlus}{file-circle-plus}{free1}{242}{"E494}
\__fontawesome_def_icon:nnnnn{\faFileCircleQuestion}{file-circle-question}{free1}{243}{"E4EF}
\__fontawesome_def_icon:nnnnn{\faFileCircleXmark}{file-circle-xmark}{free1}{244}{"E5A1}
\__fontawesome_def_icon:nnnnn{\faFileCode}{file-code}{free1}{245}{"F1C9}
\__fontawesome_def_icon:nnnnn{\faFileContract}{file-contract}{free1}{246}{"F56C}
\__fontawesome_def_icon:nnnnn{\faFileCsv}{file-csv}{free1}{247}{"F6DD}
\__fontawesome_def_icon:nnnnn{\faFileExcel}{file-excel}{free1}{248}{"F1C3}
\__fontawesome_def_icon:nnnnn{\faFileExport}{file-export}{free1}{249}{"F56E}
\__fontawesome_def_icon:nnnnn{\faFileFragment}{file-fragment}{free1}{250}{"E697}
\__fontawesome_def_icon:nnnnn{\faFileHalfDashed}{file-half-dashed}{free1}{251}{"E698}
\__fontawesome_def_icon:nnnnn{\faFileImage}{file-image}{free1}{252}{"F1C5}
\__fontawesome_def_icon:nnnnn{\faFileImport}{file-import}{free1}{253}{"F56F}
\__fontawesome_def_icon:nnnnn{\faFileInvoice}{file-invoice}{free1}{254}{"F570}
\__fontawesome_def_icon:nnnnn{\faFileInvoiceDollar}{file-invoice-dollar}{free1}{255}{"F571}
\__fontawesome_def_icon:nnnnn{\faFileLines}{file-lines}{free2}{0}{"F15C}
\__fontawesome_def_icon:nnnnn{\faFileMedical}{file-medical}{free2}{1}{"F477}
\__fontawesome_def_icon:nnnnn{\faFilePdf}{file-pdf}{free2}{2}{"F1C1}
\__fontawesome_def_icon:nnnnn{\faFilePen}{file-pen}{free2}{3}{"F31C}
\__fontawesome_def_icon:nnnnn{\faFilePowerpoint}{file-powerpoint}{free2}{4}{"F1C4}
\__fontawesome_def_icon:nnnnn{\faFilePrescription}{file-prescription}{free2}{5}{"F572}
\__fontawesome_def_icon:nnnnn{\faFileShield}{file-shield}{free2}{6}{"E4F0}
\__fontawesome_def_icon:nnnnn{\faFileSignature}{file-signature}{free2}{7}{"F573}
\__fontawesome_def_icon:nnnnn{\faFileVideo}{file-video}{free2}{8}{"F1C8}
\__fontawesome_def_icon:nnnnn{\faFileWaveform}{file-waveform}{free2}{9}{"F478}
\__fontawesome_def_icon:nnnnn{\faFileWord}{file-word}{free2}{10}{"F1C2}
\__fontawesome_def_icon:nnnnn{\faFileZipper}{file-zipper}{free2}{11}{"F1C6}
\__fontawesome_def_icon:nnnnn{\faFilesPinwheel}{files-pinwheel}{brands0}{157}{"E69F}
\__fontawesome_def_icon:nnnnn{\faFill}{fill}{free2}{12}{"F575}
\__fontawesome_def_icon:nnnnn{\faFillDrip}{fill-drip}{free2}{13}{"F576}
\__fontawesome_def_icon:nnnnn{\faFilm}{film}{free2}{14}{"F008}
\__fontawesome_def_icon:nnnnn{\faFilter}{filter}{free2}{15}{"F0B0}
\__fontawesome_def_icon:nnnnn{\faFilterCircleDollar}{filter-circle-dollar}{free2}{16}{"F662}
\__fontawesome_def_icon:nnnnn{\faFilterCircleXmark}{filter-circle-xmark}{free2}{17}{"E17B}
\__fontawesome_def_icon:nnnnn{\faFingerprint}{fingerprint}{free2}{18}{"F577}
\__fontawesome_def_icon:nnnnn{\faFire}{fire}{free2}{19}{"F06D}
\__fontawesome_def_icon:nnnnn{\faFireBurner}{fire-burner}{free2}{20}{"E4F1}
\__fontawesome_def_icon:nnnnn{\faFireExtinguisher}{fire-extinguisher}{free2}{21}{"F134}
\__fontawesome_def_icon:nnnnn{\faFireFlameCurved}{fire-flame-curved}{free2}{22}{"F7E4}
\__fontawesome_def_icon:nnnnn{\faFireFlameSimple}{fire-flame-simple}{free2}{23}{"F46A}
\__fontawesome_def_icon:nnnnn{\faFirefox}{firefox}{brands0}{158}{"F269}
\__fontawesome_def_icon:nnnnn{\faFirefoxBrowser}{firefox-browser}{brands0}{159}{"E007}
\__fontawesome_def_icon:nnnnn{\faFirstOrder}{first-order}{brands0}{160}{"F2B0}
\__fontawesome_def_icon:nnnnn{\faFirstOrderAlt}{first-order-alt}{brands0}{161}{"F50A}
\__fontawesome_def_icon:nnnnn{\faFirstdraft}{firstdraft}{brands0}{162}{"F3A1}
\__fontawesome_def_icon:nnnnn{\faFish}{fish}{free2}{24}{"F578}
\__fontawesome_def_icon:nnnnn{\faFishFins}{fish-fins}{free2}{25}{"E4F2}
\__fontawesome_def_icon:nnnnn{\faFlag}{flag}{free2}{26}{"F024}
\__fontawesome_def_icon:nnnnn{\faFlagCheckered}{flag-checkered}{free2}{27}{"F11E}
\__fontawesome_def_icon:nnnnn{\faFlagUsa}{flag-usa}{free2}{28}{"F74D}
\__fontawesome_def_icon:nnnnn{\faFlask}{flask}{free2}{29}{"F0C3}
\__fontawesome_def_icon:nnnnn{\faFlaskVial}{flask-vial}{free2}{30}{"E4F3}
\__fontawesome_def_icon:nnnnn{\faFlickr}{flickr}{brands0}{163}{"F16E}
\__fontawesome_def_icon:nnnnn{\faFlipboard}{flipboard}{brands0}{164}{"F44D}
\__fontawesome_def_icon:nnnnn{\faFloppyDisk}{floppy-disk}{free2}{31}{"F0C7}
\__fontawesome_def_icon:nnnnn{\faFlorinSign}{florin-sign}{free2}{32}{"E184}
\__fontawesome_def_icon:nnnnn{\faFlutter}{flutter}{brands0}{165}{"E694}
\__fontawesome_def_icon:nnnnn{\faFly}{fly}{brands0}{166}{"F417}
\__fontawesome_def_icon:nnnnn{\faFolder}{folder}{free2}{33}{"F07B}
\__fontawesome_def_icon:nnnnn{\faFolderClosed}{folder-closed}{free2}{34}{"E185}
\__fontawesome_def_icon:nnnnn{\faFolderMinus}{folder-minus}{free2}{35}{"F65D}
\__fontawesome_def_icon:nnnnn{\faFolderOpen}{folder-open}{free2}{36}{"F07C}
\__fontawesome_def_icon:nnnnn{\faFolderPlus}{folder-plus}{free2}{37}{"F65E}
\__fontawesome_def_icon:nnnnn{\faFolderTree}{folder-tree}{free2}{38}{"F802}
\__fontawesome_def_icon:nnnnn{\faFont}{font}{free2}{39}{"F031}
\__fontawesome_def_icon:nnnnn{\faFontAwesome}{font-awesome}{free2}{40}{"F2B4}
\__fontawesome_def_icon:nnnnn{\faFonticons}{fonticons}{brands0}{168}{"F280}
\__fontawesome_def_icon:nnnnn{\faFonticonsFi}{fonticons-fi}{brands0}{169}{"F3A2}
\__fontawesome_def_icon:nnnnn{\faFootball}{football}{free2}{41}{"F44E}
\__fontawesome_def_icon:nnnnn{\faFortAwesome}{fort-awesome}{brands0}{170}{"F286}
\__fontawesome_def_icon:nnnnn{\faFortAwesomeAlt}{fort-awesome-alt}{brands0}{171}{"F3A3}
\__fontawesome_def_icon:nnnnn{\faForumbee}{forumbee}{brands0}{172}{"F211}
\__fontawesome_def_icon:nnnnn{\faForward}{forward}{free2}{42}{"F04E}
\__fontawesome_def_icon:nnnnn{\faForwardFast}{forward-fast}{free2}{43}{"F050}
\__fontawesome_def_icon:nnnnn{\faForwardStep}{forward-step}{free2}{44}{"F051}
\__fontawesome_def_icon:nnnnn{\faFoursquare}{foursquare}{brands0}{173}{"F180}
\__fontawesome_def_icon:nnnnn{\faFrancSign}{franc-sign}{free2}{45}{"E18F}
\__fontawesome_def_icon:nnnnn{\faFreeCodeCamp}{free-code-camp}{brands0}{174}{"F2C5}
\__fontawesome_def_icon:nnnnn{\faFreebsd}{freebsd}{brands0}{175}{"F3A4}
\__fontawesome_def_icon:nnnnn{\faFrog}{frog}{free2}{46}{"F52E}
\__fontawesome_def_icon:nnnnn{\faFulcrum}{fulcrum}{brands0}{176}{"F50B}
\__fontawesome_def_icon:nnnnn{\faFutbol}{futbol}{free2}{47}{"F1E3}
\__fontawesome_def_icon:nnnnn{\faG}{g}{free2}{48}{"47}
\__fontawesome_def_icon:nnnnn{\faGalacticRepublic}{galactic-republic}{brands0}{178}{"F50C}
\__fontawesome_def_icon:nnnnn{\faGalacticSenate}{galactic-senate}{brands0}{179}{"F50D}
\__fontawesome_def_icon:nnnnn{\faGamepad}{gamepad}{free2}{49}{"F11B}
\__fontawesome_def_icon:nnnnn{\faGasPump}{gas-pump}{free2}{50}{"F52F}
\__fontawesome_def_icon:nnnnn{\faGauge}{gauge}{free2}{51}{"F624}
\__fontawesome_def_icon:nnnnn{\faGaugeHigh}{gauge-high}{free2}{52}{"F625}
\__fontawesome_def_icon:nnnnn{\faGaugeSimple}{gauge-simple}{free2}{53}{"F629}
\__fontawesome_def_icon:nnnnn{\faGaugeSimpleHigh}{gauge-simple-high}{free2}{54}{"F62A}
\__fontawesome_def_icon:nnnnn{\faGavel}{gavel}{free2}{55}{"F0E3}
\__fontawesome_def_icon:nnnnn{\faGear}{gear}{free2}{56}{"F013}
\__fontawesome_def_icon:nnnnn{\faGears}{gears}{free2}{57}{"F085}
\__fontawesome_def_icon:nnnnn{\faGem}{gem}{free2}{58}{"F3A5}
\__fontawesome_def_icon:nnnnn{\faGenderless}{genderless}{free2}{59}{"F22D}
\__fontawesome_def_icon:nnnnn{\faGetPocket}{get-pocket}{brands0}{180}{"F265}
\__fontawesome_def_icon:nnnnn{\faGg}{gg}{brands0}{181}{"F260}
\__fontawesome_def_icon:nnnnn{\faGgCircle}{gg-circle}{brands0}{182}{"F261}
\__fontawesome_def_icon:nnnnn{\faGhost}{ghost}{free2}{60}{"F6E2}
\__fontawesome_def_icon:nnnnn{\faGift}{gift}{free2}{61}{"F06B}
\__fontawesome_def_icon:nnnnn{\faGifts}{gifts}{free2}{62}{"F79C}
\__fontawesome_def_icon:nnnnn{\faGit}{git}{brands0}{183}{"F1D3}
\__fontawesome_def_icon:nnnnn{\faGitAlt}{git-alt}{brands0}{184}{"F841}
\__fontawesome_def_icon:nnnnn{\faGithub}{github}{brands0}{185}{"F09B}
\__fontawesome_def_icon:nnnnn{\faGithubAlt}{github-alt}{brands0}{186}{"F113}
\__fontawesome_def_icon:nnnnn{\faGitkraken}{gitkraken}{brands0}{187}{"F3A6}
\__fontawesome_def_icon:nnnnn{\faGitlab}{gitlab}{brands0}{188}{"F296}
\__fontawesome_def_icon:nnnnn{\faGitter}{gitter}{brands0}{189}{"F426}
\__fontawesome_def_icon:nnnnn{\faGlassWater}{glass-water}{free2}{63}{"E4F4}
\__fontawesome_def_icon:nnnnn{\faGlassWaterDroplet}{glass-water-droplet}{free2}{64}{"E4F5}
\__fontawesome_def_icon:nnnnn{\faGlasses}{glasses}{free2}{65}{"F530}
\__fontawesome_def_icon:nnnnn{\faGlide}{glide}{brands0}{190}{"F2A5}
\__fontawesome_def_icon:nnnnn{\faGlideG}{glide-g}{brands0}{191}{"F2A6}
\__fontawesome_def_icon:nnnnn{\faGlobe}{globe}{free2}{66}{"F0AC}
\__fontawesome_def_icon:nnnnn{\faGofore}{gofore}{brands0}{192}{"F3A7}
\__fontawesome_def_icon:nnnnn{\faGolang}{golang}{brands0}{193}{"E40F}
\__fontawesome_def_icon:nnnnn{\faGolfBallTee}{golf-ball-tee}{free2}{67}{"F450}
\__fontawesome_def_icon:nnnnn{\faGoodreads}{goodreads}{brands0}{194}{"F3A8}
\__fontawesome_def_icon:nnnnn{\faGoodreadsG}{goodreads-g}{brands0}{195}{"F3A9}
\__fontawesome_def_icon:nnnnn{\faGoogle}{google}{brands0}{196}{"F1A0}
\__fontawesome_def_icon:nnnnn{\faGoogleDrive}{google-drive}{brands0}{197}{"F3AA}
\__fontawesome_def_icon:nnnnn{\faGooglePay}{google-pay}{brands0}{198}{"E079}
\__fontawesome_def_icon:nnnnn{\faGooglePlay}{google-play}{brands0}{199}{"F3AB}
\__fontawesome_def_icon:nnnnn{\faGooglePlus}{google-plus}{brands0}{200}{"F2B3}
\__fontawesome_def_icon:nnnnn{\faGooglePlusG}{google-plus-g}{brands0}{201}{"F0D5}
\__fontawesome_def_icon:nnnnn{\faGoogleScholar}{google-scholar}{brands0}{202}{"E63B}
\__fontawesome_def_icon:nnnnn{\faGoogleWallet}{google-wallet}{brands0}{203}{"F1EE}
\__fontawesome_def_icon:nnnnn{\faGopuram}{gopuram}{free2}{68}{"F664}
\__fontawesome_def_icon:nnnnn{\faGraduationCap}{graduation-cap}{free2}{69}{"F19D}
\__fontawesome_def_icon:nnnnn{\faGratipay}{gratipay}{brands0}{204}{"F184}
\__fontawesome_def_icon:nnnnn{\faGrav}{grav}{brands0}{205}{"F2D6}
\__fontawesome_def_icon:nnnnn{\faGreaterThan}{greater-than}{free2}{70}{"3E}
\__fontawesome_def_icon:nnnnn{\faGreaterThanEqual}{greater-than-equal}{free2}{71}{"F532}
\__fontawesome_def_icon:nnnnn{\faGrip}{grip}{free2}{72}{"F58D}
\__fontawesome_def_icon:nnnnn{\faGripLines}{grip-lines}{free2}{73}{"F7A4}
\__fontawesome_def_icon:nnnnn{\faGripLinesVertical}{grip-lines-vertical}{free2}{74}{"F7A5}
\__fontawesome_def_icon:nnnnn{\faGripVertical}{grip-vertical}{free2}{75}{"F58E}
\__fontawesome_def_icon:nnnnn{\faGripfire}{gripfire}{brands0}{207}{"F3AC}
\__fontawesome_def_icon:nnnnn{\faGroupArrowsRotate}{group-arrows-rotate}{free2}{76}{"E4F6}
\__fontawesome_def_icon:nnnnn{\faGrunt}{grunt}{brands0}{208}{"F3AD}
\__fontawesome_def_icon:nnnnn{\faGuaraniSign}{guarani-sign}{free2}{77}{"E19A}
\__fontawesome_def_icon:nnnnn{\faGuilded}{guilded}{brands0}{209}{"E07E}
\__fontawesome_def_icon:nnnnn{\faGuitar}{guitar}{free2}{78}{"F7A6}
\__fontawesome_def_icon:nnnnn{\faGulp}{gulp}{brands0}{210}{"F3AE}
\__fontawesome_def_icon:nnnnn{\faGun}{gun}{free2}{79}{"E19B}
\__fontawesome_def_icon:nnnnn{\faH}{h}{free2}{80}{"48}
\__fontawesome_def_icon:nnnnn{\faHackerNews}{hacker-news}{brands0}{212}{"F1D4}
\__fontawesome_def_icon:nnnnn{\faHackerrank}{hackerrank}{brands0}{213}{"F5F7}
\__fontawesome_def_icon:nnnnn{\faHammer}{hammer}{free2}{81}{"F6E3}
\__fontawesome_def_icon:nnnnn{\faHamsa}{hamsa}{free2}{82}{"F665}
\__fontawesome_def_icon:nnnnn{\faHand}{hand}{free2}{83}{"F256}
\__fontawesome_def_icon:nnnnn{\faHandBackFist}{hand-back-fist}{free2}{84}{"F255}
\__fontawesome_def_icon:nnnnn{\faHandDots}{hand-dots}{free2}{85}{"F461}
\__fontawesome_def_icon:nnnnn{\faHandFist}{hand-fist}{free2}{86}{"F6DE}
\__fontawesome_def_icon:nnnnn{\faHandHolding}{hand-holding}{free2}{87}{"F4BD}
\__fontawesome_def_icon:nnnnn{\faHandHoldingDollar}{hand-holding-dollar}{free2}{88}{"F4C0}
\__fontawesome_def_icon:nnnnn{\faHandHoldingDroplet}{hand-holding-droplet}{free2}{89}{"F4C1}
\__fontawesome_def_icon:nnnnn{\faHandHoldingHand}{hand-holding-hand}{free2}{90}{"E4F7}
\__fontawesome_def_icon:nnnnn{\faHandHoldingHeart}{hand-holding-heart}{free2}{91}{"F4BE}
\__fontawesome_def_icon:nnnnn{\faHandHoldingMedical}{hand-holding-medical}{free2}{92}{"E05C}
\__fontawesome_def_icon:nnnnn{\faHandLizard}{hand-lizard}{free2}{93}{"F258}
\__fontawesome_def_icon:nnnnn{\faHandMiddleFinger}{hand-middle-finger}{free2}{94}{"F806}
\__fontawesome_def_icon:nnnnn{\faHandPeace}{hand-peace}{free2}{95}{"F25B}
\__fontawesome_def_icon:nnnnn{\faHandPointDown}{hand-point-down}{free2}{96}{"F0A7}
\__fontawesome_def_icon:nnnnn{\faHandPointLeft}{hand-point-left}{free2}{97}{"F0A5}
\__fontawesome_def_icon:nnnnn{\faHandPointRight}{hand-point-right}{free2}{98}{"F0A4}
\__fontawesome_def_icon:nnnnn{\faHandPointUp}{hand-point-up}{free2}{99}{"F0A6}
\__fontawesome_def_icon:nnnnn{\faHandPointer}{hand-pointer}{free2}{100}{"F25A}
\__fontawesome_def_icon:nnnnn{\faHandScissors}{hand-scissors}{free2}{101}{"F257}
\__fontawesome_def_icon:nnnnn{\faHandSparkles}{hand-sparkles}{free2}{102}{"E05D}
\__fontawesome_def_icon:nnnnn{\faHandSpock}{hand-spock}{free2}{103}{"F259}
\__fontawesome_def_icon:nnnnn{\faHandcuffs}{handcuffs}{free2}{104}{"E4F8}
\__fontawesome_def_icon:nnnnn{\faHands}{hands}{free2}{105}{"F2A7}
\__fontawesome_def_icon:nnnnn{\faHandsAslInterpreting}{hands-asl-interpreting}{free2}{106}{"F2A3}
\__fontawesome_def_icon:nnnnn{\faHandsBound}{hands-bound}{free2}{107}{"E4F9}
\__fontawesome_def_icon:nnnnn{\faHandsBubbles}{hands-bubbles}{free2}{108}{"E05E}
\__fontawesome_def_icon:nnnnn{\faHandsClapping}{hands-clapping}{free2}{109}{"E1A8}
\__fontawesome_def_icon:nnnnn{\faHandsHolding}{hands-holding}{free2}{110}{"F4C2}
\__fontawesome_def_icon:nnnnn{\faHandsHoldingChild}{hands-holding-child}{free2}{111}{"E4FA}
\__fontawesome_def_icon:nnnnn{\faHandsHoldingCircle}{hands-holding-circle}{free2}{112}{"E4FB}
\__fontawesome_def_icon:nnnnn{\faHandsPraying}{hands-praying}{free2}{113}{"F684}
\__fontawesome_def_icon:nnnnn{\faHandshake}{handshake}{free2}{114}{"F2B5}
\__fontawesome_def_icon:nnnnn{\faHandshakeAngle}{handshake-angle}{free2}{115}{"F4C4}
\__fontawesome_def_icon:nnnnn{\faHandshakeSimple}{handshake-simple}{free2}{116}{"F4C6}
\__fontawesome_def_icon:nnnnn{\faHandshakeSimpleSlash}{handshake-simple-slash}{free2}{117}{"E05F}
\__fontawesome_def_icon:nnnnn{\faHandshakeSlash}{handshake-slash}{free2}{118}{"E060}
\__fontawesome_def_icon:nnnnn{\faHanukiah}{hanukiah}{free2}{119}{"F6E6}
\__fontawesome_def_icon:nnnnn{\faHardDrive}{hard-drive}{free2}{120}{"F0A0}
\__fontawesome_def_icon:nnnnn{\faHashnode}{hashnode}{brands0}{214}{"E499}
\__fontawesome_def_icon:nnnnn{\faHashtag}{hashtag}{free2}{121}{"23}
\__fontawesome_def_icon:nnnnn{\faHatCowboy}{hat-cowboy}{free2}{122}{"F8C0}
\__fontawesome_def_icon:nnnnn{\faHatCowboySide}{hat-cowboy-side}{free2}{123}{"F8C1}
\__fontawesome_def_icon:nnnnn{\faHatWizard}{hat-wizard}{free2}{124}{"F6E8}
\__fontawesome_def_icon:nnnnn{\faHeadSideCough}{head-side-cough}{free2}{125}{"E061}
\__fontawesome_def_icon:nnnnn{\faHeadSideCoughSlash}{head-side-cough-slash}{free2}{126}{"E062}
\__fontawesome_def_icon:nnnnn{\faHeadSideMask}{head-side-mask}{free2}{127}{"E063}
\__fontawesome_def_icon:nnnnn{\faHeadSideVirus}{head-side-virus}{free2}{128}{"E064}
\__fontawesome_def_icon:nnnnn{\faHeading}{heading}{free2}{129}{"F1DC}
\__fontawesome_def_icon:nnnnn{\faHeadphones}{headphones}{free2}{130}{"F025}
\__fontawesome_def_icon:nnnnn{\faHeadphonesSimple}{headphones-simple}{free2}{131}{"F58F}
\__fontawesome_def_icon:nnnnn{\faHeadset}{headset}{free2}{132}{"F590}
\__fontawesome_def_icon:nnnnn{\faHeart}{heart}{free2}{133}{"F004}
\__fontawesome_def_icon:nnnnn{\faHeartCircleBolt}{heart-circle-bolt}{free2}{134}{"E4FC}
\__fontawesome_def_icon:nnnnn{\faHeartCircleCheck}{heart-circle-check}{free2}{135}{"E4FD}
\__fontawesome_def_icon:nnnnn{\faHeartCircleExclamation}{heart-circle-exclamation}{free2}{136}{"E4FE}
\__fontawesome_def_icon:nnnnn{\faHeartCircleMinus}{heart-circle-minus}{free2}{137}{"E4FF}
\__fontawesome_def_icon:nnnnn{\faHeartCirclePlus}{heart-circle-plus}{free2}{138}{"E500}
\__fontawesome_def_icon:nnnnn{\faHeartCircleXmark}{heart-circle-xmark}{free2}{139}{"E501}
\__fontawesome_def_icon:nnnnn{\faHeartCrack}{heart-crack}{free2}{140}{"F7A9}
\__fontawesome_def_icon:nnnnn{\faHeartPulse}{heart-pulse}{free2}{141}{"F21E}
\__fontawesome_def_icon:nnnnn{\faHelicopter}{helicopter}{free2}{142}{"F533}
\__fontawesome_def_icon:nnnnn{\faHelicopterSymbol}{helicopter-symbol}{free2}{143}{"E502}
\__fontawesome_def_icon:nnnnn{\faHelmetSafety}{helmet-safety}{free2}{144}{"F807}
\__fontawesome_def_icon:nnnnn{\faHelmetUn}{helmet-un}{free2}{145}{"E503}
\__fontawesome_def_icon:nnnnn{\faHexagonNodes}{hexagon-nodes}{free2}{146}{"E699}
\__fontawesome_def_icon:nnnnn{\faHexagonNodesBolt}{hexagon-nodes-bolt}{free2}{147}{"E69A}
\__fontawesome_def_icon:nnnnn{\faHighlighter}{highlighter}{free2}{148}{"F591}
\__fontawesome_def_icon:nnnnn{\faHillAvalanche}{hill-avalanche}{free2}{149}{"E507}
\__fontawesome_def_icon:nnnnn{\faHillRockslide}{hill-rockslide}{free2}{150}{"E508}
\__fontawesome_def_icon:nnnnn{\faHippo}{hippo}{free2}{151}{"F6ED}
\__fontawesome_def_icon:nnnnn{\faHips}{hips}{brands0}{216}{"F452}
\__fontawesome_def_icon:nnnnn{\faHireAHelper}{hire-a-helper}{brands0}{217}{"F3B0}
\__fontawesome_def_icon:nnnnn{\faHive}{hive}{brands0}{218}{"E07F}
\__fontawesome_def_icon:nnnnn{\faHockeyPuck}{hockey-puck}{free2}{152}{"F453}
\__fontawesome_def_icon:nnnnn{\faHollyBerry}{holly-berry}{free2}{153}{"F7AA}
\__fontawesome_def_icon:nnnnn{\faHooli}{hooli}{brands0}{219}{"F427}
\__fontawesome_def_icon:nnnnn{\faHornbill}{hornbill}{brands0}{220}{"F592}
\__fontawesome_def_icon:nnnnn{\faHorse}{horse}{free2}{154}{"F6F0}
\__fontawesome_def_icon:nnnnn{\faHorseHead}{horse-head}{free2}{155}{"F7AB}
\__fontawesome_def_icon:nnnnn{\faHospital}{hospital}{free2}{156}{"F0F8}
\__fontawesome_def_icon:nnnnn{\faHospitalUser}{hospital-user}{free2}{157}{"F80D}
\__fontawesome_def_icon:nnnnn{\faHotTubPerson}{hot-tub-person}{free2}{158}{"F593}
\__fontawesome_def_icon:nnnnn{\faHotdog}{hotdog}{free2}{159}{"F80F}
\__fontawesome_def_icon:nnnnn{\faHotel}{hotel}{free2}{160}{"F594}
\__fontawesome_def_icon:nnnnn{\faHotjar}{hotjar}{brands0}{221}{"F3B1}
\__fontawesome_def_icon:nnnnn{\faHourglass}{hourglass}{free2}{161}{"F254}
\__fontawesome_def_icon:nnnnn{\faHourglassEnd}{hourglass-end}{free2}{162}{"F253}
\__fontawesome_def_icon:nnnnn{\faHourglassHalf}{hourglass-half}{free2}{163}{"F252}
\__fontawesome_def_icon:nnnnn{\faHourglassStart}{hourglass-start}{free2}{164}{"F251}
\__fontawesome_def_icon:nnnnn{\faHouse}{house}{free2}{165}{"F015}
\__fontawesome_def_icon:nnnnn{\faHouseChimney}{house-chimney}{free2}{166}{"E3AF}
\__fontawesome_def_icon:nnnnn{\faHouseChimneyCrack}{house-chimney-crack}{free2}{167}{"F6F1}
\__fontawesome_def_icon:nnnnn{\faHouseChimneyMedical}{house-chimney-medical}{free2}{168}{"F7F2}
\__fontawesome_def_icon:nnnnn{\faHouseChimneyUser}{house-chimney-user}{free2}{169}{"E065}
\__fontawesome_def_icon:nnnnn{\faHouseChimneyWindow}{house-chimney-window}{free2}{170}{"E00D}
\__fontawesome_def_icon:nnnnn{\faHouseCircleCheck}{house-circle-check}{free2}{171}{"E509}
\__fontawesome_def_icon:nnnnn{\faHouseCircleExclamation}{house-circle-exclamation}{free2}{172}{"E50A}
\__fontawesome_def_icon:nnnnn{\faHouseCircleXmark}{house-circle-xmark}{free2}{173}{"E50B}
\__fontawesome_def_icon:nnnnn{\faHouseCrack}{house-crack}{free2}{174}{"E3B1}
\__fontawesome_def_icon:nnnnn{\faHouseFire}{house-fire}{free2}{175}{"E50C}
\__fontawesome_def_icon:nnnnn{\faHouseFlag}{house-flag}{free2}{176}{"E50D}
\__fontawesome_def_icon:nnnnn{\faHouseFloodWater}{house-flood-water}{free2}{177}{"E50E}
\__fontawesome_def_icon:nnnnn{\faHouseFloodWaterCircleArrowRight}{house-flood-water-circle-arrow-right}{free2}{178}{"E50F}
\__fontawesome_def_icon:nnnnn{\faHouseLaptop}{house-laptop}{free2}{179}{"E066}
\__fontawesome_def_icon:nnnnn{\faHouseLock}{house-lock}{free2}{180}{"E510}
\__fontawesome_def_icon:nnnnn{\faHouseMedical}{house-medical}{free2}{181}{"E3B2}
\__fontawesome_def_icon:nnnnn{\faHouseMedicalCircleCheck}{house-medical-circle-check}{free2}{182}{"E511}
\__fontawesome_def_icon:nnnnn{\faHouseMedicalCircleExclamation}{house-medical-circle-exclamation}{free2}{183}{"E512}
\__fontawesome_def_icon:nnnnn{\faHouseMedicalCircleXmark}{house-medical-circle-xmark}{free2}{184}{"E513}
\__fontawesome_def_icon:nnnnn{\faHouseMedicalFlag}{house-medical-flag}{free2}{185}{"E514}
\__fontawesome_def_icon:nnnnn{\faHouseSignal}{house-signal}{free2}{186}{"E012}
\__fontawesome_def_icon:nnnnn{\faHouseTsunami}{house-tsunami}{free2}{187}{"E515}
\__fontawesome_def_icon:nnnnn{\faHouseUser}{house-user}{free2}{188}{"E1B0}
\__fontawesome_def_icon:nnnnn{\faHouzz}{houzz}{brands0}{222}{"F27C}
\__fontawesome_def_icon:nnnnn{\faHryvniaSign}{hryvnia-sign}{free2}{189}{"F6F2}
\__fontawesome_def_icon:nnnnn{}{html5}{brands0}{223}{"F13B}
\__fontawesome_def_icon:nnnnn{\faHubspot}{hubspot}{brands0}{224}{"F3B2}
\__fontawesome_def_icon:nnnnn{\faHurricane}{hurricane}{free2}{190}{"F751}
\__fontawesome_def_icon:nnnnn{\faI}{i}{free2}{192}{"49}
\__fontawesome_def_icon:nnnnn{\faICursor}{i-cursor}{free2}{193}{"F246}
\__fontawesome_def_icon:nnnnn{\faIceCream}{ice-cream}{free2}{194}{"F810}
\__fontawesome_def_icon:nnnnn{\faIcicles}{icicles}{free2}{195}{"F7AD}
\__fontawesome_def_icon:nnnnn{\faIcons}{icons}{free2}{196}{"F86D}
\__fontawesome_def_icon:nnnnn{\faIdBadge}{id-badge}{free2}{197}{"F2C1}
\__fontawesome_def_icon:nnnnn{\faIdCard}{id-card}{free2}{198}{"F2C2}
\__fontawesome_def_icon:nnnnn{\faIdCardClip}{id-card-clip}{free2}{199}{"F47F}
\__fontawesome_def_icon:nnnnn{\faIdeal}{ideal}{brands0}{227}{"E013}
\__fontawesome_def_icon:nnnnn{\faIgloo}{igloo}{free2}{200}{"F7AE}
\__fontawesome_def_icon:nnnnn{\faImage}{image}{free2}{201}{"F03E}
\__fontawesome_def_icon:nnnnn{\faImagePortrait}{image-portrait}{free2}{202}{"F3E0}
\__fontawesome_def_icon:nnnnn{\faImages}{images}{free2}{203}{"F302}
\__fontawesome_def_icon:nnnnn{\faImdb}{imdb}{brands0}{228}{"F2D8}
\__fontawesome_def_icon:nnnnn{\faInbox}{inbox}{free2}{204}{"F01C}
\__fontawesome_def_icon:nnnnn{\faIndent}{indent}{free2}{205}{"F03C}
\__fontawesome_def_icon:nnnnn{\faIndianRupeeSign}{indian-rupee-sign}{free2}{206}{"E1BC}
\__fontawesome_def_icon:nnnnn{\faIndustry}{industry}{free2}{207}{"F275}
\__fontawesome_def_icon:nnnnn{\faInfinity}{infinity}{free2}{208}{"F534}
\__fontawesome_def_icon:nnnnn{\faInfo}{info}{free2}{209}{"F129}
\__fontawesome_def_icon:nnnnn{\faInstagram}{instagram}{brands0}{229}{"F16D}
\__fontawesome_def_icon:nnnnn{\faInstalod}{instalod}{brands0}{230}{"E081}
\__fontawesome_def_icon:nnnnn{\faIntercom}{intercom}{brands0}{231}{"F7AF}
\__fontawesome_def_icon:nnnnn{\faInternetExplorer}{internet-explorer}{brands0}{232}{"F26B}
\__fontawesome_def_icon:nnnnn{\faInvision}{invision}{brands0}{233}{"F7B0}
\__fontawesome_def_icon:nnnnn{\faIoxhost}{ioxhost}{brands0}{234}{"F208}
\__fontawesome_def_icon:nnnnn{\faItalic}{italic}{free2}{210}{"F033}
\__fontawesome_def_icon:nnnnn{\faItchIo}{itch-io}{brands0}{235}{"F83A}
\__fontawesome_def_icon:nnnnn{\faItunes}{itunes}{brands0}{236}{"F3B4}
\__fontawesome_def_icon:nnnnn{\faItunesNote}{itunes-note}{brands0}{237}{"F3B5}
\__fontawesome_def_icon:nnnnn{\faJ}{j}{free2}{211}{"4A}
\__fontawesome_def_icon:nnnnn{\faJar}{jar}{free2}{212}{"E516}
\__fontawesome_def_icon:nnnnn{\faJarWheat}{jar-wheat}{free2}{213}{"E517}
\__fontawesome_def_icon:nnnnn{\faJava}{java}{brands0}{239}{"F4E4}
\__fontawesome_def_icon:nnnnn{\faJedi}{jedi}{free2}{214}{"F669}
\__fontawesome_def_icon:nnnnn{\faJediOrder}{jedi-order}{brands0}{240}{"F50E}
\__fontawesome_def_icon:nnnnn{\faJenkins}{jenkins}{brands0}{241}{"F3B6}
\__fontawesome_def_icon:nnnnn{\faJetFighter}{jet-fighter}{free2}{215}{"F0FB}
\__fontawesome_def_icon:nnnnn{\faJetFighterUp}{jet-fighter-up}{free2}{216}{"E518}
\__fontawesome_def_icon:nnnnn{\faJira}{jira}{brands0}{242}{"F7B1}
\__fontawesome_def_icon:nnnnn{\faJoget}{joget}{brands0}{243}{"F3B7}
\__fontawesome_def_icon:nnnnn{\faJoint}{joint}{free2}{217}{"F595}
\__fontawesome_def_icon:nnnnn{\faJoomla}{joomla}{brands0}{244}{"F1AA}
\__fontawesome_def_icon:nnnnn{\faJs}{js}{brands0}{245}{"F3B8}
\__fontawesome_def_icon:nnnnn{\faJsfiddle}{jsfiddle}{brands0}{246}{"F1CC}
\__fontawesome_def_icon:nnnnn{\faJugDetergent}{jug-detergent}{free2}{218}{"E519}
\__fontawesome_def_icon:nnnnn{\faJxl}{jxl}{brands0}{247}{"E67B}
\__fontawesome_def_icon:nnnnn{\faK}{k}{free2}{219}{"4B}
\__fontawesome_def_icon:nnnnn{\faKaaba}{kaaba}{free2}{220}{"F66B}
\__fontawesome_def_icon:nnnnn{\faKaggle}{kaggle}{brands0}{249}{"F5FA}
\__fontawesome_def_icon:nnnnn{\faKey}{key}{free2}{221}{"F084}
\__fontawesome_def_icon:nnnnn{\faKeybase}{keybase}{brands0}{250}{"F4F5}
\__fontawesome_def_icon:nnnnn{\faKeyboard}{keyboard}{free2}{222}{"F11C}
\__fontawesome_def_icon:nnnnn{\faKeycdn}{keycdn}{brands0}{251}{"F3BA}
\__fontawesome_def_icon:nnnnn{\faKhanda}{khanda}{free2}{223}{"F66D}
\__fontawesome_def_icon:nnnnn{\faKickstarter}{kickstarter}{brands0}{252}{"F3BB}
\__fontawesome_def_icon:nnnnn{\faKickstarterK}{kickstarter-k}{brands0}{253}{"F3BC}
\__fontawesome_def_icon:nnnnn{\faKipSign}{kip-sign}{free2}{224}{"E1C4}
\__fontawesome_def_icon:nnnnn{\faKitMedical}{kit-medical}{free2}{225}{"F479}
\__fontawesome_def_icon:nnnnn{\faKitchenSet}{kitchen-set}{free2}{226}{"E51A}
\__fontawesome_def_icon:nnnnn{\faKiwiBird}{kiwi-bird}{free2}{227}{"F535}
\__fontawesome_def_icon:nnnnn{\faKorvue}{korvue}{brands0}{254}{"F42F}
\__fontawesome_def_icon:nnnnn{\faL}{l}{free2}{228}{"4C}
\__fontawesome_def_icon:nnnnn{\faLandMineOn}{land-mine-on}{free2}{229}{"E51B}
\__fontawesome_def_icon:nnnnn{\faLandmark}{landmark}{free2}{230}{"F66F}
\__fontawesome_def_icon:nnnnn{\faLandmarkDome}{landmark-dome}{free2}{231}{"F752}
\__fontawesome_def_icon:nnnnn{\faLandmarkFlag}{landmark-flag}{free2}{232}{"E51C}
\__fontawesome_def_icon:nnnnn{\faLanguage}{language}{free2}{233}{"F1AB}
\__fontawesome_def_icon:nnnnn{\faLaptop}{laptop}{free2}{234}{"F109}
\__fontawesome_def_icon:nnnnn{\faLaptopCode}{laptop-code}{free2}{235}{"F5FC}
\__fontawesome_def_icon:nnnnn{\faLaptopFile}{laptop-file}{free2}{236}{"E51D}
\__fontawesome_def_icon:nnnnn{\faLaptopMedical}{laptop-medical}{free2}{237}{"F812}
\__fontawesome_def_icon:nnnnn{\faLaravel}{laravel}{brands1}{0}{"F3BD}
\__fontawesome_def_icon:nnnnn{\faLariSign}{lari-sign}{free2}{238}{"E1C8}
\__fontawesome_def_icon:nnnnn{\faLastfm}{lastfm}{brands1}{1}{"F202}
\__fontawesome_def_icon:nnnnn{\faLayerGroup}{layer-group}{free2}{239}{"F5FD}
\__fontawesome_def_icon:nnnnn{\faLeaf}{leaf}{free2}{240}{"F06C}
\__fontawesome_def_icon:nnnnn{\faLeanpub}{leanpub}{brands1}{2}{"F212}
\__fontawesome_def_icon:nnnnn{\faLeftLong}{left-long}{free2}{241}{"F30A}
\__fontawesome_def_icon:nnnnn{\faLeftRight}{left-right}{free2}{242}{"F337}
\__fontawesome_def_icon:nnnnn{\faLemon}{lemon}{free2}{243}{"F094}
\__fontawesome_def_icon:nnnnn{\faLess}{less}{brands1}{3}{"F41D}
\__fontawesome_def_icon:nnnnn{\faLessThan}{less-than}{free2}{244}{"3C}
\__fontawesome_def_icon:nnnnn{\faLessThanEqual}{less-than-equal}{free2}{245}{"F537}
\__fontawesome_def_icon:nnnnn{\faLetterboxd}{letterboxd}{brands1}{5}{"E62D}
\__fontawesome_def_icon:nnnnn{\faLifeRing}{life-ring}{free2}{246}{"F1CD}
\__fontawesome_def_icon:nnnnn{\faLightbulb}{lightbulb}{free2}{247}{"F0EB}
\__fontawesome_def_icon:nnnnn{\faLine}{line}{brands1}{6}{"F3C0}
\__fontawesome_def_icon:nnnnn{\faLinesLeaning}{lines-leaning}{free2}{248}{"E51E}
\__fontawesome_def_icon:nnnnn{\faLink}{link}{free2}{249}{"F0C1}
\__fontawesome_def_icon:nnnnn{\faLinkSlash}{link-slash}{free2}{250}{"F127}
\__fontawesome_def_icon:nnnnn{\faLinkedin}{linkedin}{brands1}{7}{"F08C}
\__fontawesome_def_icon:nnnnn{\faLinkedinIn}{linkedin-in}{brands1}{8}{"F0E1}
\__fontawesome_def_icon:nnnnn{\faLinode}{linode}{brands1}{9}{"F2B8}
\__fontawesome_def_icon:nnnnn{\faLinux}{linux}{brands1}{10}{"F17C}
\__fontawesome_def_icon:nnnnn{\faLiraSign}{lira-sign}{free2}{251}{"F195}
\__fontawesome_def_icon:nnnnn{\faList}{list}{free2}{252}{"F03A}
\__fontawesome_def_icon:nnnnn{\faListCheck}{list-check}{free2}{253}{"F0AE}
\__fontawesome_def_icon:nnnnn{\faListOl}{list-ol}{free2}{254}{"F0CB}
\__fontawesome_def_icon:nnnnn{\faListUl}{list-ul}{free2}{255}{"F0CA}
\__fontawesome_def_icon:nnnnn{\faLitecoinSign}{litecoin-sign}{free3}{0}{"E1D3}
\__fontawesome_def_icon:nnnnn{\faLocationArrow}{location-arrow}{free3}{1}{"F124}
\__fontawesome_def_icon:nnnnn{\faLocationCrosshairs}{location-crosshairs}{free3}{2}{"F601}
\__fontawesome_def_icon:nnnnn{\faLocationDot}{location-dot}{free3}{3}{"F3C5}
\__fontawesome_def_icon:nnnnn{\faLocationPin}{location-pin}{free3}{4}{"F041}
\__fontawesome_def_icon:nnnnn{\faLocationPinLock}{location-pin-lock}{free3}{5}{"E51F}
\__fontawesome_def_icon:nnnnn{\faLock}{lock}{free3}{6}{"F023}
\__fontawesome_def_icon:nnnnn{\faLockOpen}{lock-open}{free3}{7}{"F3C1}
\__fontawesome_def_icon:nnnnn{\faLocust}{locust}{free3}{8}{"E520}
\__fontawesome_def_icon:nnnnn{\faLungs}{lungs}{free3}{9}{"F604}
\__fontawesome_def_icon:nnnnn{\faLungsVirus}{lungs-virus}{free3}{10}{"E067}
\__fontawesome_def_icon:nnnnn{\faLyft}{lyft}{brands1}{11}{"F3C3}
\__fontawesome_def_icon:nnnnn{\faM}{m}{free3}{11}{"4D}
\__fontawesome_def_icon:nnnnn{\faMagento}{magento}{brands1}{13}{"F3C4}
\__fontawesome_def_icon:nnnnn{\faMagnet}{magnet}{free3}{12}{"F076}
\__fontawesome_def_icon:nnnnn{\faMagnifyingGlass}{magnifying-glass}{free3}{13}{"F002}
\__fontawesome_def_icon:nnnnn{\faMagnifyingGlassArrowRight}{magnifying-glass-arrow-right}{free3}{14}{"E521}
\__fontawesome_def_icon:nnnnn{\faMagnifyingGlassChart}{magnifying-glass-chart}{free3}{15}{"E522}
\__fontawesome_def_icon:nnnnn{\faMagnifyingGlassDollar}{magnifying-glass-dollar}{free3}{16}{"F688}
\__fontawesome_def_icon:nnnnn{\faMagnifyingGlassLocation}{magnifying-glass-location}{free3}{17}{"F689}
\__fontawesome_def_icon:nnnnn{\faMagnifyingGlassMinus}{magnifying-glass-minus}{free3}{18}{"F010}
\__fontawesome_def_icon:nnnnn{\faMagnifyingGlassPlus}{magnifying-glass-plus}{free3}{19}{"F00E}
\__fontawesome_def_icon:nnnnn{\faMailchimp}{mailchimp}{brands1}{14}{"F59E}
\__fontawesome_def_icon:nnnnn{\faManatSign}{manat-sign}{free3}{20}{"E1D5}
\__fontawesome_def_icon:nnnnn{\faMandalorian}{mandalorian}{brands1}{15}{"F50F}
\__fontawesome_def_icon:nnnnn{\faMap}{map}{free3}{21}{"F279}
\__fontawesome_def_icon:nnnnn{\faMapLocation}{map-location}{free3}{22}{"F59F}
\__fontawesome_def_icon:nnnnn{\faMapLocationDot}{map-location-dot}{free3}{23}{"F5A0}
\__fontawesome_def_icon:nnnnn{\faMapPin}{map-pin}{free3}{24}{"F276}
\__fontawesome_def_icon:nnnnn{\faMarkdown}{markdown}{brands1}{16}{"F60F}
\__fontawesome_def_icon:nnnnn{\faMarker}{marker}{free3}{25}{"F5A1}
\__fontawesome_def_icon:nnnnn{\faMars}{mars}{free3}{26}{"F222}
\__fontawesome_def_icon:nnnnn{\faMarsAndVenus}{mars-and-venus}{free3}{27}{"F224}
\__fontawesome_def_icon:nnnnn{\faMarsAndVenusBurst}{mars-and-venus-burst}{free3}{28}{"E523}
\__fontawesome_def_icon:nnnnn{\faMarsDouble}{mars-double}{free3}{29}{"F227}
\__fontawesome_def_icon:nnnnn{\faMarsStroke}{mars-stroke}{free3}{30}{"F229}
\__fontawesome_def_icon:nnnnn{\faMarsStrokeRight}{mars-stroke-right}{free3}{31}{"F22B}
\__fontawesome_def_icon:nnnnn{\faMarsStrokeUp}{mars-stroke-up}{free3}{32}{"F22A}
\__fontawesome_def_icon:nnnnn{\faMartiniGlass}{martini-glass}{free3}{33}{"F57B}
\__fontawesome_def_icon:nnnnn{\faMartiniGlassCitrus}{martini-glass-citrus}{free3}{34}{"F561}
\__fontawesome_def_icon:nnnnn{\faMartiniGlassEmpty}{martini-glass-empty}{free3}{35}{"F000}
\__fontawesome_def_icon:nnnnn{\faMask}{mask}{free3}{36}{"F6FA}
\__fontawesome_def_icon:nnnnn{\faMaskFace}{mask-face}{free3}{37}{"E1D7}
\__fontawesome_def_icon:nnnnn{\faMaskVentilator}{mask-ventilator}{free3}{38}{"E524}
\__fontawesome_def_icon:nnnnn{\faMasksTheater}{masks-theater}{free3}{39}{"F630}
\__fontawesome_def_icon:nnnnn{\faMastodon}{mastodon}{brands1}{17}{"F4F6}
\__fontawesome_def_icon:nnnnn{\faMattressPillow}{mattress-pillow}{free3}{40}{"E525}
\__fontawesome_def_icon:nnnnn{\faMaxcdn}{maxcdn}{brands1}{18}{"F136}
\__fontawesome_def_icon:nnnnn{\faMaximize}{maximize}{free3}{41}{"F31E}
\__fontawesome_def_icon:nnnnn{\faMdb}{mdb}{brands1}{19}{"F8CA}
\__fontawesome_def_icon:nnnnn{\faMedal}{medal}{free3}{42}{"F5A2}
\__fontawesome_def_icon:nnnnn{\faMedapps}{medapps}{brands1}{20}{"F3C6}
\__fontawesome_def_icon:nnnnn{\faMedium}{medium}{brands1}{21}{"F23A}
\__fontawesome_def_icon:nnnnn{\faMedrt}{medrt}{brands1}{22}{"F3C8}
\__fontawesome_def_icon:nnnnn{\faMeetup}{meetup}{brands1}{23}{"F2E0}
\__fontawesome_def_icon:nnnnn{\faMegaport}{megaport}{brands1}{24}{"F5A3}
\__fontawesome_def_icon:nnnnn{\faMemory}{memory}{free3}{43}{"F538}
\__fontawesome_def_icon:nnnnn{\faMendeley}{mendeley}{brands1}{25}{"F7B3}
\__fontawesome_def_icon:nnnnn{\faMenorah}{menorah}{free3}{44}{"F676}
\__fontawesome_def_icon:nnnnn{\faMercury}{mercury}{free3}{45}{"F223}
\__fontawesome_def_icon:nnnnn{\faMessage}{message}{free3}{46}{"F27A}
\__fontawesome_def_icon:nnnnn{\faMeta}{meta}{brands1}{26}{"E49B}
\__fontawesome_def_icon:nnnnn{\faMeteor}{meteor}{free3}{47}{"F753}
\__fontawesome_def_icon:nnnnn{\faMicroblog}{microblog}{brands1}{27}{"E01A}
\__fontawesome_def_icon:nnnnn{\faMicrochip}{microchip}{free3}{48}{"F2DB}
\__fontawesome_def_icon:nnnnn{\faMicrophone}{microphone}{free3}{49}{"F130}
\__fontawesome_def_icon:nnnnn{\faMicrophoneLines}{microphone-lines}{free3}{50}{"F3C9}
\__fontawesome_def_icon:nnnnn{\faMicrophoneLinesSlash}{microphone-lines-slash}{free3}{51}{"F539}
\__fontawesome_def_icon:nnnnn{\faMicrophoneSlash}{microphone-slash}{free3}{52}{"F131}
\__fontawesome_def_icon:nnnnn{\faMicroscope}{microscope}{free3}{53}{"F610}
\__fontawesome_def_icon:nnnnn{\faMicrosoft}{microsoft}{brands1}{28}{"F3CA}
\__fontawesome_def_icon:nnnnn{\faMillSign}{mill-sign}{free3}{54}{"E1ED}
\__fontawesome_def_icon:nnnnn{\faMinimize}{minimize}{free3}{55}{"F78C}
\__fontawesome_def_icon:nnnnn{\faMintbit}{mintbit}{brands1}{29}{"E62F}
\__fontawesome_def_icon:nnnnn{\faMinus}{minus}{free3}{56}{"F068}
\__fontawesome_def_icon:nnnnn{\faMitten}{mitten}{free3}{57}{"F7B5}
\__fontawesome_def_icon:nnnnn{\faMix}{mix}{brands1}{30}{"F3CB}
\__fontawesome_def_icon:nnnnn{\faMixcloud}{mixcloud}{brands1}{31}{"F289}
\__fontawesome_def_icon:nnnnn{\faMixer}{mixer}{brands1}{32}{"E056}
\__fontawesome_def_icon:nnnnn{\faMizuni}{mizuni}{brands1}{33}{"F3CC}
\__fontawesome_def_icon:nnnnn{\faMobile}{mobile}{free3}{58}{"F3CE}
\__fontawesome_def_icon:nnnnn{\faMobileButton}{mobile-button}{free3}{59}{"F10B}
\__fontawesome_def_icon:nnnnn{\faMobileRetro}{mobile-retro}{free3}{60}{"E527}
\__fontawesome_def_icon:nnnnn{\faMobileScreen}{mobile-screen}{free3}{61}{"F3CF}
\__fontawesome_def_icon:nnnnn{\faMobileScreenButton}{mobile-screen-button}{free3}{62}{"F3CD}
\__fontawesome_def_icon:nnnnn{\faModx}{modx}{brands1}{34}{"F285}
\__fontawesome_def_icon:nnnnn{\faMonero}{monero}{brands1}{35}{"F3D0}
\__fontawesome_def_icon:nnnnn{\faMoneyBill}{money-bill}{free3}{63}{"F0D6}
\__fontawesome_def_icon:nnnnn{}{money-bill-1}{free3}{64}{"F3D1}
\__fontawesome_def_icon:nnnnn{}{money-bill-1-wave}{free3}{65}{"F53B}
\__fontawesome_def_icon:nnnnn{\faMoneyBillTransfer}{money-bill-transfer}{free3}{66}{"E528}
\__fontawesome_def_icon:nnnnn{\faMoneyBillTrendUp}{money-bill-trend-up}{free3}{67}{"E529}
\__fontawesome_def_icon:nnnnn{\faMoneyBillWave}{money-bill-wave}{free3}{68}{"F53A}
\__fontawesome_def_icon:nnnnn{\faMoneyBillWheat}{money-bill-wheat}{free3}{69}{"E52A}
\__fontawesome_def_icon:nnnnn{\faMoneyBills}{money-bills}{free3}{70}{"E1F3}
\__fontawesome_def_icon:nnnnn{\faMoneyCheck}{money-check}{free3}{71}{"F53C}
\__fontawesome_def_icon:nnnnn{\faMoneyCheckDollar}{money-check-dollar}{free3}{72}{"F53D}
\__fontawesome_def_icon:nnnnn{\faMonument}{monument}{free3}{73}{"F5A6}
\__fontawesome_def_icon:nnnnn{\faMoon}{moon}{free3}{74}{"F186}
\__fontawesome_def_icon:nnnnn{\faMortarPestle}{mortar-pestle}{free3}{75}{"F5A7}
\__fontawesome_def_icon:nnnnn{\faMosque}{mosque}{free3}{76}{"F678}
\__fontawesome_def_icon:nnnnn{\faMosquito}{mosquito}{free3}{77}{"E52B}
\__fontawesome_def_icon:nnnnn{\faMosquitoNet}{mosquito-net}{free3}{78}{"E52C}
\__fontawesome_def_icon:nnnnn{\faMotorcycle}{motorcycle}{free3}{79}{"F21C}
\__fontawesome_def_icon:nnnnn{\faMound}{mound}{free3}{80}{"E52D}
\__fontawesome_def_icon:nnnnn{\faMountain}{mountain}{free3}{81}{"F6FC}
\__fontawesome_def_icon:nnnnn{\faMountainCity}{mountain-city}{free3}{82}{"E52E}
\__fontawesome_def_icon:nnnnn{\faMountainSun}{mountain-sun}{free3}{83}{"E52F}
\__fontawesome_def_icon:nnnnn{\faMugHot}{mug-hot}{free3}{84}{"F7B6}
\__fontawesome_def_icon:nnnnn{\faMugSaucer}{mug-saucer}{free3}{85}{"F0F4}
\__fontawesome_def_icon:nnnnn{\faMusic}{music}{free3}{86}{"F001}
\__fontawesome_def_icon:nnnnn{\faN}{n}{free3}{87}{"4E}
\__fontawesome_def_icon:nnnnn{\faNairaSign}{naira-sign}{free3}{88}{"E1F6}
\__fontawesome_def_icon:nnnnn{\faNapster}{napster}{brands1}{37}{"F3D2}
\__fontawesome_def_icon:nnnnn{\faNeos}{neos}{brands1}{38}{"F612}
\__fontawesome_def_icon:nnnnn{\faNetworkWired}{network-wired}{free3}{89}{"F6FF}
\__fontawesome_def_icon:nnnnn{\faNeuter}{neuter}{free3}{90}{"F22C}
\__fontawesome_def_icon:nnnnn{\faNewspaper}{newspaper}{free3}{91}{"F1EA}
\__fontawesome_def_icon:nnnnn{\faNfcDirectional}{nfc-directional}{brands1}{39}{"E530}
\__fontawesome_def_icon:nnnnn{\faNfcSymbol}{nfc-symbol}{brands1}{40}{"E531}
\__fontawesome_def_icon:nnnnn{\faNimblr}{nimblr}{brands1}{41}{"F5A8}
\__fontawesome_def_icon:nnnnn{\faNode}{node}{brands1}{42}{"F419}
\__fontawesome_def_icon:nnnnn{\faNodeJs}{node-js}{brands1}{43}{"F3D3}
\__fontawesome_def_icon:nnnnn{\faNotEqual}{not-equal}{free3}{92}{"F53E}
\__fontawesome_def_icon:nnnnn{\faNotdef}{notdef}{free3}{93}{"E1FE}
\__fontawesome_def_icon:nnnnn{\faNoteSticky}{note-sticky}{free3}{94}{"F249}
\__fontawesome_def_icon:nnnnn{\faNotesMedical}{notes-medical}{free3}{95}{"F481}
\__fontawesome_def_icon:nnnnn{\faNpm}{npm}{brands1}{45}{"F3D4}
\__fontawesome_def_icon:nnnnn{}{ns8}{brands1}{46}{"F3D5}
\__fontawesome_def_icon:nnnnn{\faNutritionix}{nutritionix}{brands1}{47}{"F3D6}
\__fontawesome_def_icon:nnnnn{\faO}{o}{free3}{96}{"4F}
\__fontawesome_def_icon:nnnnn{\faObjectGroup}{object-group}{free3}{97}{"F247}
\__fontawesome_def_icon:nnnnn{\faObjectUngroup}{object-ungroup}{free3}{98}{"F248}
\__fontawesome_def_icon:nnnnn{\faOctopusDeploy}{octopus-deploy}{brands1}{49}{"E082}
\__fontawesome_def_icon:nnnnn{\faOdnoklassniki}{odnoklassniki}{brands1}{50}{"F263}
\__fontawesome_def_icon:nnnnn{\faOdysee}{odysee}{brands1}{51}{"E5C6}
\__fontawesome_def_icon:nnnnn{\faOilCan}{oil-can}{free3}{99}{"F613}
\__fontawesome_def_icon:nnnnn{\faOilWell}{oil-well}{free3}{100}{"E532}
\__fontawesome_def_icon:nnnnn{\faOldRepublic}{old-republic}{brands1}{52}{"F510}
\__fontawesome_def_icon:nnnnn{\faOm}{om}{free3}{101}{"F679}
\__fontawesome_def_icon:nnnnn{\faOpencart}{opencart}{brands1}{53}{"F23D}
\__fontawesome_def_icon:nnnnn{\faOpenid}{openid}{brands1}{54}{"F19B}
\__fontawesome_def_icon:nnnnn{\faOpensuse}{opensuse}{brands1}{55}{"E62B}
\__fontawesome_def_icon:nnnnn{\faOpera}{opera}{brands1}{56}{"F26A}
\__fontawesome_def_icon:nnnnn{\faOptinMonster}{optin-monster}{brands1}{57}{"F23C}
\__fontawesome_def_icon:nnnnn{\faOrcid}{orcid}{brands1}{58}{"F8D2}
\__fontawesome_def_icon:nnnnn{\faOsi}{osi}{brands1}{59}{"F41A}
\__fontawesome_def_icon:nnnnn{\faOtter}{otter}{free3}{102}{"F700}
\__fontawesome_def_icon:nnnnn{\faOutdent}{outdent}{free3}{103}{"F03B}
\__fontawesome_def_icon:nnnnn{\faP}{p}{free3}{104}{"50}
\__fontawesome_def_icon:nnnnn{\faPadlet}{padlet}{brands1}{61}{"E4A0}
\__fontawesome_def_icon:nnnnn{}{page4}{brands1}{62}{"F3D7}
\__fontawesome_def_icon:nnnnn{\faPagelines}{pagelines}{brands1}{63}{"F18C}
\__fontawesome_def_icon:nnnnn{\faPager}{pager}{free3}{105}{"F815}
\__fontawesome_def_icon:nnnnn{\faPaintRoller}{paint-roller}{free3}{106}{"F5AA}
\__fontawesome_def_icon:nnnnn{\faPaintbrush}{paintbrush}{free3}{107}{"F1FC}
\__fontawesome_def_icon:nnnnn{\faPalette}{palette}{free3}{108}{"F53F}
\__fontawesome_def_icon:nnnnn{\faPalfed}{palfed}{brands1}{64}{"F3D8}
\__fontawesome_def_icon:nnnnn{\faPallet}{pallet}{free3}{109}{"F482}
\__fontawesome_def_icon:nnnnn{\faPanorama}{panorama}{free3}{110}{"E209}
\__fontawesome_def_icon:nnnnn{\faPaperPlane}{paper-plane}{free3}{111}{"F1D8}
\__fontawesome_def_icon:nnnnn{\faPaperclip}{paperclip}{free3}{112}{"F0C6}
\__fontawesome_def_icon:nnnnn{\faParachuteBox}{parachute-box}{free3}{113}{"F4CD}
\__fontawesome_def_icon:nnnnn{\faParagraph}{paragraph}{free3}{114}{"F1DD}
\__fontawesome_def_icon:nnnnn{\faPassport}{passport}{free3}{115}{"F5AB}
\__fontawesome_def_icon:nnnnn{\faPaste}{paste}{free3}{116}{"F0EA}
\__fontawesome_def_icon:nnnnn{\faPatreon}{patreon}{brands1}{65}{"F3D9}
\__fontawesome_def_icon:nnnnn{\faPause}{pause}{free3}{117}{"F04C}
\__fontawesome_def_icon:nnnnn{\faPaw}{paw}{free3}{118}{"F1B0}
\__fontawesome_def_icon:nnnnn{\faPaypal}{paypal}{brands1}{66}{"F1ED}
\__fontawesome_def_icon:nnnnn{\faPeace}{peace}{free3}{119}{"F67C}
\__fontawesome_def_icon:nnnnn{\faPen}{pen}{free3}{120}{"F304}
\__fontawesome_def_icon:nnnnn{\faPenClip}{pen-clip}{free3}{121}{"F305}
\__fontawesome_def_icon:nnnnn{\faPenFancy}{pen-fancy}{free3}{122}{"F5AC}
\__fontawesome_def_icon:nnnnn{\faPenNib}{pen-nib}{free3}{123}{"F5AD}
\__fontawesome_def_icon:nnnnn{\faPenRuler}{pen-ruler}{free3}{124}{"F5AE}
\__fontawesome_def_icon:nnnnn{\faPenToSquare}{pen-to-square}{free3}{125}{"F044}
\__fontawesome_def_icon:nnnnn{\faPencil}{pencil}{free3}{126}{"F303}
\__fontawesome_def_icon:nnnnn{\faPeopleArrows}{people-arrows}{free3}{127}{"E068}
\__fontawesome_def_icon:nnnnn{\faPeopleCarryBox}{people-carry-box}{free3}{128}{"F4CE}
\__fontawesome_def_icon:nnnnn{\faPeopleGroup}{people-group}{free3}{129}{"E533}
\__fontawesome_def_icon:nnnnn{\faPeopleLine}{people-line}{free3}{130}{"E534}
\__fontawesome_def_icon:nnnnn{\faPeoplePulling}{people-pulling}{free3}{131}{"E535}
\__fontawesome_def_icon:nnnnn{\faPeopleRobbery}{people-robbery}{free3}{132}{"E536}
\__fontawesome_def_icon:nnnnn{\faPeopleRoof}{people-roof}{free3}{133}{"E537}
\__fontawesome_def_icon:nnnnn{\faPepperHot}{pepper-hot}{free3}{134}{"F816}
\__fontawesome_def_icon:nnnnn{\faPerbyte}{perbyte}{brands1}{67}{"E083}
\__fontawesome_def_icon:nnnnn{\faPercent}{percent}{free3}{135}{"25}
\__fontawesome_def_icon:nnnnn{\faPeriscope}{periscope}{brands1}{69}{"F3DA}
\__fontawesome_def_icon:nnnnn{\faPerson}{person}{free3}{136}{"F183}
\__fontawesome_def_icon:nnnnn{\faPersonArrowDownToLine}{person-arrow-down-to-line}{free3}{137}{"E538}
\__fontawesome_def_icon:nnnnn{\faPersonArrowUpFromLine}{person-arrow-up-from-line}{free3}{138}{"E539}
\__fontawesome_def_icon:nnnnn{\faPersonBiking}{person-biking}{free3}{139}{"F84A}
\__fontawesome_def_icon:nnnnn{\faPersonBooth}{person-booth}{free3}{140}{"F756}
\__fontawesome_def_icon:nnnnn{\faPersonBreastfeeding}{person-breastfeeding}{free3}{141}{"E53A}
\__fontawesome_def_icon:nnnnn{\faPersonBurst}{person-burst}{free3}{142}{"E53B}
\__fontawesome_def_icon:nnnnn{\faPersonCane}{person-cane}{free3}{143}{"E53C}
\__fontawesome_def_icon:nnnnn{\faPersonChalkboard}{person-chalkboard}{free3}{144}{"E53D}
\__fontawesome_def_icon:nnnnn{\faPersonCircleCheck}{person-circle-check}{free3}{145}{"E53E}
\__fontawesome_def_icon:nnnnn{\faPersonCircleExclamation}{person-circle-exclamation}{free3}{146}{"E53F}
\__fontawesome_def_icon:nnnnn{\faPersonCircleMinus}{person-circle-minus}{free3}{147}{"E540}
\__fontawesome_def_icon:nnnnn{\faPersonCirclePlus}{person-circle-plus}{free3}{148}{"E541}
\__fontawesome_def_icon:nnnnn{\faPersonCircleQuestion}{person-circle-question}{free3}{149}{"E542}
\__fontawesome_def_icon:nnnnn{\faPersonCircleXmark}{person-circle-xmark}{free3}{150}{"E543}
\__fontawesome_def_icon:nnnnn{\faPersonDigging}{person-digging}{free3}{151}{"F85E}
\__fontawesome_def_icon:nnnnn{\faPersonDotsFromLine}{person-dots-from-line}{free3}{152}{"F470}
\__fontawesome_def_icon:nnnnn{\faPersonDress}{person-dress}{free3}{153}{"F182}
\__fontawesome_def_icon:nnnnn{\faPersonDressBurst}{person-dress-burst}{free3}{154}{"E544}
\__fontawesome_def_icon:nnnnn{\faPersonDrowning}{person-drowning}{free3}{155}{"E545}
\__fontawesome_def_icon:nnnnn{\faPersonFalling}{person-falling}{free3}{156}{"E546}
\__fontawesome_def_icon:nnnnn{\faPersonFallingBurst}{person-falling-burst}{free3}{157}{"E547}
\__fontawesome_def_icon:nnnnn{\faPersonHalfDress}{person-half-dress}{free3}{158}{"E548}
\__fontawesome_def_icon:nnnnn{\faPersonHarassing}{person-harassing}{free3}{159}{"E549}
\__fontawesome_def_icon:nnnnn{\faPersonHiking}{person-hiking}{free3}{160}{"F6EC}
\__fontawesome_def_icon:nnnnn{\faPersonMilitaryPointing}{person-military-pointing}{free3}{161}{"E54A}
\__fontawesome_def_icon:nnnnn{\faPersonMilitaryRifle}{person-military-rifle}{free3}{162}{"E54B}
\__fontawesome_def_icon:nnnnn{\faPersonMilitaryToPerson}{person-military-to-person}{free3}{163}{"E54C}
\__fontawesome_def_icon:nnnnn{\faPersonPraying}{person-praying}{free3}{164}{"F683}
\__fontawesome_def_icon:nnnnn{\faPersonPregnant}{person-pregnant}{free3}{165}{"E31E}
\__fontawesome_def_icon:nnnnn{\faPersonRays}{person-rays}{free3}{166}{"E54D}
\__fontawesome_def_icon:nnnnn{\faPersonRifle}{person-rifle}{free3}{167}{"E54E}
\__fontawesome_def_icon:nnnnn{\faPersonRunning}{person-running}{free3}{168}{"F70C}
\__fontawesome_def_icon:nnnnn{\faPersonShelter}{person-shelter}{free3}{169}{"E54F}
\__fontawesome_def_icon:nnnnn{\faPersonSkating}{person-skating}{free3}{170}{"F7C5}
\__fontawesome_def_icon:nnnnn{\faPersonSkiing}{person-skiing}{free3}{171}{"F7C9}
\__fontawesome_def_icon:nnnnn{\faPersonSkiingNordic}{person-skiing-nordic}{free3}{172}{"F7CA}
\__fontawesome_def_icon:nnnnn{\faPersonSnowboarding}{person-snowboarding}{free3}{173}{"F7CE}
\__fontawesome_def_icon:nnnnn{\faPersonSwimming}{person-swimming}{free3}{174}{"F5C4}
\__fontawesome_def_icon:nnnnn{\faPersonThroughWindow}{person-through-window}{free3}{175}{"E5A9}
\__fontawesome_def_icon:nnnnn{\faPersonWalking}{person-walking}{free3}{176}{"F554}
\__fontawesome_def_icon:nnnnn{\faPersonWalkingArrowLoopLeft}{person-walking-arrow-loop-left}{free3}{177}{"E551}
\__fontawesome_def_icon:nnnnn{\faPersonWalkingArrowRight}{person-walking-arrow-right}{free3}{178}{"E552}
\__fontawesome_def_icon:nnnnn{\faPersonWalkingDashedLineArrowRight}{person-walking-dashed-line-arrow-right}{free3}{179}{"E553}
\__fontawesome_def_icon:nnnnn{\faPersonWalkingLuggage}{person-walking-luggage}{free3}{180}{"E554}
\__fontawesome_def_icon:nnnnn{\faPersonWalkingWithCane}{person-walking-with-cane}{free3}{181}{"F29D}
\__fontawesome_def_icon:nnnnn{\faPesetaSign}{peseta-sign}{free3}{182}{"E221}
\__fontawesome_def_icon:nnnnn{\faPesoSign}{peso-sign}{free3}{183}{"E222}
\__fontawesome_def_icon:nnnnn{\faPhabricator}{phabricator}{brands1}{70}{"F3DB}
\__fontawesome_def_icon:nnnnn{\faPhoenixFramework}{phoenix-framework}{brands1}{71}{"F3DC}
\__fontawesome_def_icon:nnnnn{\faPhoenixSquadron}{phoenix-squadron}{brands1}{72}{"F511}
\__fontawesome_def_icon:nnnnn{\faPhone}{phone}{free3}{184}{"F095}
\__fontawesome_def_icon:nnnnn{\faPhoneFlip}{phone-flip}{free3}{185}{"F879}
\__fontawesome_def_icon:nnnnn{\faPhoneSlash}{phone-slash}{free3}{186}{"F3DD}
\__fontawesome_def_icon:nnnnn{\faPhoneVolume}{phone-volume}{free3}{187}{"F2A0}
\__fontawesome_def_icon:nnnnn{\faPhotoFilm}{photo-film}{free3}{188}{"F87C}
\__fontawesome_def_icon:nnnnn{\faPhp}{php}{brands1}{73}{"F457}
\__fontawesome_def_icon:nnnnn{\faPiedPiper}{pied-piper}{brands1}{74}{"F2AE}
\__fontawesome_def_icon:nnnnn{\faPiedPiperAlt}{pied-piper-alt}{brands1}{75}{"F1A8}
\__fontawesome_def_icon:nnnnn{\faPiedPiperHat}{pied-piper-hat}{brands1}{76}{"F4E5}
\__fontawesome_def_icon:nnnnn{\faPiedPiperPp}{pied-piper-pp}{brands1}{77}{"F1A7}
\__fontawesome_def_icon:nnnnn{\faPiggyBank}{piggy-bank}{free3}{189}{"F4D3}
\__fontawesome_def_icon:nnnnn{\faPills}{pills}{free3}{190}{"F484}
\__fontawesome_def_icon:nnnnn{\faPinterest}{pinterest}{brands1}{78}{"F0D2}
\__fontawesome_def_icon:nnnnn{\faPinterestP}{pinterest-p}{brands1}{79}{"F231}
\__fontawesome_def_icon:nnnnn{\faPix}{pix}{brands1}{80}{"E43A}
\__fontawesome_def_icon:nnnnn{\faPixiv}{pixiv}{brands1}{81}{"E640}
\__fontawesome_def_icon:nnnnn{\faPizzaSlice}{pizza-slice}{free3}{191}{"F818}
\__fontawesome_def_icon:nnnnn{\faPlaceOfWorship}{place-of-worship}{free3}{192}{"F67F}
\__fontawesome_def_icon:nnnnn{\faPlane}{plane}{free3}{193}{"F072}
\__fontawesome_def_icon:nnnnn{\faPlaneArrival}{plane-arrival}{free3}{194}{"F5AF}
\__fontawesome_def_icon:nnnnn{\faPlaneCircleCheck}{plane-circle-check}{free3}{195}{"E555}
\__fontawesome_def_icon:nnnnn{\faPlaneCircleExclamation}{plane-circle-exclamation}{free3}{196}{"E556}
\__fontawesome_def_icon:nnnnn{\faPlaneCircleXmark}{plane-circle-xmark}{free3}{197}{"E557}
\__fontawesome_def_icon:nnnnn{\faPlaneDeparture}{plane-departure}{free3}{198}{"F5B0}
\__fontawesome_def_icon:nnnnn{\faPlaneLock}{plane-lock}{free3}{199}{"E558}
\__fontawesome_def_icon:nnnnn{\faPlaneSlash}{plane-slash}{free3}{200}{"E069}
\__fontawesome_def_icon:nnnnn{\faPlaneUp}{plane-up}{free3}{201}{"E22D}
\__fontawesome_def_icon:nnnnn{\faPlantWilt}{plant-wilt}{free3}{202}{"E5AA}
\__fontawesome_def_icon:nnnnn{\faPlateWheat}{plate-wheat}{free3}{203}{"E55A}
\__fontawesome_def_icon:nnnnn{\faPlay}{play}{free3}{204}{"F04B}
\__fontawesome_def_icon:nnnnn{\faPlaystation}{playstation}{brands1}{82}{"F3DF}
\__fontawesome_def_icon:nnnnn{\faPlug}{plug}{free3}{205}{"F1E6}
\__fontawesome_def_icon:nnnnn{\faPlugCircleBolt}{plug-circle-bolt}{free3}{206}{"E55B}
\__fontawesome_def_icon:nnnnn{\faPlugCircleCheck}{plug-circle-check}{free3}{207}{"E55C}
\__fontawesome_def_icon:nnnnn{\faPlugCircleExclamation}{plug-circle-exclamation}{free3}{208}{"E55D}
\__fontawesome_def_icon:nnnnn{\faPlugCircleMinus}{plug-circle-minus}{free3}{209}{"E55E}
\__fontawesome_def_icon:nnnnn{\faPlugCirclePlus}{plug-circle-plus}{free3}{210}{"E55F}
\__fontawesome_def_icon:nnnnn{\faPlugCircleXmark}{plug-circle-xmark}{free3}{211}{"E560}
\__fontawesome_def_icon:nnnnn{\faPlus}{plus}{free3}{212}{"2B}
\__fontawesome_def_icon:nnnnn{\faPlusMinus}{plus-minus}{free3}{213}{"E43C}
\__fontawesome_def_icon:nnnnn{\faPodcast}{podcast}{free3}{214}{"F2CE}
\__fontawesome_def_icon:nnnnn{\faPoo}{poo}{free3}{215}{"F2FE}
\__fontawesome_def_icon:nnnnn{\faPooStorm}{poo-storm}{free3}{216}{"F75A}
\__fontawesome_def_icon:nnnnn{\faPoop}{poop}{free3}{217}{"F619}
\__fontawesome_def_icon:nnnnn{\faPowerOff}{power-off}{free3}{218}{"F011}
\__fontawesome_def_icon:nnnnn{\faPrescription}{prescription}{free3}{219}{"F5B1}
\__fontawesome_def_icon:nnnnn{\faPrescriptionBottle}{prescription-bottle}{free3}{220}{"F485}
\__fontawesome_def_icon:nnnnn{\faPrescriptionBottleMedical}{prescription-bottle-medical}{free3}{221}{"F486}
\__fontawesome_def_icon:nnnnn{\faPrint}{print}{free3}{222}{"F02F}
\__fontawesome_def_icon:nnnnn{\faProductHunt}{product-hunt}{brands1}{84}{"F288}
\__fontawesome_def_icon:nnnnn{\faPumpMedical}{pump-medical}{free3}{223}{"E06A}
\__fontawesome_def_icon:nnnnn{\faPumpSoap}{pump-soap}{free3}{224}{"E06B}
\__fontawesome_def_icon:nnnnn{\faPushed}{pushed}{brands1}{85}{"F3E1}
\__fontawesome_def_icon:nnnnn{\faPuzzlePiece}{puzzle-piece}{free3}{225}{"F12E}
\__fontawesome_def_icon:nnnnn{\faPython}{python}{brands1}{86}{"F3E2}
\__fontawesome_def_icon:nnnnn{\faQ}{q}{free3}{226}{"51}
\__fontawesome_def_icon:nnnnn{\faQq}{qq}{brands1}{88}{"F1D6}
\__fontawesome_def_icon:nnnnn{\faQrcode}{qrcode}{free3}{227}{"F029}
\__fontawesome_def_icon:nnnnn{\faQuestion}{question}{free3}{228}{"3F}
\__fontawesome_def_icon:nnnnn{\faQuinscape}{quinscape}{brands1}{90}{"F459}
\__fontawesome_def_icon:nnnnn{\faQuora}{quora}{brands1}{91}{"F2C4}
\__fontawesome_def_icon:nnnnn{\faQuoteLeft}{quote-left}{free3}{229}{"F10D}
\__fontawesome_def_icon:nnnnn{\faQuoteRight}{quote-right}{free3}{230}{"F10E}
\__fontawesome_def_icon:nnnnn{\faR}{r}{free3}{231}{"52}
\__fontawesome_def_icon:nnnnn{\faRProject}{r-project}{brands1}{93}{"F4F7}
\__fontawesome_def_icon:nnnnn{\faRadiation}{radiation}{free3}{232}{"F7B9}
\__fontawesome_def_icon:nnnnn{\faRadio}{radio}{free3}{233}{"F8D7}
\__fontawesome_def_icon:nnnnn{\faRainbow}{rainbow}{free3}{234}{"F75B}
\__fontawesome_def_icon:nnnnn{\faRankingStar}{ranking-star}{free3}{235}{"E561}
\__fontawesome_def_icon:nnnnn{\faRaspberryPi}{raspberry-pi}{brands1}{94}{"F7BB}
\__fontawesome_def_icon:nnnnn{\faRavelry}{ravelry}{brands1}{95}{"F2D9}
\__fontawesome_def_icon:nnnnn{\faReact}{react}{brands1}{96}{"F41B}
\__fontawesome_def_icon:nnnnn{\faReacteurope}{reacteurope}{brands1}{97}{"F75D}
\__fontawesome_def_icon:nnnnn{\faReadme}{readme}{brands1}{98}{"F4D5}
\__fontawesome_def_icon:nnnnn{\faRebel}{rebel}{brands1}{99}{"F1D0}
\__fontawesome_def_icon:nnnnn{\faReceipt}{receipt}{free3}{236}{"F543}
\__fontawesome_def_icon:nnnnn{\faRecordVinyl}{record-vinyl}{free3}{237}{"F8D9}
\__fontawesome_def_icon:nnnnn{\faRectangleAd}{rectangle-ad}{free3}{238}{"F641}
\__fontawesome_def_icon:nnnnn{\faRectangleList}{rectangle-list}{free3}{239}{"F022}
\__fontawesome_def_icon:nnnnn{\faRectangleXmark}{rectangle-xmark}{free3}{240}{"F410}
\__fontawesome_def_icon:nnnnn{\faRecycle}{recycle}{free3}{241}{"F1B8}
\__fontawesome_def_icon:nnnnn{\faRedRiver}{red-river}{brands1}{100}{"F3E3}
\__fontawesome_def_icon:nnnnn{\faReddit}{reddit}{brands1}{101}{"F1A1}
\__fontawesome_def_icon:nnnnn{\faRedditAlien}{reddit-alien}{brands1}{102}{"F281}
\__fontawesome_def_icon:nnnnn{\faRedhat}{redhat}{brands1}{103}{"F7BC}
\__fontawesome_def_icon:nnnnn{\faRegistered}{registered}{free3}{242}{"F25D}
\__fontawesome_def_icon:nnnnn{\faRenren}{renren}{brands1}{104}{"F18B}
\__fontawesome_def_icon:nnnnn{\faRepeat}{repeat}{free3}{243}{"F363}
\__fontawesome_def_icon:nnnnn{\faReply}{reply}{free3}{244}{"F3E5}
\__fontawesome_def_icon:nnnnn{\faReplyAll}{reply-all}{free3}{245}{"F122}
\__fontawesome_def_icon:nnnnn{\faReplyd}{replyd}{brands1}{105}{"F3E6}
\__fontawesome_def_icon:nnnnn{\faRepublican}{republican}{free3}{246}{"F75E}
\__fontawesome_def_icon:nnnnn{\faResearchgate}{researchgate}{brands1}{106}{"F4F8}
\__fontawesome_def_icon:nnnnn{\faResolving}{resolving}{brands1}{107}{"F3E7}
\__fontawesome_def_icon:nnnnn{\faRestroom}{restroom}{free3}{247}{"F7BD}
\__fontawesome_def_icon:nnnnn{\faRetweet}{retweet}{free3}{248}{"F079}
\__fontawesome_def_icon:nnnnn{\faRev}{rev}{brands1}{108}{"F5B2}
\__fontawesome_def_icon:nnnnn{\faRibbon}{ribbon}{free3}{249}{"F4D6}
\__fontawesome_def_icon:nnnnn{\faRightFromBracket}{right-from-bracket}{free3}{250}{"F2F5}
\__fontawesome_def_icon:nnnnn{\faRightLeft}{right-left}{free3}{251}{"F362}
\__fontawesome_def_icon:nnnnn{\faRightLong}{right-long}{free3}{252}{"F30B}
\__fontawesome_def_icon:nnnnn{\faRightToBracket}{right-to-bracket}{free3}{253}{"F2F6}
\__fontawesome_def_icon:nnnnn{\faRing}{ring}{free3}{254}{"F70B}
\__fontawesome_def_icon:nnnnn{\faRoad}{road}{free3}{255}{"F018}
\__fontawesome_def_icon:nnnnn{\faRoadBarrier}{road-barrier}{free4}{0}{"E562}
\__fontawesome_def_icon:nnnnn{\faRoadBridge}{road-bridge}{free4}{1}{"E563}
\__fontawesome_def_icon:nnnnn{\faRoadCircleCheck}{road-circle-check}{free4}{2}{"E564}
\__fontawesome_def_icon:nnnnn{\faRoadCircleExclamation}{road-circle-exclamation}{free4}{3}{"E565}
\__fontawesome_def_icon:nnnnn{\faRoadCircleXmark}{road-circle-xmark}{free4}{4}{"E566}
\__fontawesome_def_icon:nnnnn{\faRoadLock}{road-lock}{free4}{5}{"E567}
\__fontawesome_def_icon:nnnnn{\faRoadSpikes}{road-spikes}{free4}{6}{"E568}
\__fontawesome_def_icon:nnnnn{\faRobot}{robot}{free4}{7}{"F544}
\__fontawesome_def_icon:nnnnn{\faRocket}{rocket}{free4}{8}{"F135}
\__fontawesome_def_icon:nnnnn{\faRocketchat}{rocketchat}{brands1}{109}{"F3E8}
\__fontawesome_def_icon:nnnnn{\faRockrms}{rockrms}{brands1}{110}{"F3E9}
\__fontawesome_def_icon:nnnnn{\faRotate}{rotate}{free4}{9}{"F2F1}
\__fontawesome_def_icon:nnnnn{\faRotateLeft}{rotate-left}{free4}{10}{"F2EA}
\__fontawesome_def_icon:nnnnn{\faRotateRight}{rotate-right}{free4}{11}{"F2F9}
\__fontawesome_def_icon:nnnnn{\faRoute}{route}{free4}{12}{"F4D7}
\__fontawesome_def_icon:nnnnn{\faRss}{rss}{free4}{13}{"F09E}
\__fontawesome_def_icon:nnnnn{\faRubleSign}{ruble-sign}{free4}{14}{"F158}
\__fontawesome_def_icon:nnnnn{\faRug}{rug}{free4}{15}{"E569}
\__fontawesome_def_icon:nnnnn{\faRuler}{ruler}{free4}{16}{"F545}
\__fontawesome_def_icon:nnnnn{\faRulerCombined}{ruler-combined}{free4}{17}{"F546}
\__fontawesome_def_icon:nnnnn{\faRulerHorizontal}{ruler-horizontal}{free4}{18}{"F547}
\__fontawesome_def_icon:nnnnn{\faRulerVertical}{ruler-vertical}{free4}{19}{"F548}
\__fontawesome_def_icon:nnnnn{\faRupeeSign}{rupee-sign}{free4}{20}{"F156}
\__fontawesome_def_icon:nnnnn{\faRupiahSign}{rupiah-sign}{free4}{21}{"E23D}
\__fontawesome_def_icon:nnnnn{\faRust}{rust}{brands1}{111}{"E07A}
\__fontawesome_def_icon:nnnnn{\faS}{s}{free4}{22}{"53}
\__fontawesome_def_icon:nnnnn{\faSackDollar}{sack-dollar}{free4}{23}{"F81D}
\__fontawesome_def_icon:nnnnn{\faSackXmark}{sack-xmark}{free4}{24}{"E56A}
\__fontawesome_def_icon:nnnnn{\faSafari}{safari}{brands1}{113}{"F267}
\__fontawesome_def_icon:nnnnn{\faSailboat}{sailboat}{free4}{25}{"E445}
\__fontawesome_def_icon:nnnnn{\faSalesforce}{salesforce}{brands1}{114}{"F83B}
\__fontawesome_def_icon:nnnnn{\faSass}{sass}{brands1}{115}{"F41E}
\__fontawesome_def_icon:nnnnn{\faSatellite}{satellite}{free4}{26}{"F7BF}
\__fontawesome_def_icon:nnnnn{\faSatelliteDish}{satellite-dish}{free4}{27}{"F7C0}
\__fontawesome_def_icon:nnnnn{\faScaleBalanced}{scale-balanced}{free4}{28}{"F24E}
\__fontawesome_def_icon:nnnnn{\faScaleUnbalanced}{scale-unbalanced}{free4}{29}{"F515}
\__fontawesome_def_icon:nnnnn{\faScaleUnbalancedFlip}{scale-unbalanced-flip}{free4}{30}{"F516}
\__fontawesome_def_icon:nnnnn{\faSchlix}{schlix}{brands1}{116}{"F3EA}
\__fontawesome_def_icon:nnnnn{\faSchool}{school}{free4}{31}{"F549}
\__fontawesome_def_icon:nnnnn{\faSchoolCircleCheck}{school-circle-check}{free4}{32}{"E56B}
\__fontawesome_def_icon:nnnnn{\faSchoolCircleExclamation}{school-circle-exclamation}{free4}{33}{"E56C}
\__fontawesome_def_icon:nnnnn{\faSchoolCircleXmark}{school-circle-xmark}{free4}{34}{"E56D}
\__fontawesome_def_icon:nnnnn{\faSchoolFlag}{school-flag}{free4}{35}{"E56E}
\__fontawesome_def_icon:nnnnn{\faSchoolLock}{school-lock}{free4}{36}{"E56F}
\__fontawesome_def_icon:nnnnn{\faScissors}{scissors}{free4}{37}{"F0C4}
\__fontawesome_def_icon:nnnnn{\faScreenpal}{screenpal}{brands1}{117}{"E570}
\__fontawesome_def_icon:nnnnn{\faScrewdriver}{screwdriver}{free4}{38}{"F54A}
\__fontawesome_def_icon:nnnnn{\faScrewdriverWrench}{screwdriver-wrench}{free4}{39}{"F7D9}
\__fontawesome_def_icon:nnnnn{\faScribd}{scribd}{brands1}{118}{"F28A}
\__fontawesome_def_icon:nnnnn{\faScroll}{scroll}{free4}{40}{"F70E}
\__fontawesome_def_icon:nnnnn{\faScrollTorah}{scroll-torah}{free4}{41}{"F6A0}
\__fontawesome_def_icon:nnnnn{\faSdCard}{sd-card}{free4}{42}{"F7C2}
\__fontawesome_def_icon:nnnnn{\faSearchengin}{searchengin}{brands1}{119}{"F3EB}
\__fontawesome_def_icon:nnnnn{\faSection}{section}{free4}{43}{"E447}
\__fontawesome_def_icon:nnnnn{\faSeedling}{seedling}{free4}{44}{"F4D8}
\__fontawesome_def_icon:nnnnn{\faSellcast}{sellcast}{brands1}{120}{"F2DA}
\__fontawesome_def_icon:nnnnn{\faSellsy}{sellsy}{brands1}{121}{"F213}
\__fontawesome_def_icon:nnnnn{\faServer}{server}{free4}{45}{"F233}
\__fontawesome_def_icon:nnnnn{\faServicestack}{servicestack}{brands1}{122}{"F3EC}
\__fontawesome_def_icon:nnnnn{\faShapes}{shapes}{free4}{46}{"F61F}
\__fontawesome_def_icon:nnnnn{\faShare}{share}{free4}{47}{"F064}
\__fontawesome_def_icon:nnnnn{\faShareFromSquare}{share-from-square}{free4}{48}{"F14D}
\__fontawesome_def_icon:nnnnn{\faShareNodes}{share-nodes}{free4}{49}{"F1E0}
\__fontawesome_def_icon:nnnnn{\faSheetPlastic}{sheet-plastic}{free4}{50}{"E571}
\__fontawesome_def_icon:nnnnn{\faShekelSign}{shekel-sign}{free4}{51}{"F20B}
\__fontawesome_def_icon:nnnnn{\faShield}{shield}{free4}{52}{"F132}
\__fontawesome_def_icon:nnnnn{\faShieldCat}{shield-cat}{free4}{53}{"E572}
\__fontawesome_def_icon:nnnnn{\faShieldDog}{shield-dog}{free4}{54}{"E573}
\__fontawesome_def_icon:nnnnn{\faShieldHalved}{shield-halved}{free4}{55}{"F3ED}
\__fontawesome_def_icon:nnnnn{\faShieldHeart}{shield-heart}{free4}{56}{"E574}
\__fontawesome_def_icon:nnnnn{\faShieldVirus}{shield-virus}{free4}{57}{"E06C}
\__fontawesome_def_icon:nnnnn{\faShip}{ship}{free4}{58}{"F21A}
\__fontawesome_def_icon:nnnnn{\faShirt}{shirt}{free4}{59}{"F553}
\__fontawesome_def_icon:nnnnn{\faShirtsinbulk}{shirtsinbulk}{brands1}{123}{"F214}
\__fontawesome_def_icon:nnnnn{\faShoePrints}{shoe-prints}{free4}{60}{"F54B}
\__fontawesome_def_icon:nnnnn{\faShoelace}{shoelace}{brands1}{124}{"E60C}
\__fontawesome_def_icon:nnnnn{\faShop}{shop}{free4}{61}{"F54F}
\__fontawesome_def_icon:nnnnn{\faShopLock}{shop-lock}{free4}{62}{"E4A5}
\__fontawesome_def_icon:nnnnn{\faShopSlash}{shop-slash}{free4}{63}{"E070}
\__fontawesome_def_icon:nnnnn{\faShopify}{shopify}{brands1}{125}{"E057}
\__fontawesome_def_icon:nnnnn{\faShopware}{shopware}{brands1}{126}{"F5B5}
\__fontawesome_def_icon:nnnnn{\faShower}{shower}{free4}{64}{"F2CC}
\__fontawesome_def_icon:nnnnn{\faShrimp}{shrimp}{free4}{65}{"E448}
\__fontawesome_def_icon:nnnnn{\faShuffle}{shuffle}{free4}{66}{"F074}
\__fontawesome_def_icon:nnnnn{\faShuttleSpace}{shuttle-space}{free4}{67}{"F197}
\__fontawesome_def_icon:nnnnn{\faSignHanging}{sign-hanging}{free4}{68}{"F4D9}
\__fontawesome_def_icon:nnnnn{\faSignal}{signal}{free4}{69}{"F012}
\__fontawesome_def_icon:nnnnn{\faSignalMessenger}{signal-messenger}{brands1}{127}{"E663}
\__fontawesome_def_icon:nnnnn{\faSignature}{signature}{free4}{70}{"F5B7}
\__fontawesome_def_icon:nnnnn{\faSignsPost}{signs-post}{free4}{71}{"F277}
\__fontawesome_def_icon:nnnnn{\faSimCard}{sim-card}{free4}{72}{"F7C4}
\__fontawesome_def_icon:nnnnn{\faSimplybuilt}{simplybuilt}{brands1}{128}{"F215}
\__fontawesome_def_icon:nnnnn{\faSink}{sink}{free4}{73}{"E06D}
\__fontawesome_def_icon:nnnnn{\faSistrix}{sistrix}{brands1}{129}{"F3EE}
\__fontawesome_def_icon:nnnnn{\faSitemap}{sitemap}{free4}{74}{"F0E8}
\__fontawesome_def_icon:nnnnn{\faSith}{sith}{brands1}{130}{"F512}
\__fontawesome_def_icon:nnnnn{\faSitrox}{sitrox}{brands1}{131}{"E44A}
\__fontawesome_def_icon:nnnnn{\faSketch}{sketch}{brands1}{132}{"F7C6}
\__fontawesome_def_icon:nnnnn{\faSkull}{skull}{free4}{75}{"F54C}
\__fontawesome_def_icon:nnnnn{\faSkullCrossbones}{skull-crossbones}{free4}{76}{"F714}
\__fontawesome_def_icon:nnnnn{\faSkyatlas}{skyatlas}{brands1}{133}{"F216}
\__fontawesome_def_icon:nnnnn{\faSkype}{skype}{brands1}{134}{"F17E}
\__fontawesome_def_icon:nnnnn{\faSlack}{slack}{brands1}{135}{"F198}
\__fontawesome_def_icon:nnnnn{\faSlash}{slash}{free4}{77}{"F715}
\__fontawesome_def_icon:nnnnn{\faSleigh}{sleigh}{free4}{78}{"F7CC}
\__fontawesome_def_icon:nnnnn{\faSliders}{sliders}{free4}{79}{"F1DE}
\__fontawesome_def_icon:nnnnn{\faSlideshare}{slideshare}{brands1}{136}{"F1E7}
\__fontawesome_def_icon:nnnnn{\faSmog}{smog}{free4}{80}{"F75F}
\__fontawesome_def_icon:nnnnn{\faSmoking}{smoking}{free4}{81}{"F48D}
\__fontawesome_def_icon:nnnnn{\faSnapchat}{snapchat}{brands1}{137}{"F2AB}
\__fontawesome_def_icon:nnnnn{\faSnowflake}{snowflake}{free4}{82}{"F2DC}
\__fontawesome_def_icon:nnnnn{\faSnowman}{snowman}{free4}{83}{"F7D0}
\__fontawesome_def_icon:nnnnn{\faSnowplow}{snowplow}{free4}{84}{"F7D2}
\__fontawesome_def_icon:nnnnn{\faSoap}{soap}{free4}{85}{"E06E}
\__fontawesome_def_icon:nnnnn{\faSocks}{socks}{free4}{86}{"F696}
\__fontawesome_def_icon:nnnnn{\faSolarPanel}{solar-panel}{free4}{87}{"F5BA}
\__fontawesome_def_icon:nnnnn{\faSort}{sort}{free4}{88}{"F0DC}
\__fontawesome_def_icon:nnnnn{\faSortDown}{sort-down}{free4}{89}{"F0DD}
\__fontawesome_def_icon:nnnnn{\faSortUp}{sort-up}{free4}{90}{"F0DE}
\__fontawesome_def_icon:nnnnn{\faSoundcloud}{soundcloud}{brands1}{138}{"F1BE}
\__fontawesome_def_icon:nnnnn{\faSourcetree}{sourcetree}{brands1}{139}{"F7D3}
\__fontawesome_def_icon:nnnnn{\faSpa}{spa}{free4}{91}{"F5BB}
\__fontawesome_def_icon:nnnnn{\faSpaceAwesome}{space-awesome}{brands1}{141}{"E5AC}
\__fontawesome_def_icon:nnnnn{\faSpaghettiMonsterFlying}{spaghetti-monster-flying}{free4}{93}{"F67B}
\__fontawesome_def_icon:nnnnn{\faSpeakap}{speakap}{brands1}{142}{"F3F3}
\__fontawesome_def_icon:nnnnn{\faSpeakerDeck}{speaker-deck}{brands1}{143}{"F83C}
\__fontawesome_def_icon:nnnnn{\faSpellCheck}{spell-check}{free4}{94}{"F891}
\__fontawesome_def_icon:nnnnn{\faSpider}{spider}{free4}{95}{"F717}
\__fontawesome_def_icon:nnnnn{\faSpinner}{spinner}{free4}{96}{"F110}
\__fontawesome_def_icon:nnnnn{\faSplotch}{splotch}{free4}{97}{"F5BC}
\__fontawesome_def_icon:nnnnn{\faSpoon}{spoon}{free4}{98}{"F2E5}
\__fontawesome_def_icon:nnnnn{\faSpotify}{spotify}{brands1}{144}{"F1BC}
\__fontawesome_def_icon:nnnnn{\faSprayCan}{spray-can}{free4}{99}{"F5BD}
\__fontawesome_def_icon:nnnnn{\faSprayCanSparkles}{spray-can-sparkles}{free4}{100}{"F5D0}
\__fontawesome_def_icon:nnnnn{\faSquare}{square}{free4}{101}{"F0C8}
\__fontawesome_def_icon:nnnnn{\faSquareArrowUpRight}{square-arrow-up-right}{free4}{102}{"F14C}
\__fontawesome_def_icon:nnnnn{\faSquareBehance}{square-behance}{brands1}{145}{"F1B5}
\__fontawesome_def_icon:nnnnn{\faSquareBinary}{square-binary}{free4}{103}{"E69B}
\__fontawesome_def_icon:nnnnn{\faSquareBluesky}{square-bluesky}{brands1}{146}{"E6A3}
\__fontawesome_def_icon:nnnnn{\faSquareCaretDown}{square-caret-down}{free4}{104}{"F150}
\__fontawesome_def_icon:nnnnn{\faSquareCaretLeft}{square-caret-left}{free4}{105}{"F191}
\__fontawesome_def_icon:nnnnn{\faSquareCaretRight}{square-caret-right}{free4}{106}{"F152}
\__fontawesome_def_icon:nnnnn{\faSquareCaretUp}{square-caret-up}{free4}{107}{"F151}
\__fontawesome_def_icon:nnnnn{\faSquareCheck}{square-check}{free4}{108}{"F14A}
\__fontawesome_def_icon:nnnnn{\faSquareDribbble}{square-dribbble}{brands1}{147}{"F397}
\__fontawesome_def_icon:nnnnn{\faSquareEnvelope}{square-envelope}{free4}{109}{"F199}
\__fontawesome_def_icon:nnnnn{\faSquareFacebook}{square-facebook}{brands1}{148}{"F082}
\__fontawesome_def_icon:nnnnn{\faSquareFontAwesome}{square-font-awesome}{brands1}{149}{"E5AD}
\__fontawesome_def_icon:nnnnn{\faSquareFontAwesomeStroke}{square-font-awesome-stroke}{brands1}{150}{"F35C}
\__fontawesome_def_icon:nnnnn{\faSquareFull}{square-full}{free4}{110}{"F45C}
\__fontawesome_def_icon:nnnnn{\faSquareGit}{square-git}{brands1}{151}{"F1D2}
\__fontawesome_def_icon:nnnnn{\faSquareGithub}{square-github}{brands1}{152}{"F092}
\__fontawesome_def_icon:nnnnn{\faSquareGitlab}{square-gitlab}{brands1}{153}{"E5AE}
\__fontawesome_def_icon:nnnnn{\faSquareGooglePlus}{square-google-plus}{brands1}{154}{"F0D4}
\__fontawesome_def_icon:nnnnn{\faSquareH}{square-h}{free4}{111}{"F0FD}
\__fontawesome_def_icon:nnnnn{\faSquareHackerNews}{square-hacker-news}{brands1}{155}{"F3AF}
\__fontawesome_def_icon:nnnnn{\faSquareInstagram}{square-instagram}{brands1}{156}{"E055}
\__fontawesome_def_icon:nnnnn{\faSquareJs}{square-js}{brands1}{157}{"F3B9}
\__fontawesome_def_icon:nnnnn{\faSquareLastfm}{square-lastfm}{brands1}{158}{"F203}
\__fontawesome_def_icon:nnnnn{\faSquareLetterboxd}{square-letterboxd}{brands1}{159}{"E62E}
\__fontawesome_def_icon:nnnnn{\faSquareMinus}{square-minus}{free4}{112}{"F146}
\__fontawesome_def_icon:nnnnn{\faSquareNfi}{square-nfi}{free4}{113}{"E576}
\__fontawesome_def_icon:nnnnn{\faSquareOdnoklassniki}{square-odnoklassniki}{brands1}{160}{"F264}
\__fontawesome_def_icon:nnnnn{\faSquareParking}{square-parking}{free4}{114}{"F540}
\__fontawesome_def_icon:nnnnn{\faSquarePen}{square-pen}{free4}{115}{"F14B}
\__fontawesome_def_icon:nnnnn{\faSquarePersonConfined}{square-person-confined}{free4}{116}{"E577}
\__fontawesome_def_icon:nnnnn{\faSquarePhone}{square-phone}{free4}{117}{"F098}
\__fontawesome_def_icon:nnnnn{\faSquarePhoneFlip}{square-phone-flip}{free4}{118}{"F87B}
\__fontawesome_def_icon:nnnnn{\faSquarePiedPiper}{square-pied-piper}{brands1}{161}{"E01E}
\__fontawesome_def_icon:nnnnn{\faSquarePinterest}{square-pinterest}{brands1}{162}{"F0D3}
\__fontawesome_def_icon:nnnnn{\faSquarePlus}{square-plus}{free4}{119}{"F0FE}
\__fontawesome_def_icon:nnnnn{\faSquarePollHorizontal}{square-poll-horizontal}{free4}{120}{"F682}
\__fontawesome_def_icon:nnnnn{\faSquarePollVertical}{square-poll-vertical}{free4}{121}{"F681}
\__fontawesome_def_icon:nnnnn{\faSquareReddit}{square-reddit}{brands1}{163}{"F1A2}
\__fontawesome_def_icon:nnnnn{\faSquareRootVariable}{square-root-variable}{free4}{122}{"F698}
\__fontawesome_def_icon:nnnnn{\faSquareRss}{square-rss}{free4}{123}{"F143}
\__fontawesome_def_icon:nnnnn{\faSquareShareNodes}{square-share-nodes}{free4}{124}{"F1E1}
\__fontawesome_def_icon:nnnnn{\faSquareSnapchat}{square-snapchat}{brands1}{164}{"F2AD}
\__fontawesome_def_icon:nnnnn{\faSquareSteam}{square-steam}{brands1}{165}{"F1B7}
\__fontawesome_def_icon:nnnnn{\faSquareThreads}{square-threads}{brands1}{166}{"E619}
\__fontawesome_def_icon:nnnnn{\faSquareTumblr}{square-tumblr}{brands1}{167}{"F174}
\__fontawesome_def_icon:nnnnn{\faSquareTwitter}{square-twitter}{brands1}{168}{"F081}
\__fontawesome_def_icon:nnnnn{\faSquareUpRight}{square-up-right}{free4}{125}{"F360}
\__fontawesome_def_icon:nnnnn{\faSquareUpwork}{square-upwork}{brands1}{169}{"E67C}
\__fontawesome_def_icon:nnnnn{\faSquareViadeo}{square-viadeo}{brands1}{170}{"F2AA}
\__fontawesome_def_icon:nnnnn{\faSquareVimeo}{square-vimeo}{brands1}{171}{"F194}
\__fontawesome_def_icon:nnnnn{\faSquareVirus}{square-virus}{free4}{126}{"E578}
\__fontawesome_def_icon:nnnnn{\faSquareWebAwesome}{square-web-awesome}{brands1}{172}{"E683}
\__fontawesome_def_icon:nnnnn{\faSquareWebAwesomeStroke}{square-web-awesome-stroke}{brands1}{173}{"E684}
\__fontawesome_def_icon:nnnnn{\faSquareWhatsapp}{square-whatsapp}{brands1}{174}{"F40C}
\__fontawesome_def_icon:nnnnn{\faSquareXTwitter}{square-x-twitter}{brands1}{175}{"E61A}
\__fontawesome_def_icon:nnnnn{\faSquareXing}{square-xing}{brands1}{176}{"F169}
\__fontawesome_def_icon:nnnnn{\faSquareXmark}{square-xmark}{free4}{127}{"F2D3}
\__fontawesome_def_icon:nnnnn{\faSquareYoutube}{square-youtube}{brands1}{177}{"F431}
\__fontawesome_def_icon:nnnnn{\faSquarespace}{squarespace}{brands1}{178}{"F5BE}
\__fontawesome_def_icon:nnnnn{\faStackExchange}{stack-exchange}{brands1}{179}{"F18D}
\__fontawesome_def_icon:nnnnn{\faStackOverflow}{stack-overflow}{brands1}{180}{"F16C}
\__fontawesome_def_icon:nnnnn{\faStackpath}{stackpath}{brands1}{181}{"F842}
\__fontawesome_def_icon:nnnnn{\faStaffSnake}{staff-snake}{free4}{128}{"E579}
\__fontawesome_def_icon:nnnnn{\faStairs}{stairs}{free4}{129}{"E289}
\__fontawesome_def_icon:nnnnn{\faStamp}{stamp}{free4}{130}{"F5BF}
\__fontawesome_def_icon:nnnnn{\faStapler}{stapler}{free4}{131}{"E5AF}
\__fontawesome_def_icon:nnnnn{\faStar}{star}{free4}{132}{"F005}
\__fontawesome_def_icon:nnnnn{\faStarAndCrescent}{star-and-crescent}{free4}{133}{"F699}
\__fontawesome_def_icon:nnnnn{\faStarHalf}{star-half}{free4}{134}{"F089}
\__fontawesome_def_icon:nnnnn{\faStarHalfStroke}{star-half-stroke}{free4}{135}{"F5C0}
\__fontawesome_def_icon:nnnnn{\faStarOfDavid}{star-of-david}{free4}{136}{"F69A}
\__fontawesome_def_icon:nnnnn{\faStarOfLife}{star-of-life}{free4}{137}{"F621}
\__fontawesome_def_icon:nnnnn{\faStaylinked}{staylinked}{brands1}{182}{"F3F5}
\__fontawesome_def_icon:nnnnn{\faSteam}{steam}{brands1}{183}{"F1B6}
\__fontawesome_def_icon:nnnnn{\faSteamSymbol}{steam-symbol}{brands1}{184}{"F3F6}
\__fontawesome_def_icon:nnnnn{\faSterlingSign}{sterling-sign}{free4}{138}{"F154}
\__fontawesome_def_icon:nnnnn{\faStethoscope}{stethoscope}{free4}{139}{"F0F1}
\__fontawesome_def_icon:nnnnn{\faStickerMule}{sticker-mule}{brands1}{185}{"F3F7}
\__fontawesome_def_icon:nnnnn{\faStop}{stop}{free4}{140}{"F04D}
\__fontawesome_def_icon:nnnnn{\faStopwatch}{stopwatch}{free4}{141}{"F2F2}
\__fontawesome_def_icon:nnnnn{}{stopwatch-20}{free4}{142}{"E06F}
\__fontawesome_def_icon:nnnnn{\faStore}{store}{free4}{143}{"F54E}
\__fontawesome_def_icon:nnnnn{\faStoreSlash}{store-slash}{free4}{144}{"E071}
\__fontawesome_def_icon:nnnnn{\faStrava}{strava}{brands1}{186}{"F428}
\__fontawesome_def_icon:nnnnn{\faStreetView}{street-view}{free4}{145}{"F21D}
\__fontawesome_def_icon:nnnnn{\faStrikethrough}{strikethrough}{free4}{146}{"F0CC}
\__fontawesome_def_icon:nnnnn{\faStripe}{stripe}{brands1}{187}{"F429}
\__fontawesome_def_icon:nnnnn{\faStripeS}{stripe-s}{brands1}{188}{"F42A}
\__fontawesome_def_icon:nnnnn{\faStroopwafel}{stroopwafel}{free4}{147}{"F551}
\__fontawesome_def_icon:nnnnn{\faStubber}{stubber}{brands1}{189}{"E5C7}
\__fontawesome_def_icon:nnnnn{\faStudiovinari}{studiovinari}{brands1}{190}{"F3F8}
\__fontawesome_def_icon:nnnnn{\faStumbleupon}{stumbleupon}{brands1}{191}{"F1A4}
\__fontawesome_def_icon:nnnnn{\faStumbleuponCircle}{stumbleupon-circle}{brands1}{192}{"F1A3}
\__fontawesome_def_icon:nnnnn{\faSubscript}{subscript}{free4}{148}{"F12C}
\__fontawesome_def_icon:nnnnn{\faSuitcase}{suitcase}{free4}{149}{"F0F2}
\__fontawesome_def_icon:nnnnn{\faSuitcaseMedical}{suitcase-medical}{free4}{150}{"F0FA}
\__fontawesome_def_icon:nnnnn{\faSuitcaseRolling}{suitcase-rolling}{free4}{151}{"F5C1}
\__fontawesome_def_icon:nnnnn{\faSun}{sun}{free4}{152}{"F185}
\__fontawesome_def_icon:nnnnn{\faSunPlantWilt}{sun-plant-wilt}{free4}{153}{"E57A}
\__fontawesome_def_icon:nnnnn{\faSuperpowers}{superpowers}{brands1}{193}{"F2DD}
\__fontawesome_def_icon:nnnnn{\faSuperscript}{superscript}{free4}{154}{"F12B}
\__fontawesome_def_icon:nnnnn{\faSupple}{supple}{brands1}{194}{"F3F9}
\__fontawesome_def_icon:nnnnn{\faSuse}{suse}{brands1}{195}{"F7D6}
\__fontawesome_def_icon:nnnnn{\faSwatchbook}{swatchbook}{free4}{155}{"F5C3}
\__fontawesome_def_icon:nnnnn{\faSwift}{swift}{brands1}{196}{"F8E1}
\__fontawesome_def_icon:nnnnn{\faSymfony}{symfony}{brands1}{197}{"F83D}
\__fontawesome_def_icon:nnnnn{\faSynagogue}{synagogue}{free4}{156}{"F69B}
\__fontawesome_def_icon:nnnnn{\faSyringe}{syringe}{free4}{157}{"F48E}
\__fontawesome_def_icon:nnnnn{\faT}{t}{free4}{158}{"54}
\__fontawesome_def_icon:nnnnn{\faTable}{table}{free4}{159}{"F0CE}
\__fontawesome_def_icon:nnnnn{\faTableCells}{table-cells}{free4}{160}{"F00A}
\__fontawesome_def_icon:nnnnn{\faTableCellsColumnLock}{table-cells-column-lock}{free4}{161}{"E678}
\__fontawesome_def_icon:nnnnn{\faTableCellsLarge}{table-cells-large}{free4}{162}{"F009}
\__fontawesome_def_icon:nnnnn{\faTableCellsRowLock}{table-cells-row-lock}{free4}{163}{"E67A}
\__fontawesome_def_icon:nnnnn{\faTableCellsRowUnlock}{table-cells-row-unlock}{free4}{164}{"E691}
\__fontawesome_def_icon:nnnnn{\faTableColumns}{table-columns}{free4}{165}{"F0DB}
\__fontawesome_def_icon:nnnnn{\faTableList}{table-list}{free4}{166}{"F00B}
\__fontawesome_def_icon:nnnnn{\faTableTennisPaddleBall}{table-tennis-paddle-ball}{free4}{167}{"F45D}
\__fontawesome_def_icon:nnnnn{\faTablet}{tablet}{free4}{168}{"F3FB}
\__fontawesome_def_icon:nnnnn{\faTabletButton}{tablet-button}{free4}{169}{"F10A}
\__fontawesome_def_icon:nnnnn{\faTabletScreenButton}{tablet-screen-button}{free4}{170}{"F3FA}
\__fontawesome_def_icon:nnnnn{\faTablets}{tablets}{free4}{171}{"F490}
\__fontawesome_def_icon:nnnnn{\faTachographDigital}{tachograph-digital}{free4}{172}{"F566}
\__fontawesome_def_icon:nnnnn{\faTag}{tag}{free4}{173}{"F02B}
\__fontawesome_def_icon:nnnnn{\faTags}{tags}{free4}{174}{"F02C}
\__fontawesome_def_icon:nnnnn{\faTape}{tape}{free4}{175}{"F4DB}
\__fontawesome_def_icon:nnnnn{\faTarp}{tarp}{free4}{176}{"E57B}
\__fontawesome_def_icon:nnnnn{\faTarpDroplet}{tarp-droplet}{free4}{177}{"E57C}
\__fontawesome_def_icon:nnnnn{\faTaxi}{taxi}{free4}{178}{"F1BA}
\__fontawesome_def_icon:nnnnn{\faTeamspeak}{teamspeak}{brands1}{199}{"F4F9}
\__fontawesome_def_icon:nnnnn{\faTeeth}{teeth}{free4}{179}{"F62E}
\__fontawesome_def_icon:nnnnn{\faTeethOpen}{teeth-open}{free4}{180}{"F62F}
\__fontawesome_def_icon:nnnnn{\faTelegram}{telegram}{brands1}{200}{"F2C6}
\__fontawesome_def_icon:nnnnn{\faTemperatureArrowDown}{temperature-arrow-down}{free4}{181}{"E03F}
\__fontawesome_def_icon:nnnnn{\faTemperatureArrowUp}{temperature-arrow-up}{free4}{182}{"E040}
\__fontawesome_def_icon:nnnnn{\faTemperatureEmpty}{temperature-empty}{free4}{183}{"F2CB}
\__fontawesome_def_icon:nnnnn{\faTemperatureFull}{temperature-full}{free4}{184}{"F2C7}
\__fontawesome_def_icon:nnnnn{\faTemperatureHalf}{temperature-half}{free4}{185}{"F2C9}
\__fontawesome_def_icon:nnnnn{\faTemperatureHigh}{temperature-high}{free4}{186}{"F769}
\__fontawesome_def_icon:nnnnn{\faTemperatureLow}{temperature-low}{free4}{187}{"F76B}
\__fontawesome_def_icon:nnnnn{\faTemperatureQuarter}{temperature-quarter}{free4}{188}{"F2CA}
\__fontawesome_def_icon:nnnnn{\faTemperatureThreeQuarters}{temperature-three-quarters}{free4}{189}{"F2C8}
\__fontawesome_def_icon:nnnnn{\faTencentWeibo}{tencent-weibo}{brands1}{201}{"F1D5}
\__fontawesome_def_icon:nnnnn{\faTengeSign}{tenge-sign}{free4}{190}{"F7D7}
\__fontawesome_def_icon:nnnnn{\faTent}{tent}{free4}{191}{"E57D}
\__fontawesome_def_icon:nnnnn{\faTentArrowDownToLine}{tent-arrow-down-to-line}{free4}{192}{"E57E}
\__fontawesome_def_icon:nnnnn{\faTentArrowLeftRight}{tent-arrow-left-right}{free4}{193}{"E57F}
\__fontawesome_def_icon:nnnnn{\faTentArrowTurnLeft}{tent-arrow-turn-left}{free4}{194}{"E580}
\__fontawesome_def_icon:nnnnn{\faTentArrowsDown}{tent-arrows-down}{free4}{195}{"E581}
\__fontawesome_def_icon:nnnnn{\faTents}{tents}{free4}{196}{"E582}
\__fontawesome_def_icon:nnnnn{\faTerminal}{terminal}{free4}{197}{"F120}
\__fontawesome_def_icon:nnnnn{\faTextHeight}{text-height}{free4}{198}{"F034}
\__fontawesome_def_icon:nnnnn{\faTextSlash}{text-slash}{free4}{199}{"F87D}
\__fontawesome_def_icon:nnnnn{\faTextWidth}{text-width}{free4}{200}{"F035}
\__fontawesome_def_icon:nnnnn{\faTheRedYeti}{the-red-yeti}{brands1}{202}{"F69D}
\__fontawesome_def_icon:nnnnn{\faThemeco}{themeco}{brands1}{203}{"F5C6}
\__fontawesome_def_icon:nnnnn{\faThemeisle}{themeisle}{brands1}{204}{"F2B2}
\__fontawesome_def_icon:nnnnn{\faThermometer}{thermometer}{free4}{201}{"F491}
\__fontawesome_def_icon:nnnnn{\faThinkPeaks}{think-peaks}{brands1}{205}{"F731}
\__fontawesome_def_icon:nnnnn{\faThreads}{threads}{brands1}{206}{"E618}
\__fontawesome_def_icon:nnnnn{\faThumbsDown}{thumbs-down}{free4}{202}{"F165}
\__fontawesome_def_icon:nnnnn{\faThumbsUp}{thumbs-up}{free4}{203}{"F164}
\__fontawesome_def_icon:nnnnn{\faThumbtack}{thumbtack}{free4}{204}{"F08D}
\__fontawesome_def_icon:nnnnn{\faThumbtackSlash}{thumbtack-slash}{free4}{205}{"E68F}
\__fontawesome_def_icon:nnnnn{\faTicket}{ticket}{free4}{206}{"F145}
\__fontawesome_def_icon:nnnnn{\faTicketSimple}{ticket-simple}{free4}{207}{"F3FF}
\__fontawesome_def_icon:nnnnn{\faTiktok}{tiktok}{brands1}{207}{"E07B}
\__fontawesome_def_icon:nnnnn{\faTimeline}{timeline}{free4}{208}{"E29C}
\__fontawesome_def_icon:nnnnn{\faToggleOff}{toggle-off}{free4}{209}{"F204}
\__fontawesome_def_icon:nnnnn{\faToggleOn}{toggle-on}{free4}{210}{"F205}
\__fontawesome_def_icon:nnnnn{\faToilet}{toilet}{free4}{211}{"F7D8}
\__fontawesome_def_icon:nnnnn{\faToiletPaper}{toilet-paper}{free4}{212}{"F71E}
\__fontawesome_def_icon:nnnnn{\faToiletPaperSlash}{toilet-paper-slash}{free4}{213}{"E072}
\__fontawesome_def_icon:nnnnn{\faToiletPortable}{toilet-portable}{free4}{214}{"E583}
\__fontawesome_def_icon:nnnnn{\faToiletsPortable}{toilets-portable}{free4}{215}{"E584}
\__fontawesome_def_icon:nnnnn{\faToolbox}{toolbox}{free4}{216}{"F552}
\__fontawesome_def_icon:nnnnn{\faTooth}{tooth}{free4}{217}{"F5C9}
\__fontawesome_def_icon:nnnnn{\faToriiGate}{torii-gate}{free4}{218}{"F6A1}
\__fontawesome_def_icon:nnnnn{\faTornado}{tornado}{free4}{219}{"F76F}
\__fontawesome_def_icon:nnnnn{\faTowerBroadcast}{tower-broadcast}{free4}{220}{"F519}
\__fontawesome_def_icon:nnnnn{\faTowerCell}{tower-cell}{free4}{221}{"E585}
\__fontawesome_def_icon:nnnnn{\faTowerObservation}{tower-observation}{free4}{222}{"E586}
\__fontawesome_def_icon:nnnnn{\faTractor}{tractor}{free4}{223}{"F722}
\__fontawesome_def_icon:nnnnn{\faTradeFederation}{trade-federation}{brands1}{208}{"F513}
\__fontawesome_def_icon:nnnnn{\faTrademark}{trademark}{free4}{224}{"F25C}
\__fontawesome_def_icon:nnnnn{\faTrafficLight}{traffic-light}{free4}{225}{"F637}
\__fontawesome_def_icon:nnnnn{\faTrailer}{trailer}{free4}{226}{"E041}
\__fontawesome_def_icon:nnnnn{\faTrain}{train}{free4}{227}{"F238}
\__fontawesome_def_icon:nnnnn{\faTrainSubway}{train-subway}{free4}{228}{"F239}
\__fontawesome_def_icon:nnnnn{\faTrainTram}{train-tram}{free4}{229}{"E5B4}
\__fontawesome_def_icon:nnnnn{\faTransgender}{transgender}{free4}{230}{"F225}
\__fontawesome_def_icon:nnnnn{\faTrash}{trash}{free4}{231}{"F1F8}
\__fontawesome_def_icon:nnnnn{\faTrashArrowUp}{trash-arrow-up}{free4}{232}{"F829}
\__fontawesome_def_icon:nnnnn{\faTrashCan}{trash-can}{free4}{233}{"F2ED}
\__fontawesome_def_icon:nnnnn{\faTrashCanArrowUp}{trash-can-arrow-up}{free4}{234}{"F82A}
\__fontawesome_def_icon:nnnnn{\faTree}{tree}{free4}{235}{"F1BB}
\__fontawesome_def_icon:nnnnn{\faTreeCity}{tree-city}{free4}{236}{"E587}
\__fontawesome_def_icon:nnnnn{\faTrello}{trello}{brands1}{209}{"F181}
\__fontawesome_def_icon:nnnnn{\faTriangleExclamation}{triangle-exclamation}{free4}{237}{"F071}
\__fontawesome_def_icon:nnnnn{\faTrophy}{trophy}{free4}{238}{"F091}
\__fontawesome_def_icon:nnnnn{\faTrowel}{trowel}{free4}{239}{"E589}
\__fontawesome_def_icon:nnnnn{\faTrowelBricks}{trowel-bricks}{free4}{240}{"E58A}
\__fontawesome_def_icon:nnnnn{\faTruck}{truck}{free4}{241}{"F0D1}
\__fontawesome_def_icon:nnnnn{\faTruckArrowRight}{truck-arrow-right}{free4}{242}{"E58B}
\__fontawesome_def_icon:nnnnn{\faTruckDroplet}{truck-droplet}{free4}{243}{"E58C}
\__fontawesome_def_icon:nnnnn{\faTruckFast}{truck-fast}{free4}{244}{"F48B}
\__fontawesome_def_icon:nnnnn{\faTruckField}{truck-field}{free4}{245}{"E58D}
\__fontawesome_def_icon:nnnnn{\faTruckFieldUn}{truck-field-un}{free4}{246}{"E58E}
\__fontawesome_def_icon:nnnnn{\faTruckFront}{truck-front}{free4}{247}{"E2B7}
\__fontawesome_def_icon:nnnnn{\faTruckMedical}{truck-medical}{free4}{248}{"F0F9}
\__fontawesome_def_icon:nnnnn{\faTruckMonster}{truck-monster}{free4}{249}{"F63B}
\__fontawesome_def_icon:nnnnn{\faTruckMoving}{truck-moving}{free4}{250}{"F4DF}
\__fontawesome_def_icon:nnnnn{\faTruckPickup}{truck-pickup}{free4}{251}{"F63C}
\__fontawesome_def_icon:nnnnn{\faTruckPlane}{truck-plane}{free4}{252}{"E58F}
\__fontawesome_def_icon:nnnnn{\faTruckRampBox}{truck-ramp-box}{free4}{253}{"F4DE}
\__fontawesome_def_icon:nnnnn{\faTty}{tty}{free4}{254}{"F1E4}
\__fontawesome_def_icon:nnnnn{\faTumblr}{tumblr}{brands1}{210}{"F173}
\__fontawesome_def_icon:nnnnn{\faTurkishLiraSign}{turkish-lira-sign}{free4}{255}{"E2BB}
\__fontawesome_def_icon:nnnnn{\faTurnDown}{turn-down}{free5}{0}{"F3BE}
\__fontawesome_def_icon:nnnnn{\faTurnUp}{turn-up}{free5}{1}{"F3BF}
\__fontawesome_def_icon:nnnnn{\faTv}{tv}{free5}{2}{"F26C}
\__fontawesome_def_icon:nnnnn{\faTwitch}{twitch}{brands1}{211}{"F1E8}
\__fontawesome_def_icon:nnnnn{\faTwitter}{twitter}{brands1}{212}{"F099}
\__fontawesome_def_icon:nnnnn{}{typo3}{brands1}{213}{"F42B}
\__fontawesome_def_icon:nnnnn{\faU}{u}{free5}{3}{"55}
\__fontawesome_def_icon:nnnnn{\faUber}{uber}{brands1}{215}{"F402}
\__fontawesome_def_icon:nnnnn{\faUbuntu}{ubuntu}{brands1}{216}{"F7DF}
\__fontawesome_def_icon:nnnnn{\faUikit}{uikit}{brands1}{217}{"F403}
\__fontawesome_def_icon:nnnnn{\faUmbraco}{umbraco}{brands1}{218}{"F8E8}
\__fontawesome_def_icon:nnnnn{\faUmbrella}{umbrella}{free5}{4}{"F0E9}
\__fontawesome_def_icon:nnnnn{\faUmbrellaBeach}{umbrella-beach}{free5}{5}{"F5CA}
\__fontawesome_def_icon:nnnnn{\faUncharted}{uncharted}{brands1}{219}{"E084}
\__fontawesome_def_icon:nnnnn{\faUnderline}{underline}{free5}{6}{"F0CD}
\__fontawesome_def_icon:nnnnn{\faUniregistry}{uniregistry}{brands1}{220}{"F404}
\__fontawesome_def_icon:nnnnn{\faUnity}{unity}{brands1}{221}{"E049}
\__fontawesome_def_icon:nnnnn{\faUniversalAccess}{universal-access}{free5}{7}{"F29A}
\__fontawesome_def_icon:nnnnn{\faUnlock}{unlock}{free5}{8}{"F09C}
\__fontawesome_def_icon:nnnnn{\faUnlockKeyhole}{unlock-keyhole}{free5}{9}{"F13E}
\__fontawesome_def_icon:nnnnn{\faUnsplash}{unsplash}{brands1}{222}{"E07C}
\__fontawesome_def_icon:nnnnn{\faUntappd}{untappd}{brands1}{223}{"F405}
\__fontawesome_def_icon:nnnnn{\faUpDown}{up-down}{free5}{10}{"F338}
\__fontawesome_def_icon:nnnnn{\faUpDownLeftRight}{up-down-left-right}{free5}{11}{"F0B2}
\__fontawesome_def_icon:nnnnn{\faUpLong}{up-long}{free5}{12}{"F30C}
\__fontawesome_def_icon:nnnnn{\faUpRightAndDownLeftFromCenter}{up-right-and-down-left-from-center}{free5}{13}{"F424}
\__fontawesome_def_icon:nnnnn{\faUpRightFromSquare}{up-right-from-square}{free5}{14}{"F35D}
\__fontawesome_def_icon:nnnnn{\faUpload}{upload}{free5}{15}{"F093}
\__fontawesome_def_icon:nnnnn{\faUps}{ups}{brands1}{224}{"F7E0}
\__fontawesome_def_icon:nnnnn{\faUpwork}{upwork}{brands1}{225}{"E641}
\__fontawesome_def_icon:nnnnn{\faUsb}{usb}{brands1}{226}{"F287}
\__fontawesome_def_icon:nnnnn{\faUser}{user}{free5}{16}{"F007}
\__fontawesome_def_icon:nnnnn{\faUserAstronaut}{user-astronaut}{free5}{17}{"F4FB}
\__fontawesome_def_icon:nnnnn{\faUserCheck}{user-check}{free5}{18}{"F4FC}
\__fontawesome_def_icon:nnnnn{\faUserClock}{user-clock}{free5}{19}{"F4FD}
\__fontawesome_def_icon:nnnnn{\faUserDoctor}{user-doctor}{free5}{20}{"F0F0}
\__fontawesome_def_icon:nnnnn{\faUserGear}{user-gear}{free5}{21}{"F4FE}
\__fontawesome_def_icon:nnnnn{\faUserGraduate}{user-graduate}{free5}{22}{"F501}
\__fontawesome_def_icon:nnnnn{\faUserGroup}{user-group}{free5}{23}{"F500}
\__fontawesome_def_icon:nnnnn{\faUserInjured}{user-injured}{free5}{24}{"F728}
\__fontawesome_def_icon:nnnnn{\faUserLarge}{user-large}{free5}{25}{"F406}
\__fontawesome_def_icon:nnnnn{\faUserLargeSlash}{user-large-slash}{free5}{26}{"F4FA}
\__fontawesome_def_icon:nnnnn{\faUserLock}{user-lock}{free5}{27}{"F502}
\__fontawesome_def_icon:nnnnn{\faUserMinus}{user-minus}{free5}{28}{"F503}
\__fontawesome_def_icon:nnnnn{\faUserNinja}{user-ninja}{free5}{29}{"F504}
\__fontawesome_def_icon:nnnnn{\faUserNurse}{user-nurse}{free5}{30}{"F82F}
\__fontawesome_def_icon:nnnnn{\faUserPen}{user-pen}{free5}{31}{"F4FF}
\__fontawesome_def_icon:nnnnn{\faUserPlus}{user-plus}{free5}{32}{"F234}
\__fontawesome_def_icon:nnnnn{\faUserSecret}{user-secret}{free5}{33}{"F21B}
\__fontawesome_def_icon:nnnnn{\faUserShield}{user-shield}{free5}{34}{"F505}
\__fontawesome_def_icon:nnnnn{\faUserSlash}{user-slash}{free5}{35}{"F506}
\__fontawesome_def_icon:nnnnn{\faUserTag}{user-tag}{free5}{36}{"F507}
\__fontawesome_def_icon:nnnnn{\faUserTie}{user-tie}{free5}{37}{"F508}
\__fontawesome_def_icon:nnnnn{\faUserXmark}{user-xmark}{free5}{38}{"F235}
\__fontawesome_def_icon:nnnnn{\faUsers}{users}{free5}{39}{"F0C0}
\__fontawesome_def_icon:nnnnn{\faUsersBetweenLines}{users-between-lines}{free5}{40}{"E591}
\__fontawesome_def_icon:nnnnn{\faUsersGear}{users-gear}{free5}{41}{"F509}
\__fontawesome_def_icon:nnnnn{\faUsersLine}{users-line}{free5}{42}{"E592}
\__fontawesome_def_icon:nnnnn{\faUsersRays}{users-rays}{free5}{43}{"E593}
\__fontawesome_def_icon:nnnnn{\faUsersRectangle}{users-rectangle}{free5}{44}{"E594}
\__fontawesome_def_icon:nnnnn{\faUsersSlash}{users-slash}{free5}{45}{"E073}
\__fontawesome_def_icon:nnnnn{\faUsersViewfinder}{users-viewfinder}{free5}{46}{"E595}
\__fontawesome_def_icon:nnnnn{\faUsps}{usps}{brands1}{227}{"F7E1}
\__fontawesome_def_icon:nnnnn{\faUssunnah}{ussunnah}{brands1}{228}{"F407}
\__fontawesome_def_icon:nnnnn{\faUtensils}{utensils}{free5}{47}{"F2E7}
\__fontawesome_def_icon:nnnnn{\faV}{v}{free5}{48}{"56}
\__fontawesome_def_icon:nnnnn{\faVaadin}{vaadin}{brands1}{230}{"F408}
\__fontawesome_def_icon:nnnnn{\faVanShuttle}{van-shuttle}{free5}{49}{"F5B6}
\__fontawesome_def_icon:nnnnn{\faVault}{vault}{free5}{50}{"E2C5}
\__fontawesome_def_icon:nnnnn{\faVectorSquare}{vector-square}{free5}{51}{"F5CB}
\__fontawesome_def_icon:nnnnn{\faVenus}{venus}{free5}{52}{"F221}
\__fontawesome_def_icon:nnnnn{\faVenusDouble}{venus-double}{free5}{53}{"F226}
\__fontawesome_def_icon:nnnnn{\faVenusMars}{venus-mars}{free5}{54}{"F228}
\__fontawesome_def_icon:nnnnn{\faVest}{vest}{free5}{55}{"E085}
\__fontawesome_def_icon:nnnnn{\faVestPatches}{vest-patches}{free5}{56}{"E086}
\__fontawesome_def_icon:nnnnn{\faViacoin}{viacoin}{brands1}{231}{"F237}
\__fontawesome_def_icon:nnnnn{\faViadeo}{viadeo}{brands1}{232}{"F2A9}
\__fontawesome_def_icon:nnnnn{\faVial}{vial}{free5}{57}{"F492}
\__fontawesome_def_icon:nnnnn{\faVialCircleCheck}{vial-circle-check}{free5}{58}{"E596}
\__fontawesome_def_icon:nnnnn{\faVialVirus}{vial-virus}{free5}{59}{"E597}
\__fontawesome_def_icon:nnnnn{\faVials}{vials}{free5}{60}{"F493}
\__fontawesome_def_icon:nnnnn{\faViber}{viber}{brands1}{233}{"F409}
\__fontawesome_def_icon:nnnnn{\faVideo}{video}{free5}{61}{"F03D}
\__fontawesome_def_icon:nnnnn{\faVideoSlash}{video-slash}{free5}{62}{"F4E2}
\__fontawesome_def_icon:nnnnn{\faVihara}{vihara}{free5}{63}{"F6A7}
\__fontawesome_def_icon:nnnnn{\faVimeo}{vimeo}{brands1}{234}{"F40A}
\__fontawesome_def_icon:nnnnn{\faVimeoV}{vimeo-v}{brands1}{235}{"F27D}
\__fontawesome_def_icon:nnnnn{\faVine}{vine}{brands1}{236}{"F1CA}
\__fontawesome_def_icon:nnnnn{\faVirus}{virus}{free5}{64}{"E074}
\__fontawesome_def_icon:nnnnn{\faVirusCovid}{virus-covid}{free5}{65}{"E4A8}
\__fontawesome_def_icon:nnnnn{\faVirusCovidSlash}{virus-covid-slash}{free5}{66}{"E4A9}
\__fontawesome_def_icon:nnnnn{\faVirusSlash}{virus-slash}{free5}{67}{"E075}
\__fontawesome_def_icon:nnnnn{\faViruses}{viruses}{free5}{68}{"E076}
\__fontawesome_def_icon:nnnnn{\faVk}{vk}{brands1}{237}{"F189}
\__fontawesome_def_icon:nnnnn{\faVnv}{vnv}{brands1}{238}{"F40B}
\__fontawesome_def_icon:nnnnn{\faVoicemail}{voicemail}{free5}{69}{"F897}
\__fontawesome_def_icon:nnnnn{\faVolcano}{volcano}{free5}{70}{"F770}
\__fontawesome_def_icon:nnnnn{\faVolleyball}{volleyball}{free5}{71}{"F45F}
\__fontawesome_def_icon:nnnnn{\faVolumeHigh}{volume-high}{free5}{72}{"F028}
\__fontawesome_def_icon:nnnnn{\faVolumeLow}{volume-low}{free5}{73}{"F027}
\__fontawesome_def_icon:nnnnn{\faVolumeOff}{volume-off}{free5}{74}{"F026}
\__fontawesome_def_icon:nnnnn{\faVolumeXmark}{volume-xmark}{free5}{75}{"F6A9}
\__fontawesome_def_icon:nnnnn{\faVrCardboard}{vr-cardboard}{free5}{76}{"F729}
\__fontawesome_def_icon:nnnnn{\faVuejs}{vuejs}{brands1}{239}{"F41F}
\__fontawesome_def_icon:nnnnn{\faW}{w}{free5}{77}{"57}
\__fontawesome_def_icon:nnnnn{\faWalkieTalkie}{walkie-talkie}{free5}{78}{"F8EF}
\__fontawesome_def_icon:nnnnn{\faWallet}{wallet}{free5}{79}{"F555}
\__fontawesome_def_icon:nnnnn{\faWandMagic}{wand-magic}{free5}{80}{"F0D0}
\__fontawesome_def_icon:nnnnn{\faWandMagicSparkles}{wand-magic-sparkles}{free5}{81}{"E2CA}
\__fontawesome_def_icon:nnnnn{\faWandSparkles}{wand-sparkles}{free5}{82}{"F72B}
\__fontawesome_def_icon:nnnnn{\faWarehouse}{warehouse}{free5}{83}{"F494}
\__fontawesome_def_icon:nnnnn{\faWatchmanMonitoring}{watchman-monitoring}{brands1}{241}{"E087}
\__fontawesome_def_icon:nnnnn{\faWater}{water}{free5}{84}{"F773}
\__fontawesome_def_icon:nnnnn{\faWaterLadder}{water-ladder}{free5}{85}{"F5C5}
\__fontawesome_def_icon:nnnnn{\faWaveSquare}{wave-square}{free5}{86}{"F83E}
\__fontawesome_def_icon:nnnnn{\faWaze}{waze}{brands1}{242}{"F83F}
\__fontawesome_def_icon:nnnnn{\faWebAwesome}{web-awesome}{free5}{87}{"E682}
\__fontawesome_def_icon:nnnnn{\faWebflow}{webflow}{brands1}{244}{"E65C}
\__fontawesome_def_icon:nnnnn{\faWeebly}{weebly}{brands1}{245}{"F5CC}
\__fontawesome_def_icon:nnnnn{\faWeibo}{weibo}{brands1}{246}{"F18A}
\__fontawesome_def_icon:nnnnn{\faWeightHanging}{weight-hanging}{free5}{88}{"F5CD}
\__fontawesome_def_icon:nnnnn{\faWeightScale}{weight-scale}{free5}{89}{"F496}
\__fontawesome_def_icon:nnnnn{\faWeixin}{weixin}{brands1}{247}{"F1D7}
\__fontawesome_def_icon:nnnnn{\faWhatsapp}{whatsapp}{brands1}{248}{"F232}
\__fontawesome_def_icon:nnnnn{\faWheatAwn}{wheat-awn}{free5}{90}{"E2CD}
\__fontawesome_def_icon:nnnnn{\faWheatAwnCircleExclamation}{wheat-awn-circle-exclamation}{free5}{91}{"E598}
\__fontawesome_def_icon:nnnnn{\faWheelchair}{wheelchair}{free5}{92}{"F193}
\__fontawesome_def_icon:nnnnn{\faWheelchairMove}{wheelchair-move}{free5}{93}{"E2CE}
\__fontawesome_def_icon:nnnnn{\faWhiskeyGlass}{whiskey-glass}{free5}{94}{"F7A0}
\__fontawesome_def_icon:nnnnn{\faWhmcs}{whmcs}{brands1}{249}{"F40D}
\__fontawesome_def_icon:nnnnn{\faWifi}{wifi}{free5}{95}{"F1EB}
\__fontawesome_def_icon:nnnnn{\faWikipediaW}{wikipedia-w}{brands1}{250}{"F266}
\__fontawesome_def_icon:nnnnn{\faWind}{wind}{free5}{96}{"F72E}
\__fontawesome_def_icon:nnnnn{\faWindowMaximize}{window-maximize}{free5}{97}{"F2D0}
\__fontawesome_def_icon:nnnnn{\faWindowMinimize}{window-minimize}{free5}{98}{"F2D1}
\__fontawesome_def_icon:nnnnn{\faWindowRestore}{window-restore}{free5}{99}{"F2D2}
\__fontawesome_def_icon:nnnnn{\faWindows}{windows}{brands1}{251}{"F17A}
\__fontawesome_def_icon:nnnnn{\faWineBottle}{wine-bottle}{free5}{100}{"F72F}
\__fontawesome_def_icon:nnnnn{\faWineGlass}{wine-glass}{free5}{101}{"F4E3}
\__fontawesome_def_icon:nnnnn{\faWineGlassEmpty}{wine-glass-empty}{free5}{102}{"F5CE}
\__fontawesome_def_icon:nnnnn{\faWirsindhandwerk}{wirsindhandwerk}{brands1}{252}{"E2D0}
\__fontawesome_def_icon:nnnnn{\faWix}{wix}{brands1}{253}{"F5CF}
\__fontawesome_def_icon:nnnnn{\faWizardsOfTheCoast}{wizards-of-the-coast}{brands1}{254}{"F730}
\__fontawesome_def_icon:nnnnn{\faWodu}{wodu}{brands1}{255}{"E088}
\__fontawesome_def_icon:nnnnn{\faWolfPackBattalion}{wolf-pack-battalion}{brands2}{0}{"F514}
\__fontawesome_def_icon:nnnnn{\faWonSign}{won-sign}{free5}{103}{"F159}
\__fontawesome_def_icon:nnnnn{\faWordpress}{wordpress}{brands2}{1}{"F19A}
\__fontawesome_def_icon:nnnnn{\faWordpressSimple}{wordpress-simple}{brands2}{2}{"F411}
\__fontawesome_def_icon:nnnnn{\faWorm}{worm}{free5}{104}{"E599}
\__fontawesome_def_icon:nnnnn{\faWpbeginner}{wpbeginner}{brands2}{3}{"F297}
\__fontawesome_def_icon:nnnnn{\faWpexplorer}{wpexplorer}{brands2}{4}{"F2DE}
\__fontawesome_def_icon:nnnnn{\faWpforms}{wpforms}{brands2}{5}{"F298}
\__fontawesome_def_icon:nnnnn{\faWpressr}{wpressr}{brands2}{6}{"F3E4}
\__fontawesome_def_icon:nnnnn{\faWrench}{wrench}{free5}{105}{"F0AD}
\__fontawesome_def_icon:nnnnn{\faX}{x}{free5}{106}{"58}
\__fontawesome_def_icon:nnnnn{\faXRay}{x-ray}{free5}{107}{"F497}
\__fontawesome_def_icon:nnnnn{\faXTwitter}{x-twitter}{brands2}{8}{"E61B}
\__fontawesome_def_icon:nnnnn{\faXbox}{xbox}{brands2}{9}{"F412}
\__fontawesome_def_icon:nnnnn{\faXing}{xing}{brands2}{10}{"F168}
\__fontawesome_def_icon:nnnnn{\faXmark}{xmark}{free5}{108}{"F00D}
\__fontawesome_def_icon:nnnnn{\faXmarksLines}{xmarks-lines}{free5}{109}{"E59A}
\__fontawesome_def_icon:nnnnn{\faY}{y}{free5}{110}{"59}
\__fontawesome_def_icon:nnnnn{\faYCombinator}{y-combinator}{brands2}{12}{"F23B}
\__fontawesome_def_icon:nnnnn{\faYahoo}{yahoo}{brands2}{13}{"F19E}
\__fontawesome_def_icon:nnnnn{\faYammer}{yammer}{brands2}{14}{"F840}
\__fontawesome_def_icon:nnnnn{\faYandex}{yandex}{brands2}{15}{"F413}
\__fontawesome_def_icon:nnnnn{\faYandexInternational}{yandex-international}{brands2}{16}{"F414}
\__fontawesome_def_icon:nnnnn{\faYarn}{yarn}{brands2}{17}{"F7E3}
\__fontawesome_def_icon:nnnnn{\faYelp}{yelp}{brands2}{18}{"F1E9}
\__fontawesome_def_icon:nnnnn{\faYenSign}{yen-sign}{free5}{111}{"F157}
\__fontawesome_def_icon:nnnnn{\faYinYang}{yin-yang}{free5}{112}{"F6AD}
\__fontawesome_def_icon:nnnnn{\faYoast}{yoast}{brands2}{19}{"F2B1}
\__fontawesome_def_icon:nnnnn{\faYoutube}{youtube}{brands2}{20}{"F167}
\__fontawesome_def_icon:nnnnn{\faZ}{z}{free5}{113}{"5A}
\__fontawesome_def_icon:nnnnn{\faZhihu}{zhihu}{brands2}{23}{"F63F}
